@@ -20,7 +20,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
 */ 
 
 #ifndef _GNUstep_H_GSNibTemplates
@@ -37,7 +37,7 @@
 // versions of the nib container and the templates.
 #define GNUSTEP_NIB_VERSION 1
 #define GSSWAPPER_VERSION   0
-#define GSWINDOWT_VERSION   0
+#define GSWINDOWT_VERSION   1
 #define GSVIEWT_VERSION     0
 #define GSCONTROLT_VERSION  0
 #define GSTEXTT_VERSION     0
@@ -50,6 +50,15 @@
 @class	NSMutableDictionary;
 @class  NSMutableSet;
 
+/** Window template autopositioning constants */
+enum {
+  GSWindowAutoPositionNone = 0,
+  GSWindowMinXMargin = 1,
+  GSWindowMaxXMargin = 2,
+  GSWindowMinYMargin = 4,
+  GSWindowMaxYMargin = 8
+};
+
 /*
  * This is the class that holds objects within a nib.
  */
@@ -100,7 +109,15 @@
 @interface GSWindowTemplate : GSClassSwapper
 {
   BOOL                 _deferFlag;
+  unsigned int         _autoPositionMask;
+  NSRect               _screenRect;
 }
+// auto position the window.
+- (unsigned int) autoPositionMask;
+- (void) setAutoPositionMask: (unsigned int)flag;
+- (void) autoPositionWindow: (NSWindow *)window;
+
+// set attributes specific to the template.
 - (void) setDeferFlag: (BOOL)flag;
 - (BOOL) deferFlag;
 @end
