@@ -24,7 +24,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #ifndef _GNUstep_H_NSFont
@@ -88,6 +88,14 @@ APPKIT_EXPORT const float *NSFontIdentityMatrix;
   -screenFont (and retained). For screen fonts, it's nil.
   */
   NSFont *cachedScreenFont;
+
+  /*
+  In the GNUstep implementation, fonts may encapsulate some rendering state
+  relating to view flipped state, therefore we generate a separate font for
+  this case.  We don't create it by default, unless -set is called in a
+  flipped context.
+  */
+  NSFont *cachedFlippedFont;
 }
 
 //
