@@ -25,7 +25,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #ifndef _GNUstep_H_NSTextView
@@ -123,6 +123,8 @@ therefore be stored in the NSLayoutManager to avoid problems.
     /* YES if delegate responds to
        `textView:willChangeSelectionFromCharacterRange:toCharacterRange:' */
     unsigned delegate_responds_to_will_change_sel:1;
+    /* YES if a DnD operation is in progress with this as the target view */
+    unsigned isDragTarget:1;
   } _tf;
 
 
@@ -201,6 +203,10 @@ therefore be stored in the NSLayoutManager to avoid problems.
   */
   int _currentInsertionPointMovementDirection;
 
+  /* Ivar to store the original range so it can be restored after a DnD
+   * operation is cancelled (the mouse moves back out of the view).
+   */
+  NSRange _dragTargetSelectionRange;
   /*
   TODO:
   Still need to figure out what "proper behavior" is when moving between two
