@@ -21,7 +21,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "GNUstepGUI/GSHorizontalTypesetter.h"
@@ -258,7 +258,7 @@ including gi will have been cached.
       if (g->g == NSControlGlyph)
 	return gi + cache_base;
       ch = [str characterAtIndex: g->char_index];
-      if (ch == 0x20 || ch == 0x0a || ch == 0x0d /* TODO: paragraph/line separator */ )
+      if (ch == 0x20 || ch == 0x0a || ch == 0x0d /* TODO: paragraph/line separator */)
 	{
 	  g->dont_show = YES;
 	  if (gi > 0)
