@@ -21,7 +21,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <Foundation/NSCharacterSet.h>
@@ -97,7 +97,7 @@ Private method used internally by GSLayoutManager for sanity checking.
   r->font = [r->font retain];
 }
 
--(void ) _run_free_attributes: (glyph_run_t *)r
+-(void) _run_free_attributes: (glyph_run_t *)r
 {
   [r->font release];
 }
