@@ -22,7 +22,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library;
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include <Foundation/NSArray.h>
@@ -50,6 +50,7 @@
 #include <AppKit/NSNibLoading.h>
 #include <AppKit/NSNibConnector.h>
 #include <AppKit/NSApplication.h>
+#include <AppKit/NSScreen.h>
 #include <GNUstepBase/GSObjCRuntime.h>
 #include <GNUstepGUI/GSNibTemplates.h>
 
@@ -110,7 +111,7 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 
 - init
 {
-  if((self = [super init]) != nil)
+  if ((self = [super init]) != nil)
     {
       NSNotificationCenter *nc = [NSNotificationCenter defaultCenter];
 
@@ -227,7 +228,7 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
        * file.
        */
       obj = [context objectForKey: @"NSTopLevelObjects"];
-      if([obj isKindOfClass: [NSMutableArray class]])
+      if ([obj isKindOfClass: [NSMutableArray class]])
 	{
 	  topObjects = obj;
 	}
@@ -247,7 +248,7 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 	  if ([context objectForKey: key] == nil || 
 	      [key isEqualToString: @"NSOwner"]) // we want to send the message to the owner
 	    {
-	      if([key isEqualToString: @"NSWindowsMenu"] == NO && // we don't want to send a message to these menus twice, 
+	      if ([key isEqualToString: @"NSWindowsMenu"] == NO && // we don't want to send a message to these menus twice, 
 		 [key isEqualToString: @"NSServicesMenu"] == NO && // if they're custom classes.
 		 [key isEqualToString: @"NSVisible"] == NO && // also exclude any other special parts of the nameTable.
 		 [key isEqualToString: @"NSDeferred"] == NO &&
@@ -275,11 +276,11 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 		   * then he will get the objects back in an array which he merely must release in
 		   * order to release the objects held within.  GJC
 		   */
-		  if([key isEqualToString: @"NSOwner"] == NO)
+		  if ([key isEqualToString: @"NSOwner"] == NO)
 		    {
-		      if([topLevelObjects containsObject: o]) // anything already designated a top level item..
+		      if ([topLevelObjects containsObject: o]) // anything already designated a top level item..
 			{
-			  if(topObjects == nil)
+			  if (topObjects == nil)
 			    {
 			      // It is expected, if the NSTopLevelObjects key is not passed in,
 			      // that the user has opted to either allow these objects to leak or
@@ -346,7 +347,7 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 - (void) encodeWithCoder: (NSCoder*)aCoder
 {
   int version = [GSNibContainer version];
-  if(version == GNUSTEP_NIB_VERSION)
+  if (version == GNUSTEP_NIB_VERSION)
     {
       [aCoder encodeObject: nameTable];
       [aCoder encodeObject: connections];
@@ -376,13 +377,13 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
   int version = [aCoder versionForClassName: @"GSNibContainer"]; 
 
   // save the version to the ivar, we need it later.
-  if(version == GNUSTEP_NIB_VERSION)
+  if (version == GNUSTEP_NIB_VERSION)
     {
       [aCoder decodeValueOfObjCType: @encode(id) at: &nameTable];
       [aCoder decodeValueOfObjCType: @encode(id) at: &connections];
       [aCoder decodeValueOfObjCType: @encode(id) at: &topLevelObjects];
     }
-  else if(version == 0)
+  else if (version == 0)
     {
       GSNibItemCollector *nibitems = [[GSNibItemCollector alloc] init];
       NSEnumerator *en;
@@ -399,10 +400,10 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 
       // iterate through the objects returned
       en = [nameTable keyEnumerator];
-      while((key = [en nextObject]) != nil)
+      while ((key = [en nextObject]) != nil)
 	{
 	  id o = [nameTable objectForKey: key];
-	  if(([o isKindOfClass: [NSMenu class]] && [key isEqual: @"NSMenu"]) ||
+	  if (([o isKindOfClass: [NSMenu class]] && [key isEqual: @"NSMenu"]) ||
 	     [o isKindOfClass: [NSWindow class]])
 	    {
 	      [topLevelObjects addObject: o]; // if it's a top level object, add it.
@@ -525,9 +526,9 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
   // the set of things to be retained.  Also, the initial version of the nib container
   // needed this code, but subsequent versions don't, so don't send the notification,
   // if the version isn't zero.
-  if(obj != nil && [aCoder versionForClassName: NSStringFromClass([GSNibContainer class])] == 0)
+  if (obj != nil && [aCoder versionForClassName: NSStringFromClass([GSNibContainer class])] == 0)
     {
-      if([self isKindOfClass: [GSNibItem class]] == YES &&
+      if ([self isKindOfClass: [GSNibItem class]] == YES &&
 	 [self isKindOfClass: [GSCustomView class]] == NO)
 	{
 	  NSNotificationCenter *nc = [NSNotificationCenter defaultCenter];
@@ -594,14 +595,13 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 
 - (id) initWithObject: (id)object className: (NSString *)className superClassName: (NSString *)superClassName
 {
-  if((self = [self init]) != nil)
+  if ((self = [self init]) != nil)
     {
       NSDebugLog(@"Created template %@ -> %@",NSStringFromClass([self class]), className);
       ASSIGN(_object, object);
-      ASSIGN(_className, [className copy]);
-      NSAssert(![className isEqualToString: superClassName], NSInvalidArgumentException);
+      ASSIGN(_className, className);
       _superClass = NSClassFromString(superClassName);
-      if(_superClass == nil)
+      if (_superClass == nil)
 	{
 	  [NSException raise: NSInternalInconsistencyException
 		       format: @"Unable to find class '%@', it is not linked into the application.", superClassName];
@@ -612,7 +612,7 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 
 - init
 {
-  if((self = [super init]) != nil)
+  if ((self = [super init]) != nil)
     {
       _className = nil;
       _superClass = nil;
@@ -621,9 +621,16 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
   return self;
 }
 
+- (void) dealloc
+{
+  RELEASE(_object);
+  RELEASE(_className);
+  [super dealloc];
+}
+
 - (void) setClassName: (NSString *)name
 {
-  ASSIGN(_className, [name copy]);
+  ASSIGN(_className, name);
 }
 
 - (NSString *)className
@@ -635,9 +642,9 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 {
   id obj = nil;
   int version = [coder versionForClassName: @"GSClassSwapper"];
-  if(version == 0)
+  if (version == 0)
     {
-      if((self = [super init]) != nil)
+      if ((self = [super init]) != nil)
 	{
 	  NSUnarchiver *unarchiver = (NSUnarchiver *)coder;
 
@@ -647,10 +654,10 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 
 	  // if we are living within the interface builder app, then don't try to 
 	  // morph into the subclass.
-	  if([self shouldSwapClass])
+	  if ([self shouldSwapClass])
 	    {
 	      Class aClass = NSClassFromString(_className);
-	      if(aClass == 0)
+	      if (aClass == nil)
 		{
 		  [NSException raise: NSInternalInconsistencyException
 			       format: @"Unable to find class '%@', it is not linked into the application.", _className];
@@ -680,7 +687,7 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
   [aCoder encodeValueOfObjCType: @encode(id) at: &_className];  
   [aCoder encodeValueOfObjCType: @encode(Class) at: &_superClass];
 
-  if(_object != nil)
+  if (_object != nil)
     {
       // Don't call encodeValue, the way templates are used will prevent
       // it from being saved correctly.  Just call encodeWithCoder directly.
@@ -691,7 +698,7 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 - (BOOL) shouldSwapClass
 {
   BOOL result = YES;
-  if([self respondsToSelector: @selector(isInInterfaceBuilder)])
+  if ([self respondsToSelector: @selector(isInInterfaceBuilder)])
     {
       result = !([self isInInterfaceBuilder]);
     }
@@ -708,6 +715,16 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
     }
 }
 
+- (unsigned int) autoPositionMask
+{
+  return _autoPositionMask;
+}
+
+- (void)setAutoPositionMask: (unsigned int)flag
+{
+  _autoPositionMask = flag;
+}
+
 - (BOOL)deferFlag
 {
   return _deferFlag;
@@ -718,33 +735,136 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
   _deferFlag = flag;
 }
 
+- (void) autoPositionWindow: (NSWindow *)window
+{
+  int		options = 0;
+  NSRect        currentScreenFrame = [[window screen] frame];
+  NSRect        windowFrame = [window frame];
+  NSPoint       origin  = windowFrame.origin;
+  NSSize	newSize = currentScreenFrame.size;
+  NSSize        oldSize = _screenRect.size;
+  BOOL		changedOrigin = NO;
+
+  // reposition the window on the screen.
+  if (_autoPositionMask == GSWindowAutoPositionNone)
+    return;
+
+  /*
+   * determine if and how the X axis can be resized
+   */
+  if (_autoPositionMask & GSWindowMinXMargin)
+    options++;
+
+  if (_autoPositionMask & GSWindowMaxXMargin)
+    options++;
+
+  /*
+   * adjust the X axis if any X options are set in the mask
+   */
+  if (options > 0)
+    {
+      float change = newSize.width - oldSize.width;
+      float changePerOption = change / options;
+
+      if (_autoPositionMask & GSWindowMinXMargin)
+	{
+	  origin.x += changePerOption;
+	  changedOrigin = YES;
+	}
+    }
+
+  /*
+   * determine if and how the Y axis can be resized
+   */
+  options = 0;
+  if (_autoPositionMask & GSWindowMinYMargin)
+    options++;
+
+  if (_autoPositionMask & GSWindowMaxYMargin)
+    options++;
+
+  /*
+   * adjust the Y axis if any Y options are set in the mask
+   */
+  if (options > 0)
+    {
+      float change = newSize.height - oldSize.height;
+      float changePerOption = change / options;
+      
+      if (_autoPositionMask & (GSWindowMaxYMargin | GSWindowMinYMargin))
+	{
+	  if (_autoPositionMask & GSWindowMinYMargin)
+	    {
+	      origin.y += changePerOption;
+	      changedOrigin = YES;
+	    }
+	}
+    }
+  
+  // change the origin of the window.
+  if (changedOrigin)
+    {
+      [window setFrameOrigin: origin];
+    }
+}
+
 // NSCoding...
 - (id) initWithCoder: (NSCoder *)coder
 {
   id obj = [super initWithCoder: coder];
-  if(obj != nil)
+  if (obj != nil)
     {
-      NSView *contentView = nil;
+      int version = [coder versionForClassName: @"GSWindowTemplate"];
 
-      // decode the defer flag...
-      [coder decodeValueOfObjCType: @encode(BOOL) at: &_deferFlag];      
+      if (version == GSWINDOWT_VERSION)
+	{
+	  // decode the defer flag...
+	  [coder decodeValueOfObjCType: @encode(BOOL) at: &_deferFlag];      
+	  [coder decodeValueOfObjCType: @encode(unsigned int) at: &_autoPositionMask];
+	  _screenRect = [coder decodeRect];
+	}
+      else if (version == 0)
+	{
+	  // decode the defer flag...
+	  [coder decodeValueOfObjCType: @encode(BOOL) at: &_deferFlag];      
+	  _autoPositionMask = GSWindowAutoPositionNone;
+	  _screenRect = [[_object screen] frame];
+	}
 
-      if([self shouldSwapClass])
-      {
-	if(GSGetMethod([obj class], @selector(initWithContentRect:styleMask:backing:defer:), YES, NO) != NULL)
-	  {
-	    // if we are not in interface builder, call 
-	    // designated initializer per spec...
-	    contentView = [obj contentView];
-	    obj = [obj initWithContentRect: [obj frame]
-		       styleMask: [obj styleMask]
-		       backing: [obj backingType]
-		       defer: _deferFlag];
-	    
-	    // set the content view back
-	    [obj setContentView: contentView];
-	  }
-      }
+      if ([self shouldSwapClass])
+	{
+	  if (GSGetMethod([obj class], @selector(initWithContentRect:styleMask:backing:defer:), YES, NO) != NULL
+	   && ![_className isEqualToString: NSStringFromClass(_superClass)])
+	    {
+	      NSView *contentView = [obj contentView];
+
+	      // if we are not in an interface builder, call 
+	      // designated initializer per spec...
+	      RETAIN(contentView); // prevent view from being deallocated.
+	      obj = [obj initWithContentRect: [contentView frame]
+			 styleMask: [obj styleMask]
+			 backing: [obj backingType]
+			 defer: _deferFlag];
+	      
+	      // set the content view back
+	      [obj setContentView: contentView];
+	      RELEASE(contentView); // release view.
+	    }
+
+	  // autoposition window
+	  [self autoPositionWindow: obj];
+	}
+      else
+	{
+	  //
+	  // Set all of the attributes into the object, if it 
+	  // responds to any of these methods.
+	  //
+	  if ([obj respondsToSelector: @selector(setAutoPositionMask:)])
+	    {
+	      [obj setAutoPositionMask: [self autoPositionMask]];
+	    }
+	}
       RELEASE(self);
     }
   return obj;
@@ -752,8 +872,21 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 
 - (void) encodeWithCoder: (NSCoder *)coder
 {
+  int version = [[self class] version];
+
   [super encodeWithCoder: coder];
-  [coder encodeValueOfObjCType: @encode(BOOL) at: &_deferFlag];      
+
+  if (version == GSWINDOWT_VERSION)
+    {
+      _screenRect = [[_object screen] frame];  
+      [coder encodeValueOfObjCType: @encode(BOOL) at: &_deferFlag];
+      [coder encodeValueOfObjCType: @encode(unsigned int) at: &_autoPositionMask];
+      [coder encodeRect: _screenRect]; 
+    }
+  else if (version == 0)
+    {
+      [coder encodeValueOfObjCType: @encode(BOOL) at: &_deferFlag];
+    }
 }
 @end
 
@@ -769,11 +902,12 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 - (id) initWithCoder: (NSCoder *)coder
 {
   id obj = [super initWithCoder: coder];
-  if(obj != nil)
+  if (obj != nil)
     {
-      if([self shouldSwapClass])
+      if ([self shouldSwapClass])
       {
-	if(GSGetMethod([obj class],@selector(initWithFrame:), YES, NO) != NULL)
+	if (GSGetMethod([obj class],@selector(initWithFrame:), YES, NO) != NULL
+	   && ![_className isEqualToString: NSStringFromClass(_superClass)])
 	  {
 	    NSRect theFrame = [obj frame];
 	    obj =  [obj initWithFrame: theFrame];
@@ -798,11 +932,12 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 - (id) initWithCoder: (NSCoder *)coder
 {
   id     obj = [super initWithCoder: coder];
-  if(obj != nil)
+  if (obj != nil)
     {
-      if([self shouldSwapClass])
+      if ([self shouldSwapClass])
       {
-	if(GSGetMethod([obj class],@selector(initWithFrame:), YES, NO) != NULL)
+	if (GSGetMethod([obj class],@selector(initWithFrame:), YES, NO) != NULL
+	   && ![_className isEqualToString: NSStringFromClass(_superClass)])
 	  {
 	    NSRect theFrame = [obj frame]; 
 	    obj = [obj initWithFrame: theFrame];
@@ -827,11 +962,12 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 - (id) initWithCoder: (NSCoder *)coder
 {
   id     obj = [super initWithCoder: coder];
-  if(obj != nil)
+  if (obj != nil)
     {
-      if([self shouldSwapClass])
+      if ([self shouldSwapClass])
       {
-	if(GSGetMethod([obj class],@selector(initWithFrame:textContainer:), YES, NO) != NULL)
+	if (GSGetMethod([obj class],@selector(initWithFrame:textContainer:), YES, NO) != NULL
+	   && ![_className isEqualToString: NSStringFromClass(_superClass)])
 	  {
 	    NSRect theFrame = [obj frame];
 	    id textContainer = [obj textContainer];
@@ -858,11 +994,12 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 - (id) initWithCoder: (NSCoder *)coder
 {
   id     obj = [super initWithCoder: coder];
-  if(obj != nil)
+  if (obj != nil)
     {
-      if([self shouldSwapClass])
+      if ([self shouldSwapClass])
       {
-	if(GSGetMethod([obj class],@selector(initWithTitle:), YES, NO) != NULL)
+	if (GSGetMethod([obj class],@selector(initWithTitle:), YES, NO) != NULL
+	   && ![_className isEqualToString: NSStringFromClass(_superClass)])
 	  {
 	    NSString *theTitle = [obj title]; 
 	    obj = [obj initWithTitle: theTitle];
@@ -888,12 +1025,12 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 - (id) initWithCoder: (NSCoder *)coder
 {
   id     obj = [super initWithCoder: coder];
-  if(obj != nil)
+  if (obj != nil)
     {
       /* 
-      if([self shouldSwapClass])
+      if ([self shouldSwapClass])
       {
-	if(GSGetMethod([obj class],@selector(initWithFrame:), YES, NO) != NULL)
+	if (GSGetMethod([obj class],@selector(initWithFrame:), YES, NO) != NULL)
 	  {
 	    NSRect theFrame = [obj frame]; 
 	    obj = [obj initWithFrame: theFrame];
@@ -918,11 +1055,12 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 - (id) initWithCoder: (NSCoder *)coder
 {
   id     obj = [super initWithCoder: coder];
-  if(obj != nil)
+  if (obj != nil)
     {
-      if([self shouldSwapClass])
+      if ([self shouldSwapClass])
       {
-	if(GSGetMethod([obj class],@selector(init), YES, NO) != NULL)
+	if (GSGetMethod([obj class],@selector(init), YES, NO) != NULL
+	   && ![_className isEqualToString: NSStringFromClass(_superClass)])
 	  {
 	    obj = [self init];
 	  }
@@ -942,11 +1080,8 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
       withSuperClassName: (NSString *)superClassName
 {
   id template = nil;
-  if(object != nil)
+  if (object != nil)
     {
-      // NSData *objectData = nil;
-      // [archiver encodeRootObject: object];
-      // objectData = [archiver archiverData];
       if ([object isKindOfClass: [NSWindow class]])
 	{
 	  template = [[GSWindowTemplate alloc] initWithObject: object
@@ -983,13 +1118,14 @@ static NSString *GSInternalNibItemAddedNotification = @"_GSInternalNibItemAddedN
 					     className: className 
 					     superClassName: superClassName];
 	}
-      else if ([object isKindOfClass: [NSObject class]]) // for gui elements derived from NSObject
+      else if ([object isKindOfClass: [NSObject class]]) 
 	{
+	  // for gui elements derived from NSObject
 	  template = [[GSObjectTemplate alloc] initWithObject: object
 					       className: className 
 					       superClassName: superClassName];
 	}
     }
-  return template;
+  return AUTORELEASE(template);
 }
 @end
