@@ -21,7 +21,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
@@ -60,7 +60,7 @@
 
 static GSServicesManager	*manager = nil;
 
-/*
+/**
  *	The GSListener class is for talking to other applications.
  *	It is a proxy with some dangerous methods implemented in a
  *	harmless manner to reduce the chances of a malicious app
@@ -120,43 +120,74 @@ NSUnregisterServicesProvider(NSString *name)
 void
 NSRegisterServicesProvider(id provider, NSString *name)
 {
+  NSPortNameServer	*ns;
+  id			namedPort;
+
+  if ([name length] == 0)
+    {
+      [NSException raise: NSInvalidArgumentException
+		  format: @"NSRegisterServicesProvider() no name provided"];
+    }
+  if (provider == nil)
+    {
+      [NSException raise: NSInvalidArgumentException
+		  format: @"NSRegisterServicesProvider() no provider"];
+    }
+  if (servicesProvider == provider && [providerName isEqual: name])
+    {
+      return;	// Already registered.
+    }
+
+  ns = [NSPortNameServer systemDefaultPortNameServer];
+  namedPort = [ns portForName: name];
+  if ([listenerConnection receivePort] == namedPort)
+    {
+      [ns removePortForName: name];
+      namedPort = nil;
+    }
+  if (namedPort != nil)
+    {
+      [NSException raise: NSInvalidArgumentException
+		  format: @"NSRegisterServicesProvider() %@ already in use",
+	name];
+    }
+
   if (listenerConnection != nil)
     {
-      /*
-       *	Ensure there is no previous listener and nothing else using
-       *	the given port name.
-       */
-      [[NSPortNameServer systemDefaultPortNameServer] removePortForName: name];
       [[NSNotificationCenter defaultCenter]
 	removeObserver: [GSListener class]
 		  name: NSConnectionDidDieNotification
 		object: listenerConnection];
       DESTROY(listenerConnection);
     }
-  if (name != nil && provider != nil)
+
+  listenerConnection = [NSConnection newRegisteringAtName: name
+    withRootObject: [GSListener listener]];
+  if (listenerConnection != nil)
     {
-      listenerConnection = [NSConnection newRegisteringAtName: name
-	withRootObject: [GSListener listener]];
-      if (listenerConnection != nil)
-	{
-	  RETAIN(listenerConnection);
-	  [[NSNotificationCenter defaultCenter]
-                    addObserver: [GSListener class]
-		       selector: @selector(connectionBecameInvalid:)
-			   name: NSConnectionDidDieNotification
-			 object: listenerConnection];
-	}
-      else
-	{
-	  [NSException raise: NSGenericException
-		      format: @"unable to register %@", name];
-	}
+      RETAIN(listenerConnection);
+      [[NSNotificationCenter defaultCenter]
+		addObserver: [GSListener class]
+		   selector: @selector(connectionBecameInvalid:)
+		       name: NSConnectionDidDieNotification
+		     object: listenerConnection];
     }
+  else
+    {
+      [NSException raise: NSGenericException
+		  format: @"unable to register %@", name];
+    }
+
   ASSIGN(servicesProvider, provider);
   ASSIGN(providerName, name);
 }
 
-/*
+
+@interface NSNotificationCenter (NSWorkspacePrivate)
+- (void) _postLocal: (NSString*)name userInfo: (NSDictionary*)info;
+@end
+
+/**
  * The GSListener class exists as a proxy to forward messages to
  * service provider objects.  It implements very few methods and
  * those that it does implement are generally designed to defeat
@@ -217,12 +248,15 @@ NSRegisterServicesProvider(id provider, NSString *name)
 
 + (void) setServicesProvider: (id)anObject
 {
-  NSString	*appName;
-
   if (servicesProvider != anObject)
     {
-      appName = [[NSProcessInfo processInfo] processName];
-      NSRegisterServicesProvider(anObject, appName);
+      NSString	*port = [[GSServicesManager manager] port];
+
+      if (port == nil)
+	{
+	  port = [[NSProcessInfo processInfo] processName];
+	}
+      NSRegisterServicesProvider(anObject, port);
     }
 }
 
@@ -248,12 +282,25 @@ NSRegisterServicesProvider(id provider, NSString *name)
   SEL		aSel = [anInvocation selector];
   NSString      *selName = NSStringFromSelector(aSel);
 
-  /*
-   *    If the selector matches the correct form for a services request,
-   *    send the message to the services provider.
-   */
-  if ([selName hasSuffix: @":userData:error:"])
+  if ([selName isEqualToString: @"terminate:"])
     {
+      NSNotificationCenter	*c;
+
+      /*
+       * Send a power off notification before asking app to terminate.
+       */
+      c = [[NSWorkspace sharedWorkspace] notificationCenter];
+      [c _postLocal: NSWorkspaceWillPowerOffNotification userInfo: nil];
+
+      [anInvocation invokeWithTarget: NSApp];
+      return;
+    }
+  else if ([selName hasSuffix: @":userData:error:"])
+    {
+      /*
+       *    The selector matches the correct form for a services request,
+       *    so send the message to the services provider.
+       */
       if ([servicesProvider respondsToSelector: aSel] == YES)
 	{
 	  NSPasteboard	*pb;
@@ -277,6 +324,12 @@ NSRegisterServicesProvider(id provider, NSString *name)
     {
       id	delegate = [[NSApplication sharedApplication] delegate];
 
+      if ([selName isEqualToString: @"activateIgnoringOtherApps:"])
+	{
+	  [anInvocation invokeWithTarget: NSApp];
+	  return;
+	}
+
       if ([selName hasPrefix: @"application:"] == YES)
 	{
 	  if ([delegate respondsToSelector: aSel] == YES)
@@ -329,7 +382,11 @@ NSRegisterServicesProvider(id provider, NSString *name)
   NSMethodSignature	*sig = nil;
   NSString      	*selName = NSStringFromSelector(aSelector);
 
-  if ([selName hasSuffix: @":userData:error:"])
+  if ([selName isEqualToString: @"terminate:"])
+    {
+      sig = [NSApp methodSignatureForSelector: aSelector];
+    }
+  else if ([selName hasSuffix: @":userData:error:"])
     {
       sig = [servicesProvider methodSignatureForSelector: aSelector];
     }
@@ -407,7 +464,7 @@ NSRegisterServicesProvider(id provider, NSString *name)
 static NSString         *servicesName = @".GNUstepServices";
 static NSString         *disabledName = @".GNUstepDisabled";
 
-/*
+/**
  *      Create a new listener for this application.
  *      Uses NSRegisterServicesProvider() to register itsself as a service
  *      provider with the applications name so we can handle incoming
@@ -424,7 +481,7 @@ static NSString         *disabledName = @".GNUstepDisabled";
 	{
 	  manager->_application = app;
 	}
-      return manager;
+      return RETAIN(manager);
     }
 
   manager = [GSServicesManager alloc];
@@ -667,7 +724,7 @@ static NSString         *disabledName = @".GNUstepDisabled";
   return NO;
 }
 
-/*
+/**
  *      Use tag in menu item to identify slot in menu titles array that
  *      contains the full title of the service.
  *      Return nil if this is not one of our service menu items.
@@ -765,6 +822,16 @@ static NSString         *disabledName = @".GNUstepDisabled";
   return _title2info;
 }
 
+/**
+ * Returns the 'port' of this application ... this is the name the
+ * application is registered under so that other apps can connect to
+ * it to use any services it provides.
+ */
+- (NSString*) port
+{
+  return _port;
+}
+
 - (void) rebuildServices
 {
   NSDictionary          *services;
@@ -958,7 +1025,7 @@ static NSString         *disabledName = @".GNUstepDisabled";
     }
 }
 
-/*
+/**
  *      Set up connection to listen for incoming service requests.
  */
 - (void) registerAsServiceProvider
@@ -980,59 +1047,85 @@ static NSString         *disabledName = @".GNUstepDisabled";
 
   if (registered == NO)
     {
-      int result = NSRunAlertPanel(appName,
-	@"Application may already be running with this name",
-	@"Continue", @"Abort", @"Rename");
-
-      if (result == NSAlertDefaultReturn || result == NSAlertOtherReturn)
-        {
-          if (result == NSAlertOtherReturn)
-	    appName = [[NSProcessInfo processInfo] globallyUniqueString];
-
-          [[NSPortNameServer systemDefaultPortNameServer]
-	    removePortForName: appName];
-
-          NS_DURING
-            {
-              NSRegisterServicesProvider(self, appName);
-              registered = YES;
-            }
-          NS_HANDLER
-            {
-              registered = NO;
-              NSLog(@"Warning: Could not register application due to "
-                    @"exception: %@\n", [localException reason]);
-            }
-          NS_ENDHANDLER
+      NSUserDefaults	*defs = [NSUserDefaults standardUserDefaults];
+      if ([defs boolForKey: @"NSUseRunningCopy"] == YES)
+	{
+	  id	app;
 
 	  /*
-	   *	Something is seriously wrong - we can't talk to the
-	   *	nameserver, so all interaction with the workspace manager
-	   *	and/or other applications will fail.
-	   *	Give the user a chance to keep on going anyway.
+	   * Try to activate the other app and terminate self.
 	   */
+	  app = [NSConnection rootProxyForConnectionWithRegisteredName: appName
+								  host: @""];
+	  NS_DURING
+	    {
+	      [app activateIgnoringOtherApps: YES];
+	    }
+	  NS_HANDLER
+	    {
+	      /* maybe it terminated. */
+	    }
+	  NS_ENDHANDLER
+	  registered = NO;
+        }
+      else
+	{
+	  unsigned	count = 0;
+
+	  /*
+	   * Try to rename self as a copy.
+	   */
+	  while (registered == NO && ++count < 100)
+	    {
+	      NSString	*tmp;
+
+	      tmp = [appName stringByAppendingFormat: @"Copy%d", count];
+	      NS_DURING
+		{
+		  NSRegisterServicesProvider(self, tmp);
+		  registered = YES;
+		  appName = tmp;
+		}
+	      NS_HANDLER
+		{
+		  registered = NO;
+		}
+	      NS_ENDHANDLER
+	    }
 	  if (registered == NO)
 	    {
+	      int	result;
+
+	      /*
+	       * Something is seriously wrong - we can't talk to the
+	       * nameserver, so all interaction with the workspace manager
+	       * and/or other applications will fail.
+	       * Give the user a chance to keep on going anyway.
+	       */
 	      result = NSRunAlertPanel(appName,
 		@"Unable to register application with ANY name",
 		@"Abort", @"Continue", nil);
-
 	      if (result == NSAlertDefaultReturn)
-		registered = YES;
+		{
+		  registered = YES;
+		}
 	    }
         }
 
       if (registered == NO)
-        [[NSApplication sharedApplication] terminate: self];
+	{
+	  [[NSApplication sharedApplication] terminate: self];
+	}
     }
+  ASSIGN(_port, appName);
 }
 
-/*
+/**
  * Register send and return types that an object can handle - we keep
  * a note of all the possible combinations -
  * 'returnInfo' is a set of all the return types that can be handled
  * without a send.
- * 'combinations' is a dictionary of all send types, with the assciated
+ * 'combinations' is a dictionary of all send types, with the associated
  * values being sets of possible return types.
  */
 - (void) registerSendTypes: (NSArray *)sendTypes
@@ -1316,6 +1409,10 @@ static NSString         *disabledName = @".GNUstepDisabled";
  * it will be inferred from appName ... by convention, applications
  * use their own name (minus any path or extension) for this.
  * </p>
+ * <p>If appName is nil or cannot be launched, this attempts to locate any
+ * application in a standard location whose name matches port and launch
+ * that application.
+ * </p>
  * <p>The value of expire provides a timeout in case the application cannot
  * be contacted promptly.  If it is omitted, a thirty second timeout is
  * used.
@@ -1353,9 +1450,14 @@ GSContactApplication(NSString *appName, NSString *port, NSDate *expire)
     }
   if (app == nil)
     {
-      if ([[NSWorkspace sharedWorkspace] launchApplication: appName] == NO)
+      if (appName == nil
+	|| [[NSWorkspace sharedWorkspace] launchApplication: appName] == NO)
 	{
-	  return nil;		/* Unable to launch.	*/
+          if (port == nil
+	    || [[NSWorkspace sharedWorkspace] launchApplication: port] == NO)
+	    {
+	      return nil;		/* Unable to launch.	*/
+	    }
 	}
 
       NS_DURING
