@@ -22,7 +22,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "GNUstepGUI/GSTable.h"
@@ -189,7 +189,7 @@
   
   borderChange = aBorder - _minXBorder; 
   
-  for(i = 0; i < _numberOfColumns; i++)
+  for (i = 0; i < _numberOfColumns; i++)
     {
       _columnXOrigin[i] += borderChange;
       [self _updateColumnOrigin: i];
@@ -229,7 +229,7 @@
   
   borderChange = aBorder - _minYBorder; 
   
-  for(i = 0; i < _numberOfRows; i++)
+  for (i = 0; i < _numberOfRows; i++)
     {
       _rowYOrigin[i] += borderChange;
       [self _updateRowOrigin: i];
