@@ -30,7 +30,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "config.h"
@@ -289,7 +289,7 @@ makeScrollViewWithRect(NSRect rect)
   [button setButtonType: NSMomentaryPushButton];
   [button setTitle: @""];
   [button setTarget: self];
-  [button setAction: @selector(buttonAction: )];
+  [button setAction: @selector(buttonAction:)];
   [button setFont: [NSFont systemFontOfSize: 0]];
   return button;
 }
@@ -1334,7 +1334,7 @@ void NSBeginInformationalAlertSheet(NSString *title,
   [button setAutoresizingMask: NSViewMinXMargin | NSViewMaxYMargin];
   [button setButtonType: NSMomentaryPushButton];
   [button setTarget: self];
-  [button setAction: @selector(buttonAction: )];
+  [button setAction: @selector(buttonAction:)];
   [button setFont: [NSFont systemFontOfSize: 0]];
   if (count == 0)
     {
@@ -1405,10 +1405,48 @@ void NSBeginInformationalAlertSheet(NSString *title,
   return _delegate;
 }
 
+- (void)_setupPanel
+{
+  GSAlertPanel *panel;
+  NSString *title;
+
+  panel = [[GSAlertPanel alloc] init];
+  _window = panel;
+
+  switch (_style)
+    {
+      case NSCriticalAlertStyle: 
+	  title = @"Critical";
+	  break;
+      case NSInformationalAlertStyle: 
+	  title = @"Information";
+	  break;
+      case NSWarningAlertStyle:
+      default:
+	  title = @"Alert";
+	  break;
+    }
+  [panel setTitle: title];
+  // FIXME: Should also set the icon
+  [panel setTitle: _informative_text
+	 message: _message_text
+	 def: [[_buttons objectAtIndex: 0] title]
+	 alt: [[_buttons objectAtIndex: 1] title]
+	 other: [[_buttons objectAtIndex: 2] title]];
+  [panel sizePanelToFit];
+}
+
 - (int)runModal
 {
-  // FIXME
-  return NSAlertFirstButtonReturn;
+  int result;
+
+  [self _setupPanel];
+  [NSApp runModalForWindow: _window];
+  [_window orderOut: self];
+  result = [(GSAlertPanel*)_window result];
+  DESTROY(_window);
+
+  return result;
 }
 
 - (void)beginSheetModalForWindow:(NSWindow *)window
@@ -1416,7 +1454,13 @@ void NSBeginInformationalAlertSheet(NSString *title,
 		  didEndSelector:(SEL)didEndSelector
 		     contextInfo:(void *)contextInfo
 {
-// FIXME
+  [self _setupPanel];
+  [NSApp beginSheet: _window
+     modalForWindow: window
+      modalDelegate: delegate
+     didEndSelector: didEndSelector
+	contextInfo: contextInfo];
+  DESTROY(_window);
 }
 
 - (id)window
