@@ -1,6 +1,6 @@
 /** <title>NSApplication</title>
 
-   <abstract>The one and only application class</abstract>
+   <abstract>The one and only application class.</abstract>
 
    Copyright (C) 1996,1999 Free Software Foundation, Inc.
 
@@ -26,7 +26,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "config.h"
@@ -72,6 +72,7 @@
 #include "GNUstepGUI/GSServicesManager.h"
 #include "GSGuiPrivate.h"
 #include "GNUstepGUI/GSInfoPanel.h"
+#include "GNUstepGUI/GSVersion.h"
 
 /* The -gui thread. See the comment in initialize_gnustep_backend. */
 NSThread *GSAppKitThread;
@@ -95,7 +96,7 @@ _NSAppKitUncaughtExceptionHandler (NSException *exception)
 
   /*
    * If there is no graphics context to run the alert panel in or
-   * its a sever error, use a non-graphical exception handler
+   * its a severe error, use a non-graphical exception handler
    */
   if (GSCurrentContext() == nil
     || [[exception name] isEqual: NSWindowServerCommunicationException]
@@ -111,7 +112,7 @@ _NSAppKitUncaughtExceptionHandler (NSException *exception)
 	       [[NSProcessInfo processInfo] processName]],
      @"%@: %@", 
      _(@"Abort"), 
-     _(@"Ignore"),
+     nil,
 #ifdef DEBUG
      _(@"Debug"),
 #else
@@ -127,15 +128,11 @@ _NSAppKitUncaughtExceptionHandler (NSException *exception)
 	 library exception handler */
       [exception raise];
     }
-  else if (retVal == NSAlertOther)
+  else
     {
       /* Debug button: abort so we can trace the error in gdb */
       abort();
     }
-
-  /* The user said to go on - more fun I guess - turn the AppKit
-     exception handler on again */
-  NSSetUncaughtExceptionHandler (_NSAppKitUncaughtExceptionHandler);
 }
 
 /* This is the bundle from where we load localization of messages.  */
@@ -152,6 +149,87 @@ NSBundle *GSGuiBundle (void)
 + (void) initializeBackend;
 @end
 
+static NSString *
+gnustep_backend_path (NSString *dir, NSString *name)
+{
+  NSString *path;
+  NSEnumerator *benum;
+
+  NSDebugFLLog(@"BackendBundle", @"Looking for %@", name);
+  
+  /* Find the backend framework */
+  benum = [NSStandardLibraryPaths() objectEnumerator];
+  while ((path = [benum nextObject]))
+    {
+      path = [path stringByAppendingPathComponent: dir];
+      path = [path stringByAppendingPathComponent: name];
+      if ([[NSFileManager defaultManager] fileExistsAtPath: path])
+	{
+	  break;
+	}
+    }
+  return path;
+}
+
+/* Find and load the backend framework, if there is one. The name is
+   taken from a user default containing the name of the backend framework,
+   such as 'GNUstep-back', or simply 'back', or for historical reasons,
+   'libgnustep-back'.  */
+static NSString *
+gnustep_backend_framework (NSString *bundleName)
+{
+  if (bundleName == nil)
+    bundleName = @"GNUstep_back.framework";
+  else
+    {
+      if ([bundleName hasPrefix: @"GNUstep-"])
+	bundleName = [bundleName stringByAppendingString: @".framework"];
+      else 
+	{
+	if  ([bundleName hasPrefix: @"libgnustep-"])
+	  {
+	    bundleName = [bundleName stringByDeletingPrefix: @"libgnustep-"];
+	  }
+	bundleName = [NSString stringWithFormat: @"GNUstep-%@.framework",
+			       bundleName];
+	} 
+    }
+
+  return gnustep_backend_path(@"Frameworks", bundleName);
+}
+
+/* Find and load the backend bundle, if there is one. The name is
+   taken from a user default containing the name of the backend bundle,
+   such as 'back', or for historical reasons, 'libgnustep-back'. New
+   versions may also have a version number associated with it.  */
+static NSString *
+gnustep_backend_bundle(NSString *bundleName)
+{
+  NSString *path, *bundleWithVersion;
+  int version = GNUSTEP_GUI_MAJOR_VERSION * 100 + GNUSTEP_GUI_MINOR_VERSION;
+  
+  if (bundleName == nil)
+    bundleName = @"libgnustep-back";
+  else
+    {
+      if ([bundleName hasPrefix: @"libgnustep-"] == NO)
+	{
+	  bundleName = [NSString stringWithFormat: @"libgnustep-%@",
+				 bundleName];
+	} 
+    }
+  bundleWithVersion = [NSString stringWithFormat: @"%@-%03d.bundle",
+				bundleName, version];
+  bundleName = [bundleName stringByAppendingString: @".bundle"];
+  path = gnustep_backend_path(@"Bundles", bundleWithVersion);
+  if (path == nil)
+    {
+      NSLog(@"Did not find correct version of backend, falling back to std.");
+      path = gnustep_backend_path(@"Bundles", bundleName);
+    }
+  return path;
+}
+
 BOOL
 initialize_gnustep_backend(void)
 {
@@ -173,33 +251,23 @@ initialize_gnustep_backend(void)
 #ifdef BACKEND_BUNDLE
       {      
 	NSBundle *theBundle;
-	NSEnumerator *benum;
 	NSString *path, *bundleName;
 	NSUserDefaults	*defs = [NSUserDefaults standardUserDefaults];
 
 	/* What backend ? */
 	bundleName = [defs stringForKey: @"GSBackend"];
-	if ( bundleName == nil )
-	  bundleName = @"libgnustep-back.bundle";
-	else
-	  bundleName = [bundleName stringByAppendingString: @".bundle"];
-	NSDebugFLLog(@"BackendBundle", @"Looking for %@", bundleName);
-
-	/* Find the backend bundle */
-	benum = [NSStandardLibraryPaths() objectEnumerator];
-	while ((path = [benum nextObject]))
+	path = gnustep_backend_framework (bundleName);
+	if (path == nil)
 	  {
-	    path = [path stringByAppendingPathComponent: @"Bundles"];
-	    path = [path stringByAppendingPathComponent: bundleName];
-	    if ([[NSFileManager defaultManager] fileExistsAtPath: path])
-	      {
-		break;
-	      }
+	    NSDebugLLog(@"BackendBundle", @"Did not find backend framework.");
+	    path = gnustep_backend_bundle (bundleName);
 	  }
 
 	/* FIXME/TODO - update localized error messages.  */
 
 	/* Backend found ? */
+	if (bundleName == nil)
+	  bundleName = @"back";
 	NSCAssert1(path != nil, _(@"Unable to find backend %@"), bundleName);
 	NSDebugLog(@"Loading Backend from %@", path);
 	NSDebugFLLog(@"BackendBundle", @"Loading Backend from %@", path);
@@ -571,6 +639,32 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
 
 @end
 
+/**
+ * <p>Every graphical GNUstep application has exactly one instance of
+ * <code>NSApplication</code> (or a subclass) instantiated.  Usually this is
+ * created through the +sharedApplication method.  Once created, this instance
+ * is always accessible through the global variable '<code>NSApp</code>'.</p>
+ * 
+ * <p>The NSApplication instance manages the main run loop, dispatches
+ * events, and manages resources.  It sets up the connection to the window
+ * server and provides special methods for putting up "modal" (always on top)
+ * windows.</p>
+ *
+ * <p>Typically, -run is called by an application's <code>main</code> method
+ * after the NSApplication instance is created, which never returns.  However,
+ * applications needing to integrate other event loops may strategically call
+ * the -stop method, followed by -run later on.</p>
+ *
+ * <p>To avoid most common needs for subclassing, NSApplication allows you to
+ * specify a <em>delegate</em> that is messaged in particular situations.
+ * See -delegate , -setDelegate: , and [(GSAppDelegateProtocol)].</p>
+ *
+ * <p><strong>Subclassing</strong> should be a last resort, and delegate
+ * methods should be used in most cases.  However, subclassing is most
+ * frequently done to implement custom event loop management by overriding
+ * -run when the method described above is not sufficient, or to intercept
+ * events by overriding -sendEvent: .</p>
+ */
 @implementation NSApplication
 
 /*
@@ -614,6 +708,10 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
   RELEASE(pool);
 }
 
+/**
+ * Calls [NSThread+detachNewThreadSelector:toTarget:withObject:] with the
+ * invocation wrapped by an autorelease pool.
+ */
 + (void) detachDrawingThread: (SEL)selector
 		    toTarget: (id)target
 		  withObject: (id)argument
@@ -630,38 +728,38 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
 }
 
 /**
- * Return the shared application instance, creating one (of the
+ * <p>Return the shared application instance, creating one (of the
  * receiver class) if needed.  There is (and must always be) only a
  * single shared application instance for each application.  After the
  * shared application instance has been created, you can access it
- * directly via the global variable NSApp (but not before!).  When the
- * shared application instance is created, it is also automatically
- * initialized (that is, its -init method is called), which connects
- * to the window server and prepares the gui library for actual
- * operation.  For this reason, you must always call [NSApplication
- * sharedApplication] before using any functionality of the gui
+ * directly via the global variable <code>NSApp</code> (but not before!). When
+ * the shared application instance is created, it is also automatically
+ * initialized (that is, its <code>init</code> method is called), which
+ * connects to the window server and prepares the gui library for actual
+ * operation.  For this reason, you must always call <code>[NSApplication
+ * sharedApplication]</code> before using any functionality of the gui
  * library - so, normally, this should be one of the first commands in
- * your program (if you use NSApplicationMain(), this is automatically
- * done).
+ * your program (if you use <code>NSApplicationMain()</code>, this is
+ * automatically done).</p>
  *
- * The shared application instance is normally an instance of
+ * <p>The shared application instance is normally an instance of
  * NSApplication; but you can subclass NSApplication, and have an
  * instance of your own subclass be created and used as the shared
  * application instance.  If you want to get this result, you need to
  * make sure the first time you call +sharedApplication is on your
  * custom NSApplication subclass (rather than on NSApplication).
- * Putting [MyApplicationClass sharedApplication]; as the first
+ * Putting <code>[MyApplicationClass sharedApplication]</code>; as the first
  * command in your program is the recommended way. :-) If you use
- * NSApplicationMain(), it automatically creates the appropriate
+ * <code>NSApplicationMain()</code>, it automatically creates the appropriate
  * instance (which you can control by editing the info dictionary of
- * the application).
+ * the application).</p>
  *
- * It is not safe to call this method from multiple threads - it would
+ * <p>It is not safe to call this method from multiple threads - it would
  * be useless anyway since the whole library is not thread safe: there
  * must always be at most one thread using the gui library at a time.
  * (If you absolutely need to have multiple threads in your
  * application, make sure only one of them uses the gui [the 'drawing'
- * thread], and the other ones do not).
+ * thread], and the other ones do not).</p>
  */
 + (NSApplication *) sharedApplication
 {
@@ -684,9 +782,10 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
 - (void) _init
 {
   GSDisplayServer *srv;
+  NSDictionary *attributes;
   /* Initialization must be enclosed in an autorelease pool.  */
   CREATE_AUTORELEASE_POOL (_app_init_pool);
-
+ 
   /* 
    * Set NSApp as soon as possible, since other gui classes (which
    * we refer or use in this method) might be calling [NSApplication
@@ -706,8 +805,9 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
   RETAIN(srv);
   [GSDisplayServer setCurrentServer: srv];
 
-  /* Create a default context.  */
-  _default_context = [NSGraphicsContext graphicsContextWithAttributes: nil];
+  /* Create a default context with the attributes of the main screen.  */
+  attributes = [[NSScreen mainScreen] deviceDescription];
+  _default_context = [NSGraphicsContext graphicsContextWithAttributes: attributes];
   RETAIN(_default_context);
   [NSGraphicsContext setCurrentContext: _default_context];
 
@@ -758,7 +858,7 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
  * sharedApplication].
  *
  * If you call this method from your code (which we discourage you
- * from doing), it is /your/ responsibility to make sure it is called
+ * from doing), it is <em>your</em> responsibility to make sure it is called
  * only once (this is according to the openstep specification).  Since
  * +sharedApplication automatically calls this method, making also
  * sure it calls it only once, you definitely want to use
@@ -794,6 +894,18 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
   return NSApp;
 }
 
+/**
+ * <p>Activates the application, sets the application icon, loads the main
+ * Nib file if <code>NSMainNibFile</code> is set in the application
+ * property list, posts an
+ * <code>NSApplicationWillFinishLaunchingNotification</code>, and takes care
+ * of a few other startup tasks, then posts
+ * <code>NSApplicationDidFinishLaunchingNotification</code>.
+ * If you override this method, be sure to call <em>super</em>.</p>
+ *
+ * <p>The -run method calls this the first time it is called, before starting
+ * the event loop for the first time.</p>
+ */
 - (void) finishLaunching
 {
   NSBundle		*mainBundle = [NSBundle mainBundle];
@@ -993,8 +1105,12 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
   [super dealloc];
 }
 
-/*
- * Changing the active application
+/**
+ * Activate app unconditionally if flag is YES, otherwise only if no other app
+ * is active.  (<em><strong>Note:</strong> this is currently not implemented
+ * under GNUstep.  The app is always activated unconditionally.</em>)  Usually
+ * it is not necessary to manually call this method, except in some
+ * circumstances of interapplication communication.
  */
 - (void) activateIgnoringOtherApps: (BOOL)flag
 {
@@ -1056,6 +1172,10 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
     }
 }
 
+/**
+ * Forcefully deactivate the app, without activating another.  It is rarely
+ * necessary to use this method.
+ */
 - (void) deactivate
 {
   if (_app_is_active == YES)
@@ -1114,16 +1234,29 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
     }
 }
 
+/**
+ * Returns whether this app is the currently active GNUstep application.
+ * Note that on a GNUstep system, unlike OS X, it is possible for NO GNUstep
+ * app to be active.
+ */
 - (BOOL) isActive
 {
   return _app_is_active;
 }
 
+/**
+ * Cause all other apps to hide themselves.
+ * <em>Unimplemented under GNUstep.</em>
+ */
 - (void) hideOtherApplications: (id)sender
 {
   // FIXME Currently does nothing
 }
 
+/**
+ * Cause all apps including this one to unhide themselves.
+ * <em>Unimplemented under GNUstep.</em>
+ */
 - (void) unhideAllApplications: (id)sender
 {
   // FIXME Currently does nothing
@@ -1134,7 +1267,13 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
  */
 
 /**
- * This method starts the main event loop of the application.
+ * <p>This method first calls -finishLaunching (if this is the first time -run)
+ * has been called, then starts the main event loop of the application which
+ * continues until -terminate: or -stop: is called.</p>
+ *
+ * <p>At each iteration, at most one event is dispatched, the main and services
+ * menus are sent [NSMenu-update] messages, and -updateWindows is possibly
+ * called if this has been flagged as necessary.</p>
  */
 - (void) run
 {
@@ -1147,18 +1286,23 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
 		   format: @"NSApp's run called recursively"];
     }
 
-  IF_NO_GC(_runLoopPool = [arpClass new]);
   /*
    *  Set this flag here in case the application is actually terminated
    *  inside -finishLaunching.
    */
   _app_is_running = YES;
 
-  [self finishLaunching];
+  if (_app_is_launched == NO)
+    {
+      _app_is_launched = YES;
+      IF_NO_GC(_runLoopPool = [arpClass new]);
 
-  [_listener updateServicesMenu];
-  [_main_menu update];
-  DESTROY(_runLoopPool);
+      [self finishLaunching];
+
+      [_listener updateServicesMenu];
+      [_main_menu update];
+      DESTROY(_runLoopPool);
+    }
  
   while (_app_is_running)
     {
@@ -1201,6 +1345,9 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
   DESTROY (_runLoopPool);
 }
 
+/**
+ *  Returns whether the event loop managed by -run is currently active.
+ */
 - (BOOL) isRunning
 {
   return _app_is_running;
@@ -1209,6 +1356,14 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
 /*
  * Running modal event loops
  */
+
+/**
+ * Halts a currently running modal event loop started by -runModalForWindow:
+ * or -runModalSession: .  If you wish to halt the session in response to
+ * user interaction with the modal window, use -stopModalWithCode: or
+ * -stopModal instead; only use this to halt the loop from elsewhere, such as
+ * another thread.
+ */
 - (void) abortModal
 {
   if (_session == 0)
@@ -1262,6 +1417,10 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
   return theSession;
 }
 
+/**
+ * Clean up after a modal session has been run.  Called with theSession
+ * returned from a previous call to beginModalSessionForWindow: .
+ */
 - (void) endModalSession: (NSModalSession)theSession
 {
   NSModalSession	tmp = _session;
@@ -1302,9 +1461,9 @@ static NSSize scaledIconSizeForSize(NSSize imageSize)
 
 /**
  * Starts modal event loop for given window, after calling
- * -beginModalSessionForWindow:.  Loop is broken only by stopModal: ,
- * -stopModalWithCode: , or -abortModal: , at which time -endModalSession:
- * is called.
+ * -beginModalSessionForWindow:.  Loop is broken only by -stopModal ,
+ * -stopModalWithCode: , or -abortModal , at which time -endModalSession:
+ * is called automatically.
  */
 - (int) runModalForWindow: (NSWindow*)theWindow
 {
@@ -1483,6 +1642,9 @@ See -runModalForWindow:
     return nil;
 }
 
+/**
+ * Stops the main run loop, as well as a modal session if it is running.
+ */
 - (void) stop: (id)sender
 {
   if (_session != 0)
@@ -1498,11 +1660,21 @@ See -runModalForWindow:
     }
 }
 
+/**<p> Stops a running modal session causing -runModalForWindow: or
+ * -runModalSession: to return <code>NSRunStoppedResponse</code>.  Use this
+ * or -stopModalWithCode: to end a modal session in response to user input.</p>
+ * <p>See Also: -stopModalWithCode:</p>
+ */
 - (void) stopModal
 {
   [self stopModalWithCode: NSRunStoppedResponse];
 }
 
+/**
+ * Stops a running modal session causing -runModalForWindow: or
+ * -runModalSession: to return the specified integer code.  Use this
+ * or -stopModal to end a modal session in response to user input.
+ */
 - (void) stopModalWithCode: (int)returnCode
 {
   if (_session == 0)
@@ -1518,6 +1690,13 @@ See -runModalForWindow:
   _session->runState = returnCode;
 }
 
+/**
+ * Put up a modal window centered relative to docWindow.  On OS X this is
+ * deprecated in favor of
+ * -beginSheet:modalForWindow:modalDelegate:didEndSelector:contextInfo: .
+ * <em>Not implemented under GNUstep.  Currently just centers window on the
+ * screen.</em>
+ */
 - (int) runModalForWindow: (NSWindow *)theWindow
 	relativeToWindow: (NSWindow *)docWindow
 {
@@ -1525,6 +1704,17 @@ See -runModalForWindow:
   return [self runModalForWindow: theWindow];
 }
 
+/**
+ * Put up a modal sheet sliding down from top of docWindow.  If modalDelegate
+ * is non-nil and responds to didEndSelector (this is optional), it is invoked
+ * after the session ends.  The selector should take three arguments:
+ * NSWindow *, int, void *.  It is passed the sheet window, the return code,
+ * and the contextInfo passed in here.
+
+ * <em>Under GNUstep, the sheet aspect is not implemented (just centers
+ * window on the screen), but modalDelegate didEndSelector is called if
+ * both non-nil.</em>
+ */
 - (void) beginSheet: (NSWindow *)sheet
      modalForWindow: (NSWindow *)docWindow
       modalDelegate: (id)modalDelegate
@@ -1547,12 +1737,18 @@ See -runModalForWindow:
     }
 }
 
+/**
+ *  Analogous to -stopModal for sheets.
+ */
 - (void) endSheet: (NSWindow *)sheet
 {
   // FIXME
   [self stopModal];
 }
 
+/**
+ *  Analogous to -stopModalWithCode: for sheets.
+ */
 - (void) endSheet: (NSWindow *)sheet
        returnCode: (int)returnCode
 {
@@ -1564,6 +1760,12 @@ See -runModalForWindow:
 /*
  * Getting, removing, and posting events
  */
+
+/**
+ * Called by -run to dispatch events that are received according to AppKit's
+ * forwarding conventions.  You rarely need to invoke this directly.  If you
+ * want to synthesize an event for processing, call -postEvent:atStart: .
+ */
 - (void) sendEvent: (NSEvent *)theEvent
 {
   NSEventType type;
@@ -1623,17 +1825,38 @@ See -runModalForWindow:
     }
 }
 
+/**
+ * Returns the most recent event -run pulled off the event queue.
+ */
 - (NSEvent*) currentEvent
 {
   return _current_event;
 }
 
+/* Utility for pen-device input.  See NSResponder. */
+- (BOOL) shouldBeTreatedAsInkEvent: (NSEvent *)theEvent
+{
+  return [[theEvent window] shouldBeTreatedAsInkEvent: theEvent];
+}
+
+/**
+ * Drop events matching mask from the queue, before but not including
+ * lastEvent.  The mask is a bitwise AND of event mask constants.
+ * See (EventType) .  Use <code>NSAnyEventMask</code> to discard everything
+ * up to lastEvent.
+ */
 - (void) discardEventsMatchingMask: (unsigned int)mask
 		       beforeEvent: (NSEvent *)lastEvent
 {
   DPSDiscardEvents(GSCurrentServer(), mask, lastEvent);
 }
 
+/**
+ * Return the next event matching mask from the queue, dequeuing if flag is
+ * YES.  Intervening events are NOT dequeued.  If no matching event is on the
+ * queue, will wait for one until expiration, returning nil if none found.
+ * See (EventType) for the list of masks.
+ */
 - (NSEvent*) nextEventMatchingMask: (unsigned int)mask
 			 untilDate: (NSDate*)expiration
 			    inMode: (NSString*)mode
@@ -1677,6 +1900,12 @@ IF_NO_GC(NSAssert([event retainCount] > 0, NSInternalInconsistencyException));
   return event;
 }
 
+/**
+ * Add an event to be processed by the app, either at end or at beginning
+ * (next up) if flag is YES.  This provides a way to provide synthetic input
+ * to an application, or, for whatever reason, to allow a real event to be
+ * re-dispatched.
+ */
 - (void) postEvent: (NSEvent *)event atStart: (BOOL)flag
 {
   DPSPostEvent(GSCurrentServer(), event, flag);
@@ -1741,7 +1970,7 @@ IF_NO_GC(NSAssert([event retainCount] > 0, NSInternalInconsistencyException));
  *   Returns the target object that will respond to aSelector, if any. The
  *   method first checks if any of the key window's first responders, the
  *   key window or its delegate responds. Next it checks the main window in
- *   the same way. Finally it checks the receiver (NSApplication) and it's
+ *   the same way. Finally it checks the receiver (NSApplication) and its
  *   delegate.
  * </p>
  */
@@ -1872,10 +2101,9 @@ IF_NO_GC(NSAssert([event retainCount] > 0, NSInternalInconsistencyException));
   return NO;
 }
 
-/**
-Sets the application's icon. Any windows that use the old application
+/**<p>Sets the application's icon. Any windows that use the old application
 icon image as their mini window image will be updated to use the new
-image.
+image.</p><p>See Also: -applicationIconImage</p>
 */
 - (void) setApplicationIconImage: (NSImage*)anImage
 {
@@ -1903,11 +2131,18 @@ image.
   DESTROY(old_app_icon);
 }
 
+/**<p>Returns the current icon be used for the application.</p>
+   <p>See Also: -setApplicationIconImage:</p>
+ */
 - (NSImage*) applicationIconImage
 {
   return _app_icon;
 }
 
+/**
+ * Returns the actual window object being used to display the application
+ * icon (usually in the dock).
+ */
 - (NSWindow*) iconWindow
 {
   return _app_icon_window;
@@ -1916,6 +2151,14 @@ image.
 /*
  * Hiding and arranging windows
  */
+
+/**<p> Request this application to "hide" (unmap all windows from the screen
+ * except the icon window).  Posts 
+ * <code>NSApplicationWillHideNotification</code> and
+ * <code>NSApplicationDidHideNotification</code>.  On OS X this activates
+ * the next app that is running, however on GNUstep this is up to the window
+ * manager.</p><p>See Also: -unhide: -isHidden</p>
+ */
 - (void) hide: (id)sender
 {
   if (_app_is_hidden == NO)
@@ -1966,11 +2209,17 @@ image.
     }
 }
 
+/**<p>Returns whether app is currently in hidden state.</p>
+   <p>See Also: -hide: -unhide:</p>
+ */
 - (BOOL) isHidden
 {
   return _app_is_hidden;
 }
 
+/**<p>Unhides and activates this application.</p>
+   <p>See Also: -unhideWithoutActivation -hide: -isHidden</p>
+ */
 - (void) unhide: (id)sender
 {
   if (_app_is_hidden)
@@ -1987,6 +2236,9 @@ image.
     }
 }
 
+/**
+ * Unhides this app (displays its windows) but does not activate it.
+ */
 - (void) unhideWithoutActivation
 {
   if (_app_is_hidden == YES)
@@ -2021,6 +2273,10 @@ image.
     }
 }
 
+/**
+ * Arranges all app's windows in front by successively calling
+ * [NSWindow-orderFront:] on each window in the app's Windows menu.
+ */
 - (void) arrangeInFront: (id)sender
 {
   NSMenu	*menu;
@@ -2049,52 +2305,54 @@ image.
 /*
  * Managing windows
  */
+
+/**
+ * Returns current key window.  If this app is active, one window should be
+ * key.  If this app is not active, nil should be returned.  The key window
+ * is the one that will receive keyboard input.
+ */
 - (NSWindow*) keyWindow
 {
   return _key_window;
 }
 
+/**
+ * Returns current main window of this application. There need not necessarily
+ * be a main window, even if app is active, and this should return nil if the
+ * app is inactive.
+ */
 - (NSWindow*) mainWindow
 {
   return _main_window;
 }
 
+/**
+ * Sends aSelector to each window, either in the app's internal window list
+ * (flag = NO) or their stacking order from front to back on the screen
+ * (flag = YES, <em>currently not implemented under GNUstep</em>).
+ */
 - (NSWindow*) makeWindowsPerform: (SEL)aSelector inOrder: (BOOL)flag
 {
   NSArray	*window_list = [self windows];
   unsigned	i;
 
-  if (flag)
+  // FIXME flag ignored
+  i = [window_list count];
+  while (i-- > 0)
     {
-      // FIXME This is not the order specified in the MacOSX spec
-      unsigned	count = [window_list count];
+      NSWindow *window = [window_list objectAtIndex: i];
 
-      for (i = 0; i < count; i++)
-	{
-	  NSWindow *window = [window_list objectAtIndex: i];
-
-	  if ([window performSelector: aSelector] != nil)
-	    {
-	      return window;
-	    }
-	}
-    }
-  else
-    {
-      i = [window_list count];
-      while (i-- > 0)
-	{
-	  NSWindow *window = [window_list objectAtIndex: i];
-
-	  if ([window performSelector: aSelector] != nil)
-	    {
-	      return window;
-	    }
-	}
+      if ([window performSelector: aSelector] != nil)
+        {
+          return window;
+        }
     }
   return nil;
 }
 
+/**
+ * Iconify all windows in the app.
+ */
 - (void) miniaturizeAll: sender
 {
   NSArray *window_list = [self windows];
@@ -2104,16 +2362,30 @@ image.
     [[window_list objectAtIndex: i] miniaturize: sender];
 }
 
+/**
+ * Prevent window reordering in response to most recent mouse down (useful to
+ * prevent raise-on-mouse-click).  <em>Not implemented under GNUstep.</em>
+ */
 - (void) preventWindowOrdering
 {
   //TODO
 }
 
+/**
+ * Set whether the main run loop will request all visible windows update
+ * themselves after the current or next event is processed.  (Update occurs
+ * after event dispatch in the loop.)
+ */
 - (void) setWindowsNeedUpdate: (BOOL)flag
 {
   _windows_need_update = flag;
 }
 
+/**
+ * Sends each of the app's visible windows an [NSWindow-update] message.
+ * This method is called once per iteration of the main run loop managed
+ * by -run .
+ */
 - (void) updateWindows
 {
   NSArray		*window_list = [self windows];
@@ -2132,11 +2404,18 @@ image.
   [nc postNotificationName: NSApplicationDidUpdateNotification object: self];
 }
 
+/**
+ *  Returns array of app's visible and invisible windows.
+ */
 - (NSArray*) windows
 {
   return GSAllWindows();
 }
 
+/**
+ * Returns window for windowNum.  Note the window number can be obtained for
+ * a window from [NSWindow-windowNumber].
+ */
 - (NSWindow *) windowWithWindowNumber: (int)windowNum
 {
   return GSWindowWithNumber(windowNum);
@@ -2145,6 +2424,7 @@ image.
 /*
  * Showing Standard Panels
  */
+
 /** Calls -orderFrontStandardAboutPanelWithOptions: with nil passed as
     the options dictionary.
 */
@@ -2153,7 +2433,7 @@ image.
   [self orderFrontStandardAboutPanelWithOptions: nil];
 }
 
-/** Calls -orderFrontStandardInfoPanelWithOptions:
+/** OS X compatibility: Calls -orderFrontStandardInfoPanelWithOptions: .
 */
 - (void) orderFrontStandardAboutPanelWithOptions: (NSDictionary *)dictionary
 {
@@ -2201,8 +2481,8 @@ image.
    <term>ApplicationIcon</term> 
    <desc> An image to be shown near the title.
    If not available, <file>Info-gnustep.plist</file> is searched for
-   <var>ApplicationIcon</var>; if this fails, [NSApp-applicationIconImage]
-   is used instead.  
+   <var>ApplicationIcon</var>; if this fails, NSApp's -applicationIconImage
+   method is used instead.  
    </desc>
 
    <term>ApplicationRelease</term> 
@@ -2228,7 +2508,7 @@ image.
    <term>Authors</term> 
    <desc> An array of strings, each one with the name
    of an author (eg, <var>[NSArray arrayWithObject: "Nicola Pero
-   &lt;n.peromi.flashnet.it&gt;"]</var>).  If not found,
+   &lt;n.pero\@mi.flashnet.it&gt;"]</var>).  If not found,
    <file>Info-gnustep.plist</file> is searched for <var>Authors</var>,
    if this fails, <var>"Unknown"</var> is displayed.
    </desc>
@@ -2282,7 +2562,8 @@ image.
 }
 
 /**
- * Sets the main menu of the receiver
+ * Sets the main menu of the receiver.  This is sent update messages by the
+ * main event loop.
  */ 
 - (void) setMainMenu: (NSMenu*)aMenu
 {
@@ -2304,6 +2585,9 @@ image.
     }
 }
 
+/*
+   Overrides to show transient version of main menu as in NeXTstep.
+*/
 - (void) rightMouseDown: (NSEvent*)theEvent
 {
   // On right mouse down display the main menu transient
@@ -2315,6 +2599,9 @@ image.
     [super rightMouseDown: theEvent];
 }
 
+/**
+ *  Here for compatibility with OS X, but currently a no-op.
+ */
 - (void) setAppleMenu: (NSMenu*)aMenu
 {
     //TODO: Unclear, what this should do.
@@ -2323,6 +2610,11 @@ image.
 /*
  * Managing the Windows menu
  */
+
+/**
+ * Adds an item to the app's Windows menu.  This is usually done automatically
+ * so you don't need to call this method.
+ */
 - (void) addWindowsItem: (NSWindow*)aWindow
 		  title: (NSString*)aString
 	       filename: (BOOL)isFilename
@@ -2330,6 +2622,10 @@ image.
   [self changeWindowsItem: aWindow  title: aString  filename: isFilename];
 }
 
+/**
+ * Removes an item from the app's Windows menu.  This is usually done
+ * automatically so you don't need to call this method.
+ */
 - (void) removeWindowsItem: (NSWindow*)aWindow
 {
   if (_windows_menu)
@@ -2352,6 +2648,8 @@ image.
     }
 }
 
+// this is an internal helper method for changeWindowsItem:title:filename
+// when window represents an editable document
 - (void) setImageForWindowsItem: (NSMenuItem *)item
 {
   NSImage *oldImage = [item image];
@@ -2501,6 +2799,10 @@ image.
   [self setImageForWindowsItem: item];
 }
 
+/**
+ * Update Windows menu item for aWindow, to reflect its edited status.  This
+ * is usually done automatically so you don't need to call this.
+ */
 - (void) updateWindowsItem: (NSWindow*)aWindow
 {
   NSMenu *menu;
@@ -2601,6 +2903,10 @@ image.
   }
 }
 
+/**
+ * Returns current Windows menu for the application (whose window contents are
+ * managed automatically by this class and NSWindow).
+ */
 - (NSMenu*) windowsMenu
 {
   return _windows_menu;
@@ -2611,7 +2917,11 @@ image.
  */
 
 /**
- * Accepts an array of sendTypes and an array of returnTypes.   
+ * Registers the types this application can send and receive over Services.
+ * sendTypes represents the pasteboard types this app can receive in Service
+ * invocation.  This is used to set up the services menu of this app -- an
+ * item is added for each registered service that can accept one of sendTypes
+ * or return one of returnTypes
  */
 - (void) registerServicesMenuSendTypes: (NSArray *)sendTypes
 			   returnTypes: (NSArray *)returnTypes
@@ -2620,25 +2930,26 @@ image.
 		  returnTypes: returnTypes];
 }
 
-/**
- * Return the services menu of the receiver.
+/** <p>Returns the services menu of the receiver.</p>
+    <p>See Also: -setServicesMenu:</p>
  */
 - (NSMenu *) servicesMenu
 {
   return [_listener servicesMenu];
 }
 
-/**
- * Returns the services provided previously registered using the
- * -setServicesProvider: method.
+/**<p> Returns the services provided previously registered using the
+ * -setServicesProvider: method.</p><p>See Also: -setServicesProvider:</p>
  */
 - (id) servicesProvider
 {
   return [_listener servicesProvider];
 }
 
-/**
- * Sets the services menu for the receiver.
+/**<p>ets the services menu for the receiver.  This should be called, otherwise
+ * warnings will be generated by the main event loop, which is in charge of
+ * updating all menus, including the Services menu.</p>
+ * <p>See Also: -servicesMenu</p>
  */
 - (void) setServicesMenu: (NSMenu *)aMenu
 {
@@ -2656,23 +2967,36 @@ image.
   [_listener setServicesProvider: anObject];
 }
 
+/**
+ * Return an object capable of sending and receiving the specified sendType
+ * and returnType in a services interaction.  NSApp is generally the last
+ * responder to get this request, and the implementation passes it on to the
+ * delegate if it handles it and is not itself an [NSResponder], or returns
+ * nil otherwise.
+ */
 - (id) validRequestorForSendType: (NSString *)sendType
 		      returnType: (NSString *)returnType
 {
   if (_delegate != nil && ![_delegate isKindOfClass: [NSResponder class]]
     && [_delegate respondsToSelector:
-    @selector(validRequestorForSendType:returnType:)])
+                    @selector(validRequestorForSendType:returnType:)])
     return [_delegate validRequestorForSendType: sendType
 				     returnType: returnType];
 
   return nil;
 }
 
+/**
+ *  Returns the default drawing context for the app.
+ */
 - (NSGraphicsContext *) context
 {
   return _default_context;
 }
 
+/**
+ *  NSLogs an exception without raising it.
+ */
 - (void) reportException: (NSException *)anException
 {
   if (anException)
@@ -2680,7 +3004,10 @@ image.
 }
 
 /**
- * Terminates the application.
+ * Requests the application terminates the application.  First an
+ * -applicationShouldTerminate: message is sent to the delegate, and only if
+ * it returns YES (or <code>NSTerminateNow</code>) will termination be
+ * carried out.
  */
 - (void) terminate: (id)sender
 {
@@ -2692,19 +3019,28 @@ image.
     }
   else
     {
-      shouldTerminate = [[NSDocumentController sharedDocumentController] 
-			  reviewUnsavedDocumentsWithAlertTitle: _(@"Quit")
-			   cancellable:YES];
+      if ([NSDocumentController isDocumentBasedApplication])
+	{
+	  shouldTerminate = [[NSDocumentController sharedDocumentController] 
+				reviewUnsavedDocumentsWithAlertTitle: _(@"Quit")
+				cancellable:YES];
+	}
     }
 
   if (shouldTerminate == NSTerminateNow)
     {
       [self replyToApplicationShouldTerminate: YES];
     }
+  /*
+     Don't need to do anything on NSTerminateLater, as long as user code
+     follows the contract (to call replyTo... later).
+  */
 }
 
 /**
- * Perform the actual application termination.
+ * Terminates the app if shouldTerminate is YES, otherwise does nothing.
+ * This should be called by user code if a delegate has returned
+ * <code>NSTerminateLater</code> to an -applicationShouldTerminate: message.
  */
 - (void) replyToApplicationShouldTerminate: (BOOL)shouldTerminate
 {
@@ -2718,6 +3054,7 @@ image.
       _app_is_running = NO;
 
       [[self windows] makeObjectsPerformSelector: @selector(close)];
+      [NSCursor setHiddenUntilMouseMoves: NO];
       
       /* Store our user information.  */
       [[NSUserDefaults standardUserDefaults] synchronize];
@@ -2751,7 +3088,7 @@ image.
 }
 
 /**
- * Returns the applications delegate, as set by the -setDelegate: method.<br />
+ * Returns the application's delegate, as set by the -setDelegate: method.<br/>
  * <p>The application delegate will automatically be sent various
  * notifications (as long as it implements the appropriate methods)
  * when application events occur.  The method to handle each of these
@@ -2779,19 +3116,26 @@ image.
  * as it implements the appropriate methods).
  * </p>
  * <list>
- *   <item>applicationShouldTerminateAfterLastWindowClosed:</item>
- *   <item>applicationShouldOpenUntitledFile:</item>
- *   <item>applicationOpenUntitledFile:</item>
- *   <item>applicationShouldTerminate:</item>
+ *   <item>application:shouldTerminateAfterLastWindowClosed:</item>
+ *   <item>application:shouldOpenUntitledFile:</item>
+ *   <item>application:openFile:</item>
+ *   <item>application:openFileWithoutUI:</item>
+ *   <item>application:openTempFile:</item>
+ *   <item>application:openUntitledFile:</item>
+ *   <item>application:shouldOpenUntitledFile:</item>
+ *   <item>application:printFile:</item>
+ *   <item>application:shouldTerminate:</item>
+ *   <item>application:shouldTerminateAfterLastWindowClosed:</item>
  * </list>
  * <p>The delegate is also called upon to respond to any actions which
  *   are not handled by a window, a window delgate, or by the application
- *   object itsself..  This is controlled by the -targetForAction: method. 
+ *   object itself.  This is controlled by the -targetForAction: method. 
  * </p>
  * <p>Finally, the application delegate is responsible for handling
  *   messages sent to the application from remote processes (see the
  *   section documenting distributed objects for [NSPasteboard]).
  * </p>
+ * <p>See -setDelegate: and [(GSAppDelegateProtocol)] for more information.</p>
  */
 - (id) delegate
 {
@@ -2805,6 +3149,7 @@ image.
  * stop it being the application delagate by calling this
  * method again with another object (or nil) as the argument.
  * </p>
+ * <p>See -delegate and [(GSAppDelegateProtocol)] for more information.</p>
  */
 - (void) setDelegate: (id)anObject
 {
@@ -2836,12 +3181,22 @@ image.
 /*
  * Methods for scripting
  */
+
+/**
+ * OS X scripting method to return document objects being handled by
+ * application.  <em>Not implemented yet under GNUstep.</em>
+ */
 - (NSArray *) orderedDocuments
 {
   // FIXME
   return nil;
 }
 
+/**
+ * OS X scripting method to return windows in front-to-back on-screen order.
+ * <em>The GNUstep implementation returns all the windows in an arbitrary
+ * order.</em>
+ */
 - (NSArray *) orderedWindows
 {
   // FIXME
@@ -2851,11 +3206,22 @@ image.
 /*
  * Methods for user attention requests
  */
+
+/**
+ * Cancels a request previously made through calling -requestUserAttention: .
+ * Note that request is cancelled automatically if user activates the app.
+ */
 - (void) cancelUserAttentionRequest: (int)request
 {
   // FIXME
 }
 
+/**
+ * Method that on OS X makes the icon jump in the doc.  Mercifully, this is
+ * unimplemented under GNUstep.  If it <em>were</em> implemented, requestType
+ * could be either <code>NSCriticalRequest</code> (bounce endlessly) or
+ * <code>NSInformationalRequest</code> (bounce for one second).
+ */
 - (int) requestUserAttention: (NSRequestUserAttentionType)requestType
 {
   // FIXME
