@@ -22,7 +22,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
    */ 
 
 #include "NSBitmapImageRep+PNM.h"
@@ -56,7 +56,7 @@
   do									\
     {									\
       char *p = buffer;							\
-      while ( *ptr != '\n' && *ptr != '\r' && (ptr-bytes) < length)	\
+      while (*ptr != '\n' && *ptr != '\r' && (ptr-bytes) < length)	\
 	{								\
 	  *p++ = *ptr++;						\
 	  if (p == &buffer[sizeof(buffer)])				\
@@ -117,7 +117,7 @@
 	       bytesPerRow: 0
 	       bitsPerPixel: 0];
 
-  if ([self bytesPerRow] * ysize > (length - (ptr - bytes)) )
+  if ([self bytesPerRow] * ysize > (length - (ptr - bytes)))
     ERRMSG(@"Invalid PNM file (short data)");
   pchar = [self bitmapData];
   if (levels < 256)
