@@ -22,7 +22,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "config.h"
@@ -162,9 +162,10 @@ static BOOL supports_lzw_compression = NO;
   return types;
 }
 
-/** Returns a newly allocated NSBitmapImageRep object representing the
-    image stored in imageData.  If the image data contains more than one
-    image, the first one is choosen.  */
+/** <p>Returns a newly allocated NSBitmapImageRep object representing the
+    image stored in imageData. If the image data contains more than one
+    image, the first one is choosen.</p><p>See Also: +imageRepWithData:</p>  
+*/
 + (id) imageRepWithData: (NSData *)imageData
 {
   NSArray* array;
@@ -177,8 +178,10 @@ static BOOL supports_lzw_compression = NO;
   return nil;
 }
 
-/** Returns an array containing newly allocated NSBitmapImageRep
-    objects representing the images stored in imageData.  */
+/**<p>Returns an array containing newly allocated NSBitmapImageRep
+    objects representing the images stored in imageData.</p>
+    <p>See Also: +imageRepWithData:</p>
+*/
 + (NSArray*) imageRepsWithData: (NSData *)imageData
 {
   int		 i, images;
