@@ -1,6 +1,7 @@
 /** <title>NSBox</title>
 
-   <abstract>Simple box view that can display a border and title</abstract>
+   <abstract>Simple box view that can display a border and title
+   </abstract>
 
    Copyright (C) 1996 Free Software Foundation, Inc.
 
@@ -22,7 +23,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
@@ -45,6 +46,8 @@
 - (NSRect) calcSizesAllowingNegative: (BOOL)aFlag;
 @end
 
+/**<p> TODO : Description</p>
+*/
 @implementation NSBox
 
 //
@@ -91,19 +94,29 @@
   [super dealloc];
 }
 
-//
-// Getting and Modifying the Border and Title 
-//
+/**<p>Returns the border rectangle of the box.</p>
+ */
 - (NSRect) borderRect
 {
   return _border_rect;
 }
 
+/**<p>Returns the NSBox's border type. See <ref type="type" id="NSBorderType"> 
+   NSBorderType</ref>  for more information. The default border type is
+   <ref type="type" id="NSBorderType">NSGrooveBorder</ref>.</p>
+   <p>See Also: -setBorderType:</p>
+ */
 - (NSBorderType) borderType
 {
   return _border_type;
 }
 
+/**<p>Sets the border type to <var>aType</var>, resizes the content view frame
+   if needed, and marks self for display. See <ref type="type" 
+   id="NSBorderType">NSBorderType</ref> for more informations The default
+   boder type is <ref type="type" id="NSBorderType">NSGrooveBorder</ref>.</p>
+   <p>See Also: -borderType</p>
+ */
 - (void) setBorderType: (NSBorderType)aType
 {
   if (_border_type != aType)
@@ -114,9 +127,14 @@
     }
 }
 
-// TODO: implement the macosx behaviour for setTitle:
+/**<p>Sets the title cell to <var>aString</var>, resizes the content
+   view frame if needed and marks self for display.</p>
+   <p>Warning: This method does not implement the Cocoa behaviour</p>
+   <p>See Also: -title [NSCell-setStringValue:]</p>
+ */ 
 - (void) setTitle: (NSString *)aString
 {
+  // TODO: implement the macosx behaviour for setTitle:
   [_cell setStringValue: aString];
   [_content_view setFrame: [self calcSizesAllowingNegative: NO]];
   [self setNeedsDisplay: YES];
@@ -129,6 +147,10 @@
   [self setNeedsDisplay: YES];
 }
 
+/**<p>Sets the title cell font to <var>fontObj</var>, resizes 
+ * the content view frame if needed and marks self for display.</p>
+ *<p>See Also: -titleFont [NSCell-setFont:]</p>
+ */
 - (void) setTitleFont: (NSFont *)fontObj
 {
   [_cell setFont: fontObj];
@@ -136,6 +158,13 @@
   [self setNeedsDisplay: YES];
 }
 
+/**<p>Sets the title cell position to <var>aPosition</var>, resizes the
+   content view frame if needed and marks self for display.
+   See <ref type="type" id="NSTitlePosition">NSTitlePosition</ref> for more
+   information. The default position is <ref type="type" id="NSTitlePosition">
+   NSAtTop</ref>.</p>
+   <p>See Also: -titlePosition</p>
+ */
 - (void) setTitlePosition: (NSTitlePosition)aPosition
 {
   if (_title_position != aPosition)
@@ -146,44 +175,71 @@
     }
 }
 
+/**<p>Returns title cell string value.</p>
+ *<p>See Also: -setTitle: [NSCell-stringValue]</p>
+ */
 - (NSString*) title
 {
   return [_cell stringValue];
 }
 
+/**<p>Returns the title cell</p>
+ */
 - (id) titleCell
 {
   return _cell;
 }
 
+/**<p>Returns the title cell font.</p>
+ *<p>See Also: -setTitleFont: [NSCell-font]</p>
+ */
 - (NSFont*) titleFont
 {
   return [_cell font];
 }
 
+/**<p>Returns the title position. See <ref type="type" id="NSTitlePosition">
+   NSTitlePosition</ref> for more information. The default position is 
+   <ref type="type" id="NSTitlePosition">NSAtTop</ref></p>
+   <p>See Also: -setTitlePosition:</p>
+ */
 - (NSTitlePosition) titlePosition
 {
   return _title_position;
 }
 
+/**<p>Returns the title rectangle</p>
+ */
 - (NSRect) titleRect
 {
   return _title_rect;
 }
 
-//
-// Setting and Placing the Content View 
-//
+/**<p>Returns the NSBox's content view. The content view is created as NSView
+   when the box is initialized. The contentView is resizes when needed.</p>
+   <p>See Also: -setContentView:</p>
+ */
 - (id) contentView
 {
   return _content_view;
 }
 
+/**<p>Returns an NSSize containing the interior margins of the receiver. 
+  An NSBox's content view margins are empty space that is subtracted 
+  from the top, bottom, and sides as padding between the inside of the box
+  and the frame of its content view.</p>
+  <p>See Also: -setContentViewMargins:</p>
+ */
 - (NSSize) contentViewMargins
 {
   return _offsets;
 }
 
+/**<p>Sets the content view to aView. The current content view is replaced
+   by -replaceSubview:with:. So you should -retain the current
+   view if you want to use it later. The contentView frame is resized if 
+   needed.</p><p>See Also: -contentView</p>
+ */
 - (void) setContentView: (NSView*)aView
 {
   if (aView)
@@ -194,6 +250,12 @@
     }
 }
 
+/**<p>Sets the NSSize containing the interior margins to offsetSize. 
+  An NSBox's content view margins are empty space that is subtracted 
+  from the top, bottom, and sides as padding between the inside of the box
+  and the frame of its content view</p>
+  <p> See Also: -contentViewMargins</p>
+ */
 - (void) setContentViewMargins: (NSSize)offsetSize
 {
   NSAssert(offsetSize.width >= 0 && offsetSize.height >= 0,
@@ -213,11 +275,16 @@
   [super setFrame: frameRect];
   [_content_view setFrame: [self calcSizesAllowingNegative: NO]];
 }
+
 - (void) setFrameSize: (NSSize)newSize
 {
   [super setFrameSize: newSize];
   [_content_view setFrame: [self calcSizesAllowingNegative: NO]];
 }
+
+/**<p>Resizes the NSBox to fit the content view frame 
+   <var>contentFrame</var>.</p>
+ */
 - (void) setFrameFromContentFrame: (NSRect)contentFrame
 {
   // First calc the sizes to see how much we are off by
@@ -228,7 +295,7 @@
 	@"illegal content frame supplied");
 
   if (_super_view)
-    r = [_super_view convertRect: r fromView: self];
+    r = [_super_view convertRect:r fromView: self];
   
   // Add the difference to the frame
   f.size.width = f.size.width + (contentFrame.size.width - r.size.width);
@@ -242,38 +309,46 @@
 
 -(NSSize) minimumSize
 {
-  NSRect r;
+  NSRect rect;
   NSSize borderSize = _sizeForBorderType (_border_type);
 
   if ([_content_view respondsToSelector: @selector(minimumSize)])
     {
-      r.size = [_content_view minimumSize];
+      rect.size = [_content_view minimumSize];
     }
   else
     {   
       NSArray *subviewArray = [_content_view subviews];
+
       if ([subviewArray count])
 	{
-	  id o, e = [subviewArray objectEnumerator];
-	  r = [[e nextObject] frame];
-	  // Loop through subviews and calculate rect to encompass all
-	  while ((o = [e nextObject]))
+	  id subview;
+	  NSEnumerator *enumerator;
+	  enumerator = [subviewArray objectEnumerator];
+	  
+	  rect = [[enumerator nextObject] frame];
+	  
+	  // Loop through subviews and calculate rect
+	  // to encompass all
+	  while ((subview = [enumerator nextObject]))
 	    {
-	      r = NSUnionRect(r, [o frame]);
+	      rect = NSUnionRect(rect, [subview frame]);
 	    }
 	}
       else // _content_view has no subviews
 	{
-	  r = NSZeroRect;
+	  rect = NSZeroRect;
 	}
     }
 
-  r.size = [self convertSize: r.size fromView: _content_view];
-  r.size.width += (2 * _offsets.width) + (2 * borderSize.width);
-  r.size.height += (2 * _offsets.height) + (2 * borderSize.height);
-  return r.size;
+  rect.size = [self convertSize: rect.size fromView:_content_view];
+  rect.size.width += (2 * _offsets.width) + (2 * borderSize.width);
+  rect.size.height += (2 * _offsets.height) + (2 * borderSize.height);
+  return rect.size;
 }
 
+/**<p>Resizes the NSBox and its content view to fit its subviews.</p>
+ */
 - (void) sizeToFit
 {
   NSRect f;
