@@ -24,7 +24,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library;
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
@@ -271,12 +271,12 @@ Class gmodel_class(void)
       NSFileManager	*mgr = [NSFileManager defaultManager];
       BOOL              isDir = NO;
 
-      if([mgr fileExistsAtPath: fileName isDirectory: &isDir])
+      if ([mgr fileExistsAtPath: fileName isDirectory: &isDir])
 	{
 	  NSData	*data = nil;
 	  
 	  // if the data is in a directory, then load from objects.gorm in the directory
-	  if(isDir == NO)
+	  if (isDir == NO)
 	    {
 	      data = [NSData dataWithContentsOfFile: fileName];
 	      NSDebugLog(@"Loaded data from file...");
@@ -420,7 +420,7 @@ Class gmodel_class(void)
       else
 	{
 	  path = [rootPath stringByAppendingPathExtension: ext];
-	  if([mgr isReadableFileAtPath: path])
+	  if ([mgr isReadableFileAtPath: path])
 	    {
 	      return path;
 	    }
