@@ -22,7 +22,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
    */ 
 /*
     Keeps a representation of an image in an off-screen window.  If the
@@ -63,9 +63,15 @@
 }
 @end
 
+/**<p>Todo Description </p>
+ */
 @implementation NSCachedImageRep
 
-// Initializing an NSCachedImageRep 
+/** <p>Initializes and returns a new NSCachedImageRep with size 
+    and depth specified by <var>aSize</var> and <var>aDepth</var> respectively.
+    If seperate is YES,  the image will gets its own unique cache without 
+    sharing it with other images. </p>
+ */
 - (id) initWithSize: (NSSize)aSize
 	      depth: (NSWindowDepth)aDepth
 	   separate: (BOOL)separate
@@ -85,9 +91,15 @@
   RELEASE(win);
   [self setAlpha: alpha];
   [self setBitsPerSample: NSBitsPerSampleFromDepth(aDepth)];
+
   return self;
 }
 
+/** <p>Initializes and returns a new NSCachedImageRep into a NSWindow 
+    <var>aWindow</var>. The image will be draw into the rectange aRect of
+    this window. aWindow is retained.</p>
+    <p>See Also: -rect -window</p>
+ */
 - (id) initWithWindow: (NSWindow *)aWindow rect: (NSRect)aRect
 {
   [super init];
@@ -128,12 +140,17 @@
   [super dealloc];
 }
 
-// Getting the Representation 
+/** <p>Returns the rectangle where the image is cached.</p>
+    <p>See Also: -initWithWindow:rect:</p>
+ */
 - (NSRect) rect
 {
   return _rect;
 }
 
+/** <p>Returns the NSWindow where the image is cached.</p>
+    <p>See Also: -initWithWindow:rect:</p>
+ */
 - (NSWindow *) window
 {
   return _window;
