@@ -28,7 +28,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "config.h"
@@ -86,6 +86,10 @@ static NSColor	*shadowCol;
 @end
 
 
+/**
+ *<p> TODO Desctiption</p>
+ */
+
 @implementation NSCell
 
 /*
@@ -118,6 +122,9 @@ static NSColor	*shadowCol;
   return nil;
 }
 
+/**<p>This class method returns NO. This method should be overrided by 
+   subclasses.</p>
+ */
 + (BOOL) prefersTrackingUntilMouseUp
 {
   return NO;
@@ -131,6 +138,12 @@ static NSColor	*shadowCol;
   return [self initTextCell: @""];
 }
 
+/**<p>Initializes and returns a new NSCell with a NSImage <var>anImage</var>. 
+   This method sets the image position to <ref type="type" 
+   id="NSCellImagePosition">NSImageOnly</ref> and the cell's type to
+   <ref type="type" id="NSCellType">NSImageCellType</ref>.</p>
+   <p>See Also: -initTextCell: </p>
+ */
 - (id) initImageCell: (NSImage*)anImage
 {
   _cell.type = NSImageCellType;
@@ -160,7 +173,11 @@ static NSColor	*shadowCol;
 
   return self;
 }
-
+/**<p>Initializes and returns a new NSCell with a NSString aString. 
+   This method sets the cell's type to <ref type="type" id="NSCellType">
+   NSTextCellType</ref>.</p>
+   <p>See Also: -initImageCell: </p>
+ */
 - (id) initTextCell: (NSString*)aString
 {
   _cell.type = NSTextCellType;
@@ -219,6 +236,9 @@ static NSColor	*shadowCol;
   return _cell.has_valid_object_value;
 }
 
+/**<p>Returns the NSCell's value as a double. </p>
+ *<p>See Also: -setDoubleValue: </p>
+ */
 - (double) doubleValue
 {
   if ((_cell.has_valid_object_value == YES) &&
@@ -232,6 +252,9 @@ static NSColor	*shadowCol;
     }
 }
 
+/**<p>Returns the cell's value as a float. </p>
+ *<p>See Also: -setFloatValue: </p>
+ */
 - (float) floatValue
 {
   if ((_cell.has_valid_object_value == YES) &&
@@ -245,6 +268,9 @@ static NSColor	*shadowCol;
     }
 }
 
+/**<p>Returns the cell's value as an int. </p>
+ *<p>See Also: -setIntValue:</p>
+ */
 - (int) intValue
 {
   if ((_cell.has_valid_object_value == YES) &&
@@ -258,6 +284,9 @@ static NSColor	*shadowCol;
     }
 }
 
+/**<p>Returns the cell's value as a NSString.</p>
+ *<p>See Also: -setStringValue: </p>
+ */
 - (NSString*) stringValue
 {
   if (_cell.contents_is_attributed_string == NO)
@@ -277,30 +306,48 @@ static NSColor	*shadowCol;
   
   ASSIGN (_objectValue, object);
   
-  newContents = [_formatter stringForObjectValue: _objectValue];
-  if (newContents != nil)
+  if (_formatter == nil) 
     {
-      _cell.has_valid_object_value = YES;
-    }
-  else
-    {
-      if ((_formatter == nil) 
-	  && ([object isKindOfClass: [NSString class]] == YES))
+      if ([object isKindOfClass: [NSString class]] == YES)
 	{
-	  newContents = _objectValue;
+	  newContents = object;
+	  _cell.contents_is_attributed_string = NO;
 	  _cell.has_valid_object_value = YES;
 	}
+      if ([object isKindOfClass: [NSAttributedString class]] == YES)
+        {
+          newContents = object;
+          _cell.contents_is_attributed_string = YES;
+	  _cell.has_valid_object_value = YES;
+        }
       else
 	{
 	  newContents = [_objectValue description];
+	  _cell.contents_is_attributed_string = NO;
+	  _cell.has_valid_object_value = YES;
+	}
+  }
+  else
+    {
+      newContents = [_formatter stringForObjectValue: _objectValue];
+      _cell.contents_is_attributed_string = NO;
+      if (newContents != nil)
+        {
+	  _cell.has_valid_object_value = YES;
+	}
+      else
+        {
 	  _cell.has_valid_object_value = NO;
 	}
     }
-  
+
   ASSIGN (_contents, newContents);
-  _cell.contents_is_attributed_string = NO;
 }
 
+
+/**<p>Sets the NSCell's value to aDouble.</p>
+ *<p>See Also: -doubleValue</p> 
+ */
 - (void) setDoubleValue: (double)aDouble
 {
   NSNumber *number;
@@ -311,6 +358,11 @@ static NSColor	*shadowCol;
   [self setObjectValue: number];
 }
 
+/**
+ *<p>Sets the NSCell's value to a aFloat. This used for example in 
+ NSSliderCell</p>
+ *<p>See Also: -floatValue</p> 
+ */
 - (void) setFloatValue: (float)aFloat
 {
   NSNumber *number;
@@ -322,6 +374,11 @@ static NSColor	*shadowCol;
   [self setObjectValue: number];
 }
 
+
+/**
+ *<p>Sets the NSCell's value to anInt.</p>
+ *<p>See Also: -intValue</p> 
+ */
 - (void) setIntValue: (int)anInt
 {
   NSNumber *number;
@@ -332,6 +389,10 @@ static NSColor	*shadowCol;
   [self setObjectValue: number];
 }
 
+/**<p>Sets the cell's value to a NSString. 
+   The NSCell's type is set to NSTextCellType if needed</p>
+   <p>See Also: -stringValue</p> 
+ */
 - (void) setStringValue: (NSString*)aString
 {
   NSString *string = aString;
@@ -353,7 +414,8 @@ static NSColor	*shadowCol;
   if (_formatter == nil)
     {
       ASSIGN (_contents, string);
-      _cell.has_valid_object_value = NO;
+      ASSIGN (_objectValue, string);
+      _cell.has_valid_object_value = YES;
     }
   else
     {
@@ -361,7 +423,7 @@ static NSColor	*shadowCol;
       
       if ([_formatter getObjectValue: &newObjectValue 
 		      forString: string 
-		      errorDescription: NULL] == YES)
+		      errorDescription: NULL])
 	{
 	  [self setObjectValue: newObjectValue];
 	}
@@ -373,8 +435,9 @@ static NSColor	*shadowCol;
     }
 }
 
-/*
- * Setting Parameters
+/**<p>Returns some NSCell's attributes for the specified <ref type="type"
+   id="NSCellAttribute">NSCellAttribute</ref></p>
+   <p>See Also: -setCellAttribute:to:</p>
  */
 - (int) cellAttribute: (NSCellAttribute)aParameter
 {
@@ -421,6 +484,10 @@ static NSColor	*shadowCol;
   return 0;
 }
 
+
+/**<p>TODO</p>
+ *<p>See Also: -cellAttribute:</p>
+ */
 - (void) setCellAttribute: (NSCellAttribute)aParameter  to: (int)value
 {
   switch (aParameter)
@@ -535,9 +602,11 @@ static NSColor	*shadowCol;
     }
 }
 
-/*
- * Setting the NSCell's Type
- */
+/**<p>Sets the NSCell's type. See <ref type="type" id="NSCellType">NSCellType
+   </ref>.If the cell is set to NSTextCellType, the cell is given
+   a default title and is reset to the default system font.</p>
+   <p>See Also: -type</p>
+*/
 - (void) setType: (NSCellType)aType
 {
   if (_cell.type == aType)
@@ -565,6 +634,11 @@ static NSColor	*shadowCol;
     }
 }
 
+/**<p>Returns the cell's type. Returns NSNullCellType if the
+  cell's type flag is set to NSImageCellType and if the cell's image 
+  is nil. See <ref type="type" id="NSCellType">NSCellType</ref> for more 
+  information.</p><p>See Also -setType:</p>
+ */
 - (NSCellType) type
 {
   if (_cell.type == NSImageCellType && _cell_image == nil)
@@ -573,37 +647,51 @@ static NSColor	*shadowCol;
   return _cell.type;
 }
 
-/*
- * Enabling and Disabling the NSCell
+
+/**<p>Returns whether the NSCell can respond to mouse events.</p>
+ *<p>See Also: -setEnabled:</p>
  */
 - (BOOL) isEnabled
 {
   return !_cell.is_disabled;
 }
 
+/**<p>Sets whether the NSCell can respond to mouse events</p>
+ <p>See Also: -isEnabled</p>
+ */
 - (void) setEnabled: (BOOL)flag
 {
   _cell.is_disabled = !flag;  
 }
 
-/*
- * Modifying Graphic Attributes
+/**<p>Returns whether the NSCell has a bezeled border. By default a NSCell
+   has no bezeled border</p><p>See Also: -setBezeled:</p>
  */
 - (BOOL) isBezeled
 {
   return _cell.is_bezeled;
 }
 
+/**<p>Returns whether the NSCell has a border. By default a NSCell has 
+   border</p><p>See Also: -setBordered: -setBezeled: -isBezeled</p>
+ */
 - (BOOL) isBordered
 {
   return _cell.is_bordered;
 }
 
+/**<p>Returns whether the cell is opaque. Return NO by default</p>
+ */
 - (BOOL) isOpaque
 {
   return NO;
 }
 
+/**<p>Sets whether the cell has a bezeled border. 
+ If the cell has a bezeled border, the bordered  flag is turn off.
+ By default a NSCell has no bezeled border</p>
+ <p>See Also: -isBezeled -setBordered: -isBordered</p>
+ */
 - (void) setBezeled: (BOOL)flag
 {
   _cell.is_bezeled = flag;
@@ -613,6 +701,10 @@ static NSColor	*shadowCol;
     }
 }
 
+/**<p>Sets whether the cell has a border.  If the cell has a border, 
+ the bezeled flag is turn off. By default a NSCell has no border</p>
+ <p>See Also: -isBordered -setBezeled: -isBezeled</p>
+ */
 - (void) setBordered: (BOOL)flag
 {
   _cell.is_bordered = flag;
@@ -622,9 +714,10 @@ static NSColor	*shadowCol;
     }
 }
 
-
-/*
- * Setting the NSCell's State
+/**<p>Sets the NSCell's state.  Please use always symbolic constants when
+   calling this method. The integer values could be changed in the this
+   implementation. (Currently they match the Cocoa values but they are
+   quite strange)</p> <p>See Also: -state</p>
  */
 - (void) setState: (int)value
 {
@@ -648,6 +741,9 @@ static NSColor	*shadowCol;
     }
 }
 
+/**<p>Returns the NSCell's state</p>
+ <p>See Also: -setState: </p>
+*/
 - (int) state
 {
   return _cell.state;
@@ -699,40 +795,62 @@ static NSColor	*shadowCol;
   [self setState: [self nextState]];
 }
 
-/*
- * Modifying Text Attributes
+/**<p>Returns the alignment of the text used in the NSCell. See 
+   <ref type="type" id="NSTextAlignment">NSTextAlignment</ref> for more
+   informations. By default the text alignment is <ref type="type" 
+   id="NSTextAlignment">NSJustifiedTextAlignment</ref></p>
+   <p>See Also: -setAlignment:</p>
  */
 - (NSTextAlignment) alignment
 {
   return _cell.text_align;
 }
 
+/** <p>Returns the font of the text used in the NSCell</p>
+    <p>See Also: -setFont:</p>
+ */
 - (NSFont*) font
 {
   return _font;
 }
 
+/**<p>Returns whether the cell is editable.By default a NSCell is not editable.
+   </p><p>See Also: -setEditable:</p>
+ */
 - (BOOL) isEditable
 {
   return _cell.is_editable;
 }
 
+/**<p>Returns whether the cell is selectable. This method returns YES if 
+   the cell is selectable or editable. NO otherwise</p>
+   <p>See Also: -setSelectable: -isEditable -setEditable: </p>
+ */
 - (BOOL) isSelectable
 {
   return _cell.is_selectable || _cell.is_editable;
 }
 
+/**<p>Returns whether the NSCell is scrollable. By default a NSCell is not
+   scrollable</p><p>See Also: -setScrollable:</p>
+ */
 - (BOOL) isScrollable
 {
   return _cell.is_scrollable;
 }
 
+/**<p>Sets the alignment of the text. See <ref type="type" 
+   id="NSTextAlignment">NSTextAlignment</ref>.</p><p>See Also: -alignment </p>
+ */
 - (void) setAlignment: (NSTextAlignment)mode
 {
   // This does not have any influence on attributed strings
   _cell.text_align = mode;
 }
 
+/**<p>Sets whether the NSCell's text is editable.</p>
+   <p>See Also: -isEditable -setSelectable: -isSelectable</p>
+*/
 - (void) setEditable: (BOOL)flag
 {
   /*
@@ -743,6 +861,9 @@ static NSColor	*shadowCol;
   _cell.is_editable = flag;
 }
 
+/**<p>Sets the text font. The NSCell's type is set to NSTextCellType if needed
+   </p><p>See Also: -font -setType: -type</p>
+ */
 - (void) setFont: (NSFont*)fontObject
 {
   if (_cell.type != NSTextCellType)
@@ -754,18 +875,21 @@ static NSColor	*shadowCol;
   ASSIGN (_font, fontObject);
 }
 
+/**<p>Sets whether the cell selectable. Making a cell unselectable also
+ * makes it uneditable until a -setEditable: re-enables it.</p>
+ *<p>See Also: -isSelectable -setEditable: -isEditable</p>
+ */
 - (void) setSelectable: (BOOL)flag
 {
   _cell.is_selectable = flag;
 
-  /*
-   *	Making a cell unselectable also makes it uneditable until a
-   *	setEditable re-enables it.
-   */
   if (!flag)
     _cell.is_editable = NO;
 }
 
+/**<p>Sets whether the NCell is scrollable. By default a NSCell is not
+   scrollable</p><p>See Also: -isSelectable</p>
+ */
 - (void) setScrollable: (BOOL)flag
 {
   _cell.is_scrollable = flag;
@@ -904,37 +1028,56 @@ static NSColor	*shadowCol;
   [self setStringValue: aString];
 }
 
-/*
- * Target and Action
+/**<p>Implemented by subclasses to return the action method.
+   The NSCell implementaiton returns NULL.</p>
+ <p>See Also: -setAction: -setTarget: -target</p>
  */
 - (SEL) action
 {
   return NULL;
 }
 
+/** <p>Implemented by subclasses to set the action method. 
+    The NSCell implementation raises a NSInternalInconsistencyException</p>
+ <p>See Also: -action -setTarget: -target</p>
+*/
 - (void) setAction: (SEL)aSelector
 {
   [NSException raise: NSInternalInconsistencyException
 	      format: @"attempt to set an action in an NSCell"];
 }
 
+/**<p>Implemented by subclasses to set the target object.
+   The NSCell implementation raises a NSInternalInconsistencyException</p>
+   <p>See Also: -target -setAction: -action</p>
+ */
 - (void) setTarget: (id)anObject
 {
   [NSException raise: NSInternalInconsistencyException
 	      format: @"attempt to set a target in an NSCell"];
 }
 
+/**<p>Implemented by subclass to return the target object. 
+   The NSCell implementation returns nil</p>
+   <p>See Also: -setTarget: -setAction: -action</p>
+ */
 - (id) target
 {
   return nil;
 }
 
+/**<p>Returns whether the cell can continuously send its action messages.</p>
+   <p>See Also: -setContinuous:</p>
+ */
 - (BOOL) isContinuous
 {
   // Some subclasses should redefine this with NSLeftMouseDraggedMask
   return (_action_mask & NSPeriodicMask) != 0;
 }
 
+/**<p>Sets whether the cell can continuously send its action messages.</p>
+ *<p>See Also: -isContinuous</p>
+ */
 - (void) setContinuous: (BOOL)flag
 {
   // Some subclasses should redefine this with NSLeftMouseDraggedMask
@@ -948,6 +1091,8 @@ static NSColor	*shadowCol;
     }
 }
 
+/**<p>TODO Explain</p>
+ */
 - (int) sendActionOn: (int)mask
 {
   unsigned int previousMask = _action_mask;
@@ -957,8 +1102,10 @@ static NSColor	*shadowCol;
   return previousMask;
 }
 
-/*
- * Setting the Image
+/**<p>Returns the NSCell's image if the NSCell's type is <ref type="type" 
+   id="NSCellType">NSImageCellType</ref>,
+   returns nil otherwise.</p>
+   <p>See Also: -setImage: -setType: -type</p>
  */
 - (NSImage*) image
 {
@@ -970,6 +1117,11 @@ static NSColor	*shadowCol;
     return nil;
 }
 
+/**<p>Sets the NSCell's image to anImage. This method sets the cell's type 
+   to NSImageCellType if needed. Raises an NSInvalidArgumentException if
+   the anImage is not an NSImage (sub)class. The new image is retained and the
+   old one is released</p><p>See Also: -image</p>
+ */
 - (void) setImage: (NSImage*)anImage
 {
   if (anImage) 
@@ -986,8 +1138,9 @@ static NSColor	*shadowCol;
   ASSIGN (_cell_image, anImage);
 }
 
-/*
- * Assigning a Tag
+/**<p>Implemented by sublclasses to assigns the tag <var>anInt</var>.
+    The NSCell implementation raises an NSInvalidArgumentException.</p>
+    <p>See Also: -tag</p>
  */
 - (void) setTag: (int)anInt
 {
@@ -995,6 +1148,9 @@ static NSColor	*shadowCol;
 	      format: @"attempt to set a tag in an NSCell"];
 }
 
+/**<p>Implemented by subclasses to Return the tag. 
+   The NSCell implementation returns -1 </p><p>See Also: -setTag:</p>
+ */
 - (int) tag
 {
   return -1;
@@ -1020,11 +1176,15 @@ static NSColor	*shadowCol;
   return _formatter;
 }
 
+/**<p> TODO</p>
+ */
 - (int) entryType
 {
   return _cell.entry_type;
 }
 
+/** <p>TODO</p>
+ */
 - (void) setEntryType: (int)aType
 {
   [self setType: NSTextCellType];
@@ -1169,7 +1329,8 @@ static NSColor	*shadowCol;
 }
 
 /**
- * Simulates a single click in the cell. The display of the cell with this event
+ * Simulates a single click in the cell.
+ * The display of the cell with this event
  * occurs in the area delimited by <var>cellFrame</var> within
  * <var>controlView</var>.
  */
@@ -1177,7 +1338,7 @@ static NSColor	*shadowCol;
 {
   SEL action = [self action];
 
-  if(_cell.is_disabled == YES)
+  if (_cell.is_disabled == YES)
     {
       return;
     }
@@ -1243,42 +1404,59 @@ static NSColor	*shadowCol;
   [self setObjectValue: [sender objectValue]];
 }
 
+/** <p>Sets the NSCell's double value to sender's double value</p>
+    <p>See Also: -setDoubleValue:</p>
+ */
 - (void) takeDoubleValueFrom: (id)sender
 {
   [self setDoubleValue: [sender doubleValue]];
 }
 
+/** <p>Sets the NSCell's float value to sender's float value</p>
+    <p>See Also: -setFloatValue:</p>
+ */
 - (void) takeFloatValueFrom: (id)sender
 {
   [self setFloatValue: [sender floatValue]];
 }
 
+/** <p>Sets the NSCell's int value to sender's int value</p>
+    <p>See Also: -setIntValue:</p>
+ */
 - (void) takeIntValueFrom: (id)sender
 {
   [self setIntValue: [sender intValue]];
 }
 
+/** <p>Sets the NSCell's NSString value to sender's NSSting value</p>
+    <p>See Also: -setStringValue:</p>
+ */
 - (void) takeStringValueFrom: (id)sender
 {
   [self setStringValue: [sender stringValue]];
 }
 
-/*
- * Using the NSCell to Represent an Object
+/** <p>Returns the NSCell's represented object</p>
+    <p>See Also: -setRepresentedObject:</p>
  */
 - (id) representedObject
 {
   return _represented_object;
 }
 
+/** <p>Sets the NSCell's represented object to <var>anObject</var>.
+    anObject will be retain.</p><p>See Also: -representedObject</p>
+ */
 - (void) setRepresentedObject: (id)anObject
 {
   /* Ahm - not nice - the RETAIN here could cause retain cycles - anyway. */
   ASSIGN (_represented_object, anObject);
 }
 
-/*
- * Tracking the Mouse
+/** <p>Returns YES. Subclasses should overrided this method if you want
+    stop tracking the mouse. This method is call in the
+    -trackMouse:inRect:ofView:untilMouseUp: main loop.</p>
+    <p>See Also: -trackMouse:inRect:ofView:untilMouseUp:</p>
  */
 - (BOOL) continueTracking: (NSPoint)lastPoint
 		       at: (NSPoint)currentPoint
@@ -1287,17 +1465,33 @@ static NSColor	*shadowCol;
   return YES;
 }
 
+/**<p>Returns the mouse flags. This flags are usally sets in 
+   the -trackMouse:inRect:ofView:untilMouseUp: method</p>
+ */
 - (int) mouseDownFlags
 { 
   return _mouse_down_flags;
 }
 
+/**<p>Gets the NSCell's <var>delay</var> and the <var>interval</var>
+   parameters used when NSCell sends continouly action messages.
+   The NSCell implementation sets both <var>delay</var> and <var>interval</var>
+   to 0.1.</p>
+   <p>See Also: -trackMouse:inRect:ofView:untilMouseUp:</p>
+ */
 - (void) getPeriodicDelay: (float*)delay interval: (float*)interval
 {
   *delay = 0.1;
   *interval = 0.1;
 }
 
+/**<p>Returns whether tracking starts. The NSCell implementation
+   returns YES when the <var>startPoint</var> is into the control view
+   retangle, NO otherwise. This method is call at the early stage of
+   -trackMouse:inRect:ofView:untilMouseUp:</p><p>See Also:
+   [NSView-mouse:inRect:] -trackMouse:inRect:ofView:untilMouseUp:
+   </p>
+ */
 - (BOOL) startTrackingAt: (NSPoint)startPoint inView: (NSView*)controlView
 {
   // If the point is in the view then yes start tracking
@@ -1307,6 +1501,8 @@ static NSColor	*shadowCol;
     return NO;
 }
 
+/**<p>TODO</p>
+ */
 - (void) stopTracking: (NSPoint)lastPoint
 		   at: (NSPoint)stopPoint
 	       inView: (NSView*)controlView
@@ -1465,22 +1661,21 @@ static NSColor	*shadowCol;
   return NO;				// Otherwise return NO
 }
 
-/*
- * Managing the Cursor
+/** <p>TODO</p>
  */
 - (void) resetCursorRect: (NSRect)cellFrame inView: (NSView*)controlView
 {
   if (_cell.type == NSTextCellType && _cell.is_disabled == NO
     && (_cell.is_selectable == YES || _cell.is_editable == YES))
     {
-      static NSCursor	*c = nil;
-      NSRect	r;
+      static NSCursor	*cursor = nil;
+      NSRect	rect;
 
-      if (c == nil)
+      if (cursor== nil)
 	{
-	  c = RETAIN([NSCursor IBeamCursor]);
+	  cursor = RETAIN([NSCursor IBeamCursor]);
 	}
-      r = NSIntersectionRect(cellFrame, [controlView visibleRect]);
+      rect = NSIntersectionRect(cellFrame, [controlView visibleRect]);
       /*
        * Here we depend on an undocumented feature of NSCursor which may or
        * may not exist in OPENSTEP or MacOS-X ...
@@ -1488,25 +1683,38 @@ static NSColor	*shadowCol;
        * either entry to or exit from the view, we push it on entry and
        * pop it from the cursor stack on exit.
        */
-      [controlView addCursorRect: r cursor: c];
+      [controlView addCursorRect: rect cursor: cursor];
     }
 }
 
-/*
- * Handling Keyboard Alternatives
+/**<p>Implemented by subclasses to returns the key equivalent. 
+   The NSCell implementation returns an empty NSString. </p>
  */
 - (NSString*) keyEquivalent
 {
   return @"";
 }
 
-/*
- * Determining Component Sizes
+/**<p>Does nothing. This method is used by subclasses to recalculate sizes</p>
+   <p>It is usally called from a NSControl object</p>
+   <p>See Also: [NSControl-calcSize]</p>
  */
 - (void) calcDrawInfo: (NSRect)aRect
 {
 }
 
+/**Returns the minimun size needed to display the NSCell.
+   This size is calculate by adding : 
+   <list>
+   <item> the borders (plain or bezeled) size</item>
+   <item> the spacing between the border and inside the cell</item>
+   <item> the TODO ... if the cell is type  of NSTextCellType 
+   or the image size if the cell has a NSImageCellType type.</item>
+   </list>
+  <p>This method  returns NSZeroSize if the cell has a NSNullCellType type
+   (Cocoa returns a very big size instead).
+   </p>
+ */
 - (NSSize) cellSize
 {
   NSSize borderSize, s;
@@ -1570,6 +1778,9 @@ static NSColor	*shadowCol;
   return s;
 }
 
+/**<p>TODO. Currently the GNUstep implementation returns -cellSize</p>
+   <p>See Also: -cellSize</p>
+ */
 - (NSSize) cellSizeForBounds: (NSRect)aRect
 {
   if (_cell.type == NSTextCellType)
@@ -1580,6 +1791,8 @@ static NSColor	*shadowCol;
   return [self cellSize];
 }
 
+/**<p>TODO</p>
+ */
 - (NSRect) drawingRectForBounds: (NSRect)theRect
 {
   NSSize borderSize;
@@ -1595,11 +1808,15 @@ static NSColor	*shadowCol;
   return NSInsetRect(theRect, borderSize.width, borderSize.height);
 }
 
+/**<p>The GNUstep implementation returns -drawingRectForBounds:</p>
+ */
 - (NSRect) imageRectForBounds: (NSRect)theRect
 {
   return [self drawingRectForBounds: theRect];
 }
 
+/** <p>TODO</p>
+ */
 - (NSRect) titleRectForBounds: (NSRect)theRect
 {
   if (_cell.type == NSTextCellType)
@@ -1644,23 +1861,19 @@ static NSColor	*shadowCol;
   return NSDefaultControlTint;
 }
 
-/*
- * Displaying
+/**<p>This method is used by subclasses to specified the control view.
+   This method returns nil.</p>
  */
 - (NSView*) controlView
 {
   return nil;
 }
 
-/*
- * This drawing is minimal and with no background,
- * to make it easier for subclass to customize drawing. 
+/** <p>This drawing is minimal and with no background,
+ * to make it easier for subclass to customize drawing. </p>
  */
 - (void) drawInteriorWithFrame: (NSRect)cellFrame inView: (NSView*)controlView
 {
-  if (![controlView window])
-    return;
-
   cellFrame = [self drawingRectForBounds: cellFrame];
 
   //FIXME: Check if this is also neccessary for images,
@@ -1714,10 +1927,12 @@ static NSColor	*shadowCol;
   // prettyfying
 }
 
+/**<p>Draws the cell in <var>controlView</var></p>
+ */
 - (void) drawWithFrame: (NSRect)cellFrame inView: (NSView*)controlView
 {
   // do nothing if cell's frame rect is zero
-  if (NSIsEmptyRect(cellFrame) || ![controlView window])
+  if (NSIsEmptyRect(cellFrame))
     return;
 
   // draw the border if needed
@@ -1734,16 +1949,26 @@ static NSColor	*shadowCol;
   [self drawInteriorWithFrame: cellFrame inView: controlView];
 }
 
+/**<p>Sets whether the NSCell is highlighted.</p>
+   <p>See Also: -isHighlighted</p>
+ */
 - (void) setHighlighted: (BOOL) flag
 {
   _cell.is_highlighted = flag;
 }
 
+/**<p>Returns whether the cell is highlighted. By default NO</p>
+   <p>See Also: -setHighlighted:</p>
+ */
 - (BOOL) isHighlighted
 {
   return _cell.is_highlighted;
 }
 
+/**
+ *<p>TODO explain</p>
+ */
+
 - (void) highlight: (BOOL)lit
 	 withFrame: (NSRect)cellFrame
 	    inView: (NSView*)controlView
@@ -1809,6 +2034,10 @@ static NSColor	*shadowCol;
 /*
  * Editing Text
  */
+/** <p>.This method does nothing if a the <var>controlView</var> is nil,
+    if text object does not exist or if the cell's type is not <ref type="type"
+    id="NSCellType">NSTextCellType</ref></p>
+ */
 - (void) editWithFrame: (NSRect)aRect
 		inView: (NSView*)controlView
 		editor: (NSText*)textObject
@@ -1856,16 +2085,24 @@ static NSColor	*shadowCol;
     }
 }
 
+/**<p>Ends any text editing. This method sets the text object's delegate 
+   to nil, and remove the NSClipView and the text object used for editing</p>
+ <p>See Also:  -editWithFrame:inView:editor:delegate:event:</p>
+ */
 - (void) endEditing: (NSText*)textObject
 {
-  NSClipView *cv;
+  NSClipView *clipView;
 
   [textObject setDelegate: nil];
-  cv = (NSClipView*)[textObject superview];
+  clipView = (NSClipView*)[textObject superview];
   [textObject removeFromSuperview];
-  [cv removeFromSuperview];
+  [clipView removeFromSuperview];
 }
 
+/** <p> TODO.This method does nothing if a the <var>controlView</var> is nil,
+    if text object does not exist or if the cell's type is not <ref type="type"
+    id="NSCellType">NSTextCellType</ref> </p>
+ */
 - (void) selectWithFrame: (NSRect)aRect
 		  inView: (NSView*)controlView
 		  editor: (NSText*)textObject
