@@ -21,7 +21,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
 */
 
 #include "config.h"
@@ -116,6 +116,11 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   [super dealloc];
 }
 
+
+/**<p>Sets aView the NSClipView's document view to <var>aView</var>
+   </p>
+   <p>See Also: -documentView</p>
+ */
 - (void) setDocumentView: (NSView*)aView
 {
   NSNotificationCenter	*nc;
@@ -362,6 +367,9 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   [_super_view reflectScrolledClipView: self];
 }
 
+/**
+ *<p></p>
+ */
 - (NSPoint) constrainScrollPoint: (NSPoint)proposedNewOrigin
 {
   NSRect	documentFrame;
@@ -431,6 +439,9 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   return new;
 }
 
+/**<p>Returns the document rectangle.</p>
+   <p>See Also: -documentVisibleRect </p>
+ */
 - (NSRect) documentRect
 {
   NSRect documentFrame;
@@ -451,6 +462,10 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   return rect;
 }
 
+/**<p>Returns the document visible rectangle. Returns NSZeroRect if the 
+   document view does not exists.</p>
+ <p>See Also: -documentRect [NSView-convertRect:toView:]</p>
+ */
 - (NSRect) documentVisibleRect
 {
   NSRect documentBounds;
@@ -478,6 +493,8 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
     }
 }
 
+/**<p>Scrolls in response to mouse-dragged events. </p>
+ */
 - (BOOL) autoscroll: (NSEvent*)theEvent
 {
   NSPoint new;
@@ -524,6 +541,9 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   [_super_view reflectScrolledClipView: self];
 }
 
+/**<p>Used when the document view frame notify its change.
+   ( with NSViewFrameDidChangeNotification )</p>
+ */
 - (void) viewFrameChanged: (NSNotification*)aNotification
 {
   [self setBoundsOrigin: [self constrainScrollPoint: _bounds.origin]];
@@ -579,36 +599,60 @@ static inline NSRect integralRect (NSRect rect, NSView *view)
   [_super_view reflectScrolledClipView: self];
 }
 
+/**
+ *<p>Returns the NSClipView's document view.</p>
+ *<p>See Also: -setDocumentView: </p>
+ */
 - (id) documentView
 {
   return _documentView;
 }
 
+/**
+ */
 - (void) setCopiesOnScroll: (BOOL)flag
 {
   _copiesOnScroll = flag;
 }
 
+/**
+ */
 - (BOOL) copiesOnScroll
 {
   return _copiesOnScroll;
 }
 
+/**<p>Sets the cursor for the document view to <var>aCursor</var></p>
+ <p>See Also: -documentCursor</p>
+ */
 - (void) setDocumentCursor: (NSCursor*)aCursor
 {
   ASSIGN (_cursor, aCursor);
 }
 
+/**<p>Returns the cursor of the document view</p>
+   <p>See Also: -setDocumentCursor: </p>
+*/
 - (NSCursor*) documentCursor
 {
   return _cursor;
 }
 
+/**<p>Returns the NSClipView's background color</p>
+   <p>See Also: -setBackgroundColor:</p>
+ */
 - (NSColor*) backgroundColor
 {
   return _backgroundColor;
 }
 
+/**<p>Sets the NSClipView's background color to <var>aColor</var> and marks
+   self for display. Sets the opaque flag if needed ( to YES if the
+   NSClipView does not draw its background, if the background color
+   is nil or if the background color alpha component is less than 1.0 , NO
+   otherwise) </p> 
+   <p>See Also: -backgroundColor [NSView-isOpaque]</p>
+ */
 - (void) setBackgroundColor: (NSColor*)aColor
 {
   if (![_backgroundColor isEqual: aColor])
