@@ -24,7 +24,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "config.h"
@@ -230,28 +230,28 @@ void initSystemColors(void)
     }
 
     {
-      NSEnumerator *e;
-      NSString *r;
+      NSEnumerator *enumerator;
+      NSString *key;
       BOOL changed = NO;
 
       // Set up default system colors
 
-      e = [colorStrings keyEnumerator];
+      enumerator = [colorStrings keyEnumerator];
   
-      while ((r = (NSString *)[e nextObject])) 
+      while ((key = (NSString *)[enumerator nextObject])) 
 	{
-	  NSString *cs;
-	  NSColor *c;
+	  NSString *aColorString;
+	  NSColor *color;
 
-	  if ([systemColors colorWithKey: r])
+	  if ([systemColors colorWithKey: key])
 	    continue;
 
-	  cs = [colorStrings objectForKey: r];
-	  c = [NSColorClass colorFromString: cs];
+	  aColorString = [colorStrings objectForKey: key];
+	  color = [NSColorClass colorFromString: aColorString];
 
-	  NSCAssert1(c, @"couldn't get default system color %@", r);
+	  NSCAssert1(color, @"couldn't get default system color %@", key);
 
-	  [systemColors setColor: c forKey: r];
+	  [systemColors setColor: color forKey: key];
 
 	  changed = YES;
 	}
@@ -278,6 +278,10 @@ systemColorWithName(NSString *name)
   return col;
 }
 
+/**
+ *<p>TODO NSColor description</p>
+ *
+ */
 @implementation NSColor
 
 //
@@ -308,124 +312,155 @@ systemColorWithName(NSString *name)
     }
 }
 
-//
-// Creating an NSColor from Component Values
-//
+/**<p>Creates and returns a new NSColor in a NSCalibratedRGBColorSpace space 
+   name, with hue, saturation, brightness and alpha as specified. Valid values
+   are the range 0.0 to 1.0. Out of range values will be clipped.</p>
+*/
 + (NSColor*) colorWithCalibratedHue: (float)hue
 			 saturation: (float)saturation
 			 brightness: (float)brightness
 			      alpha: (float)alpha
 {
-  id c;
+  id color;
 
-  c = [GSCalibratedRGBColor allocWithZone: NSDefaultMallocZone()];
-  c = [c initWithCalibratedHue: hue
-		    saturation: saturation
-		    brightness: brightness
-			 alpha: alpha];
+  color = [GSCalibratedRGBColor allocWithZone: NSDefaultMallocZone()];
+  color = [color initWithCalibratedHue: hue
+		 saturation: saturation
+		 brightness: brightness
+		 alpha: alpha];
 
-  return AUTORELEASE(c);
+  return AUTORELEASE(color);
 }
 
+
+/**<p>Creates and returns a new NSColor in a NSCalibratedRGBColorSpace space 
+   name, with red, green, blue and alpha as specified. Valid values
+   are the range 0.0 to 1.0. Out of range values will be clipped.</p>
+*/
 + (NSColor*) colorWithCalibratedRed: (float)red
 			      green: (float)green
 			       blue: (float)blue
 			      alpha: (float)alpha
 {
-  id c;
+  id color;
 
-  c = [GSCalibratedRGBColor allocWithZone: NSDefaultMallocZone()];
-  c = [c initWithCalibratedRed: red
-			 green: green
-			  blue: blue
-			 alpha: alpha];
-  return AUTORELEASE(c);
+  color = [GSCalibratedRGBColor allocWithZone: NSDefaultMallocZone()];
+  color = [color initWithCalibratedRed: red
+		 green: green
+		 blue: blue
+		 alpha: alpha];
+  return AUTORELEASE(color);
 }
 
+
+/**<p>Creates and returns a new NSColor in a NSCalibratedWhiteColorSpace space 
+   name, with red, green, blue and alpha as specified. Valid values
+   are the range 0.0 to 1.0. Out of range values will be clipped.</p>
+*/
 + (NSColor*) colorWithCalibratedWhite: (float)white
 				alpha: (float)alpha
 {
-  id c;
+  id color;
 
-  c = [GSCalibratedWhiteColor allocWithZone: NSDefaultMallocZone()] ;
-  c = [c initWithCalibratedWhite: white
-			   alpha: alpha];
+  color = [GSCalibratedWhiteColor allocWithZone: NSDefaultMallocZone()] ;
+  color = [color initWithCalibratedWhite: white
+		 alpha: alpha];
 
-  return AUTORELEASE(c);
+  return AUTORELEASE(color);
 }
 
+/**
+ * <p> TODO </p>
+ */
 + (NSColor*) colorWithCatalogName: (NSString *)listName
 			colorName: (NSString *)colorName
 {
-  id c;
+  id color;
 
-  c = [GSNamedColor allocWithZone: NSDefaultMallocZone()] ;
-  c = [c initWithCatalogName: listName
-		   colorName: colorName];
+  color = [GSNamedColor allocWithZone: NSDefaultMallocZone()] ;
+  color = [color initWithCatalogName: listName
+		 colorName: colorName];
 
-  return AUTORELEASE(c);
+  return AUTORELEASE(color);
 }
 
+/**<p>Creates and returns a new NSColor in a NSDeviceCMYKColorSpace space 
+   name, with cyan, magenta, yellow, black and alpha as specified. Valid values
+   are the range 0.0 to 1.0. Out of range values will be clipped.</p>
+*/
 + (NSColor*) colorWithDeviceCyan: (float)cyan
 			 magenta: (float)magenta
 			  yellow: (float)yellow
 			   black: (float)black
 			   alpha: (float)alpha
 {
-  id c;
+  id color;
 
-  c = [GSDeviceCMYKColor allocWithZone: NSDefaultMallocZone()];
-  c = [c initWithDeviceCyan: cyan
-		    magenta: magenta
-		     yellow: yellow
-		      black: black
-		      alpha: alpha];
+  color = [GSDeviceCMYKColor allocWithZone: NSDefaultMallocZone()];
+  color = [color initWithDeviceCyan: cyan
+		 magenta: magenta
+		 yellow: yellow
+		 black: black
+		 alpha: alpha];
 
-  return AUTORELEASE(c);
+  return AUTORELEASE(color);
 }
 
+
+/**<p>Creates and returns a new NSColor in a NSDeviceCMYKColorSpace space 
+   name, with hue, saturation, brightness and alpha as specified. Valid values
+   are the range 0.0 to 1.0. Out of range values will be clipped.</p>
+*/
 + (NSColor*) colorWithDeviceHue: (float)hue
 		     saturation: (float)saturation
 		     brightness: (float)brightness
 			  alpha: (float)alpha
 {
-  id c;
+  id color;
 
-  c = [GSDeviceRGBColor allocWithZone: NSDefaultMallocZone()];
-  c = [c initWithDeviceHue: hue
-		saturation: saturation
-		brightness: brightness
-		     alpha: alpha];
+  color = [GSDeviceRGBColor allocWithZone: NSDefaultMallocZone()];
+  color = [color initWithDeviceHue: hue
+		 saturation: saturation
+		 brightness: brightness
+		 alpha: alpha];
 
-  return AUTORELEASE(c);
+  return AUTORELEASE(color);
 }
 
+/**<p>Creates and returns a new NSColor in a NSDeviceCMYKColorSpace space 
+   name, with red, green, blue and alpha as specified. Valid values
+   are the range 0.0 to 1.0. Out of range values will be clipped.</p>
+*/
 + (NSColor*) colorWithDeviceRed: (float)red
 			  green: (float)green
 			   blue: (float)blue
 			  alpha: (float)alpha
 {
-  id c;
+  id color;
 
-  c = [GSDeviceRGBColor allocWithZone: NSDefaultMallocZone()];
-  c = [c initWithDeviceRed: red
-		     green: green
-		      blue: blue
-		     alpha: alpha];
+  color = [GSDeviceRGBColor allocWithZone: NSDefaultMallocZone()];
+  color = [color initWithDeviceRed: red
+		 green: green
+		 blue: blue
+		 alpha: alpha];
 
-  return AUTORELEASE(c);
+  return AUTORELEASE(color);
 }
 
+/**<p>Creates and returns a new NSColor in a  NSDeviceWhiteColorSpace space 
+   name, with red, green, blue and alpha as specified. Valid values
+   are the range 0.0 to 1.0. Out of range values will be clipped.</p>
+*/
 + (NSColor*) colorWithDeviceWhite: (float)white
 			    alpha: (float)alpha
 {
-  id c;
+  id color;
 
-  c = [GSDeviceWhiteColor allocWithZone: NSDefaultMallocZone()];
-  c = [c initWithDeviceWhite: white
-		alpha: alpha];
+  color = [GSDeviceWhiteColor allocWithZone: NSDefaultMallocZone()];
+  color = [color initWithDeviceWhite: white
+		 alpha: alpha];
 
-  return AUTORELEASE(c);
+  return AUTORELEASE(color);
 }
 
 + (NSColor*) colorForControlTint: (NSControlTint)controlTint
@@ -436,22 +471,29 @@ systemColorWithName(NSString *name)
 
 + (NSColor*) colorWithPatternImage: (NSImage*)image
 {
-  id c;
+  id color;
 
-  c = [GSPatternColor allocWithZone: NSDefaultMallocZone()];
-  c = [c initWithPatternImage: image];
+  color = [GSPatternColor allocWithZone: NSDefaultMallocZone()];
+  color = [color initWithPatternImage: image];
 
-  return AUTORELEASE(c);
+  return AUTORELEASE(color);
 }
 
-//
-// Creating an NSColor With Preset Components
-//
+
+/**<p>Returns a NSColor in a NSCalibratedWhiteColorSpace space name.
+  with white and alpha values set as NSBlack and 1.0 respectively.</p>
+  <p>See Also : +colorWithCalibratedWhite:alpha:</p>
+*/
 + (NSColor*) blackColor
 {
   return [self colorWithCalibratedWhite: NSBlack alpha: 1.0];
 }
 
+
+/**<p>Returns an NSColor in a  NSCalibratedRGBColorSpace space name.
+  with red, green, blue and alpha values set as 0.0, 0.0, 1.0 and 1.0
+  respectively.</p><p>See Also : +colorWithCalibratedRed:green:blue:alpha:</p>
+*/
 + (NSColor*) blueColor
 {
   return [self colorWithCalibratedRed: 0.0
@@ -460,6 +502,10 @@ systemColorWithName(NSString *name)
 			        alpha: 1.0];
 }
 
+/**<p>Returns a NSColor in a NSCalibratedRGBColorSpace space name.
+  with red, green, blue and alpha values set as 0.6, 0.4, 0.2 and 1.0
+  respectively.</p><p>See Also: +colorWithCalibratedRed:green:blue:alpha:</p>
+*/
 + (NSColor*) brownColor
 {
   return [self colorWithCalibratedRed: 0.6
@@ -468,11 +514,20 @@ systemColorWithName(NSString *name)
 			        alpha: 1.0];
 }
 
+/**<p>Returns a NSColor in a NSCalibratedWhiteColorSpace space name.
+  with white and alpha values set as 0.0 and 1.0 respectively.</p>
+  <p>See Also : +colorWithCalibratedWhite:alpha:</p>
+*/
 + (NSColor*) clearColor
 {
   return [self colorWithCalibratedWhite: 0.0 alpha: 0.0];
 }
 
+
+/**<p>Returns a NSColor in a NSCalibratedRGBColorSpace space name.
+  with red, green, blue and alpha values set as 0.0, 1.0, 1.0 and 1.0
+  respectively.</p><p>See Also : +colorWithCalibratedRed:green:blue:alpha:</p>
+*/
 + (NSColor*) cyanColor
 {
   return [self colorWithCalibratedRed: 0.0
@@ -481,16 +536,28 @@ systemColorWithName(NSString *name)
 			        alpha: 1.0];
 }
 
+/**<p>Returns a NSColor in a NSCalibratedWhiteColorSpace space name.
+  with white and alpha values set as NSDarkGray and 1.0 respectively. </p>
+  <p>See Also : +colorWithCalibratedWhite:alpha:</p>
+*/
 + (NSColor*) darkGrayColor
 {
   return [self colorWithCalibratedWhite: NSDarkGray alpha: 1.0];
 }
 
+/**<p>Returns a NSColor in a NSCalibratedWhiteColorSpace space name.
+  with white and alpha values set as NSGray and 1.0 respectively. </p>
+  <p>See Also: +colorWithCalibratedWhite:alpha:</p>
+*/
 + (NSColor*) grayColor
 {
   return [self colorWithCalibratedWhite: NSGray alpha: 1.0];
 }
 
+/**<p>Returns a NSColor in a  NSCalibratedRGBColorSpace space name.
+  with red, green, blue and alpha values set as 0.0, 1.0, 0.0 and 1.0
+  respectively </p><p>See Also: +colorWithCalibratedRed:green:blue:alpha:</p>
+*/
 + (NSColor*) greenColor
 {
   return [self colorWithCalibratedRed: 0.0
@@ -499,11 +566,19 @@ systemColorWithName(NSString *name)
 			        alpha: 1.0];
 }
 
+/**<p>Returns a NSColor in a NSCalibratedWhiteColorSpace space name.
+  with white and alpha values set as NSLightGray and 1.0 respectively </p>
+  <p>See Also : +colorWithCalibratedRed:green:blue:alpha:</p>
+*/
 + (NSColor*) lightGrayColor
 {
   return [self colorWithCalibratedWhite: NSLightGray alpha: 1];
 }
 
+/**<p>Returns a NSColor in a NSCalibratedRGBColorSpace space name.
+  with red, green, blue and alpha values set as 1.0, 0.0, 1.0 and 1.0
+  respectively.</p><p>See Also : +colorWithCalibratedRed:green:blue:alpha:</p>
+*/
 + (NSColor*) magentaColor
 {
   return [self colorWithCalibratedRed: 1.0
@@ -512,6 +587,11 @@ systemColorWithName(NSString *name)
 			        alpha: 1.0];
 }
 
+
+/**<p>Returns a NSColor in a NSCalibratedRGBColorSpace space name.
+  with red, green, blue and alpha values set as 1.0, 0.5, 0.0 and 1.0
+  respectively.</p><p>See Also: +colorWithCalibratedRed:green:blue:alpha:</p>
+*/
 + (NSColor*) orangeColor
 {
   return [self colorWithCalibratedRed: 1.0
@@ -520,6 +600,11 @@ systemColorWithName(NSString *name)
 			        alpha: 1.0];
 }
 
+
+/**<p>Returns a NSColor in a NSCalibratedRGBColorSpace space name.
+  with red, green, blue and alpha values set as 0.5, 0.0, 0.5 and 1.0
+  respectively.</p><p>See Also : +colorWithCalibratedRed:green:blue:alpha:</p>
+*/
 + (NSColor*) purpleColor
 {
   return [self colorWithCalibratedRed: 0.5
@@ -528,6 +613,11 @@ systemColorWithName(NSString *name)
 			        alpha: 1.0];
 }
 
+
+/**<p>Returns a NSColor in a NSCalibratedRGBColorSpace space name.
+  with red, green, blue and alpha values set as 1.0, 0.0, 0.0 and 1.0
+  respectively </p><p>See Also: +colorWithCalibratedRed:green:blue:alpha:</p>
+*/
 + (NSColor*) redColor
 {
   return [self colorWithCalibratedRed: 1.0
@@ -536,11 +626,20 @@ systemColorWithName(NSString *name)
 			        alpha: 1.0];
 }
 
+/**<p>Returns a NSColor in a NSCalibratedWhiteColorSpace space name.
+  with white and alpha values set as NSWhite and 1.0 respectively. </p>
+  <p>See Also : +colorWithCalibratedWhite:alpha:</p>
+*/
 + (NSColor*) whiteColor
 {
   return [self colorWithCalibratedWhite: NSWhite alpha: 1.0];
 }
 
+
+/**<p>Returns a NSColor in a NSCalibratedRGBColorSpace space name.
+  with red, green, blue and alpha values set as 1.0, 0.0, 0.0 and 1.0
+  respectively.</p><p>See Also : +colorWithCalibratedRed:green:blue:alpha:</p>
+*/
 + (NSColor*) yellowColor
 {
   return [self colorWithCalibratedRed: 1.0
@@ -549,29 +648,34 @@ systemColorWithName(NSString *name)
 			        alpha: 1.0];
 }
 
-//
-// Ignoring Alpha Components
-//
+
+/** Returns whether TODO
+ *<p>See Also: +setIgnoresAlpha:</p>
+ */
 + (BOOL) ignoresAlpha
 {
   return gnustep_gui_ignores_alpha;
 }
 
+/** TODO
+ *<p>See Also: +ignoresAlpha</p>
+ */
 + (void) setIgnoresAlpha: (BOOL)flag
 {
   gnustep_gui_ignores_alpha = flag;
 }
 
-//
-// Copying and Pasting
-//
+/**<p>Returns the NSColor on the NSPasteboard pasteBoard
+   or nil if it does not exists.</p><p>See Also: -writeToPasteboard:</p>
+ */
 + (NSColor*) colorFromPasteboard: (NSPasteboard *)pasteBoard
 {
-  NSData *d = [pasteBoard dataForType: NSColorPboardType];
+  NSData *colorData = [pasteBoard dataForType: NSColorPboardType];
 
   // FIXME: This should better use the description format
-  if (d != nil)
-    return [NSUnarchiver unarchiveObjectWithData: d];
+  if (colorData != nil)
+    return [NSUnarchiver unarchiveObjectWithData: colorData];
+
   return nil;
 }
 
@@ -762,9 +866,10 @@ systemColorWithName(NSString *name)
   return nil;
 }
 
-//
-// Retrieving a Set of Components
-//
+/**<p>Gets the cyan, magenta, yellow,black and alpha values from the NSColor.
+ Raises a NSInternalInconsistencyException if the NSColor is not a CYMK color
+ </p>
+ */
 - (void) getCyan: (float*)cyan
 	 magenta: (float*)magenta
 	  yellow: (float*)yellow
@@ -775,6 +880,10 @@ systemColorWithName(NSString *name)
     format: @"Called getCyan:magenta:yellow:black:alpha: on non-CMYK colour"];
 }
 
+/**<p>Gets the hue, saturation, brightness and alpha values from the NSColor.
+ Raises a NSInternalInconsistencyException if the NSColor is not a RGB color
+ </p>
+ */
 - (void) getHue: (float*)hue
      saturation: (float*)saturation
      brightness: (float*)brightness
@@ -784,7 +893,11 @@ systemColorWithName(NSString *name)
     format: @"Called getHue:saturation:brightness:alpha: on non-RGB colour"];
 }
 
-- (void) getRed: (float*)red
+/**<p>Gets the red, green, blue and alpha values from the NSColor.
+ Raises a NSInternalInconsistencyException if the NSColor is not a RGB color
+ </p>
+ */
+-(void) getRed: (float*)red
 	  green: (float*)green
 	   blue: (float*)blue
 	  alpha: (float*)alpha
@@ -793,6 +906,10 @@ systemColorWithName(NSString *name)
 	      format: @"Called getRed:green:blue:alpha: on non-RGB colour"];
 }
 
+/**<p>Gets the white alpha values from the NSColor.
+ Raises a NSInternalInconsistencyException if the NSColor is not a 
+ greyscale color</p>
+ */
 - (void) getWhite: (float*)white
 	    alpha: (float*)alpha
 {
@@ -813,14 +930,16 @@ systemColorWithName(NSString *name)
     }
 }
 
-//
-// Retrieving Individual Components
-//
+/** <p>Returns the alpha component. </p>
+ */
 - (float) alphaComponent
 {
   return 1.0;
 }
 
+/** <p>Returns the black component. Raises a NSInternalInconsistencyException
+    if NSColor is not a CMYK color.</p>
+ */
 - (float) blackComponent
 {
   [NSException raise: NSInternalInconsistencyException
@@ -828,6 +947,9 @@ systemColorWithName(NSString *name)
   return 0.0;
 }
 
+/** <p>Returns the blue component. Raises a NSInternalInconsistencyException
+    if NSColor is not a RGB color.</p>
+ */
 - (float) blueComponent
 {
   [NSException raise: NSInternalInconsistencyException
@@ -835,6 +957,9 @@ systemColorWithName(NSString *name)
   return 0.0;
 }
 
+/** <p>Returns the brightness component. Raises a 
+    NSInternalInconsistencyException if NSColor space is not a RGB color</p>
+*/
 - (float) brightnessComponent
 {
   [NSException raise: NSInternalInconsistencyException
@@ -856,6 +981,9 @@ systemColorWithName(NSString *name)
   return nil;
 }
 
+/** <p>Returns the cyan component. Raises a  NSInternalInconsistencyException 
+    if NSColor is not a CYMK color</p>
+*/
 - (float) cyanComponent
 {
   [NSException raise: NSInternalInconsistencyException
@@ -863,6 +991,9 @@ systemColorWithName(NSString *name)
   return 0.0;
 }
 
+/** <p>Returns the green component. Raises a  NSInternalInconsistencyException 
+    if NSColor is not a RGB color</p>
+*/
 - (float) greenComponent
 {
   [NSException raise: NSInternalInconsistencyException
@@ -870,6 +1001,9 @@ systemColorWithName(NSString *name)
   return 0.0;
 }
 
+/** <p>Returns the hue component. Raises a  NSInternalInconsistencyException 
+    if NSColor is not a RGB color</p>
+*/
 - (float) hueComponent
 {
   [NSException raise: NSInternalInconsistencyException
@@ -891,6 +1025,9 @@ systemColorWithName(NSString *name)
   return nil;
 }
 
+/** <p>Returns the magenta component. Raises a  
+    NSInternalInconsistencyException  if NSColor is not a CMYK color</p>
+*/
 - (float) magentaComponent
 {
   [NSException raise: NSInternalInconsistencyException
@@ -898,6 +1035,9 @@ systemColorWithName(NSString *name)
   return 0.0;
 }
 
+/** <p>Returns the red component. Raises a NSInternalInconsistencyException  
+    if NSColor is not a RGB color</p>
+*/
 - (float) redComponent
 {
   [NSException raise: NSInternalInconsistencyException
@@ -905,6 +1045,9 @@ systemColorWithName(NSString *name)
   return 0.0;
 }
 
+/** <p>Returns the saturation component. Raises a
+    NSInternalInconsistencyException if NSColor is not a RGB color</p>
+*/
 - (float) saturationComponent
 {
   [NSException raise: NSInternalInconsistencyException
@@ -912,6 +1055,9 @@ systemColorWithName(NSString *name)
   return 0.0;
 }
 
+/** <p>Returns the white component. Raises a NSInternalInconsistencyException  
+    if NSColor is not a grayscale color</p>
+*/
 - (float) whiteComponent
 {
   [NSException raise: NSInternalInconsistencyException
@@ -926,6 +1072,9 @@ systemColorWithName(NSString *name)
   return nil;
 }
 
+/** <p>Returns the yellow component. Raises a NSInternalInconsistencyException
+    if NSColor is not a RGB color</p>
+*/
 - (float) yellowComponent
 {
   [NSException raise: NSInternalInconsistencyException
@@ -1028,16 +1177,17 @@ systemColorWithName(NSString *name)
 			        ofColor: [NSColorClass shadowColor]];
 }
 
-//
-// Copying and Pasting
-//
+/**<p>Writes the NSColor into the NSPasteboard specified by pasteBoard</p>
+ * <p>See Also: +colorFromPasteboard: </p>
+ */
 - (void) writeToPasteboard: (NSPasteboard *)pasteBoard
 {
   // FIXME: We should better use the description
-  NSData *d = [NSArchiver archivedDataWithRootObject: self];
+  NSData *colorData = [NSArchiver archivedDataWithRootObject: self];
 
-  if (d != nil)
-    [pasteBoard setData: d forType: NSColorPboardType];
+  if (colorData != nil)
+    [pasteBoard setData: colorData
+		forType: NSColorPboardType];
 }
 
 //
@@ -1075,7 +1225,8 @@ systemColorWithName(NSString *name)
       int colorSpace = [aDecoder decodeIntForKey: @"NSColorSpace"];
 
       DESTROY(self);
-      if (colorSpace == 1)
+
+      if ((colorSpace == 1) || (colorSpace == 2))
         {
 	  unsigned length;
 	  const uint8_t *data;
@@ -1089,8 +1240,9 @@ systemColorWithName(NSString *name)
 	  if ([aDecoder containsValueForKey: @"NSRGB"])
 	    {
 	      data = [aDecoder decodeBytesForKey: @"NSRGB"
-			     returnedLength: &length]; 
-	      str = [[NSString alloc] initWithCString: data length: length];
+			       returnedLength: &length]; 
+	      str = [[NSString alloc] initWithCString: (const char*)data 
+				      length: length];
 	      scanner = [[NSScanner alloc] initWithString: str];
 	      [scanner scanFloat: &red];
 	      [scanner scanFloat: &green];
@@ -1099,12 +1251,22 @@ systemColorWithName(NSString *name)
 	      RELEASE(str);
 	    }
 
-	  self = [NSColor colorWithCalibratedRed: red
-			  green: green
-			  blue: blue
-			  alpha: alpha];
+	  if (colorSpace == 1)
+	    {
+	      self = [NSColor colorWithCalibratedRed: red
+			      green: green
+			      blue: blue
+			      alpha: alpha];
+	    }
+	  else
+	    {
+	      self = [NSColor colorWithDeviceRed: red
+			      green: green
+			      blue: blue
+			      alpha: alpha];
+	    }
 	}
-      else if (colorSpace == 3)
+      else if ((colorSpace == 3) || (colorSpace == 4))
         {
 	  unsigned length;
 	  const uint8_t *data;
@@ -1116,15 +1278,57 @@ systemColorWithName(NSString *name)
 	  if ([aDecoder containsValueForKey: @"NSWhite"])
 	    {
 	      data = [aDecoder decodeBytesForKey: @"NSWhite"
-			     returnedLength: &length]; 
-	      str = [[NSString alloc] initWithCString: data length: length];
+			       returnedLength: &length]; 
+	      str = [[NSString alloc] initWithCString: (const char*)data 
+				      length: length];
 	      scanner = [[NSScanner alloc] initWithString: str];
 	      [scanner scanFloat: &white];
 	      RELEASE(scanner);
 	      RELEASE(str);
 	    }
 	  
-	  self = [NSColor colorWithDeviceWhite: white
+	  if (colorSpace == 3)
+	    {
+	      self = [NSColor colorWithCalibratedWhite: white
+			      alpha: alpha];
+	    }
+	  else
+	    {
+	      self = [NSColor colorWithDeviceWhite: white
+			      alpha: alpha];
+	    }
+	}
+      else if (colorSpace == 5)
+        {
+	  unsigned length;
+	  const uint8_t *data;
+	  float cyan = 0.0;
+	  float yellow = 0.0;
+	  float magenta = 0.0;
+	  float black = 0.0;
+	  float alpha = 1.0;
+	  NSString *str;
+	  NSScanner *scanner;
+	  
+	  if ([aDecoder containsValueForKey: @"NSCYMK"])
+	    {
+	      data = [aDecoder decodeBytesForKey: @"NSCYMK"
+			       returnedLength: &length]; 
+	      str = [[NSString alloc] initWithCString: (const char*)data 
+				      length: length];
+	      scanner = [[NSScanner alloc] initWithString: str];
+	      [scanner scanFloat: &cyan];
+	      [scanner scanFloat: &yellow];
+	      [scanner scanFloat: &magenta];
+	      [scanner scanFloat: &black];
+	      RELEASE(scanner);
+	      RELEASE(str);
+	    }
+
+	  self = [NSColor colorWithDeviceCyan: cyan
+			  magenta: magenta
+			  yellow: yellow
+			  black: black
 			  alpha: alpha];
 	}
       else if (colorSpace == 6)
@@ -1136,6 +1340,12 @@ systemColorWithName(NSString *name)
 	  self = [NSColor colorWithCatalogName: catalog
 			  colorName: name];
 	}
+      else if (colorSpace == 10)
+        {
+	  NSImage *image = [aDecoder decodeObjectForKey: @"NSImage"];
+	  
+	  self = [NSColor colorWithPatternImage: image];
+	}
       
       return self;
     }
@@ -1363,13 +1573,14 @@ systemColorWithName(NSString *name)
 	  [scanner scanFloat: &b] &&
 	  [scanner isAtEnd])
 	{
+	  RELEASE(scanner);
 	  return [self colorWithCalibratedRed: r
 					green: g
 					 blue: b
 					alpha: 1.0];
 	}
 
-      DESTROY(scanner);
+      RELEASE(scanner);
     }
 
   return nil;
@@ -1579,9 +1790,18 @@ systemColorWithName(NSString *name)
 //
 - (void) encodeWithCoder: (NSCoder*)aCoder
 {
-  [aCoder encodeObject: [self colorSpaceName]];
-  [aCoder encodeObject: _catalog_name];
-  [aCoder encodeObject: _color_name];
+  if ([aCoder allowsKeyedCoding])
+    {
+      [aCoder encodeInt: 6 forKey: @"NSColorSpace"];
+      [aCoder encodeObject: _catalog_name forKey: @"NSCatalogName"];
+      [aCoder encodeObject: _color_name forKey: @"NSColorName"];
+    }
+  else 
+    {
+      [aCoder encodeObject: [self colorSpaceName]];
+      [aCoder encodeObject: _catalog_name];
+      [aCoder encodeObject: _color_name];
+    }
 }
 
 - (id) initWithCoder: (NSCoder*)aDecoder
@@ -1748,9 +1968,31 @@ systemColorWithName(NSString *name)
 //
 - (void) encodeWithCoder: (NSCoder*)aCoder
 {
-  [aCoder encodeObject: [self colorSpaceName]];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_white_component];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_alpha_component];
+  if ([aCoder allowsKeyedCoding])
+    {
+      NSString *str;
+
+      if ([[self colorSpaceName] isEqualToString: NSCalibratedWhiteColorSpace])
+        {
+	  [aCoder encodeInt: 3 forKey: @"NSColorSpace"];
+	}
+      else
+        {
+	  [aCoder encodeInt: 4 forKey: @"NSColorSpace"];
+	}
+      // FIXME: Missing handling of alpha value
+      str = [[NSString alloc] initWithFormat: @"%f", _white_component];
+      [aCoder encodeBytes: (const uint8_t*)[str cString] 
+	      length: [str cStringLength] 
+	      forKey: @"NSWhite"];
+      RELEASE(str);
+    }
+  else 
+    {
+      [aCoder encodeObject: [self colorSpaceName]];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_white_component];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_alpha_component];
+    }
 }
 
 - (id) initWithCoder: (NSCoder*)aDecoder
@@ -2032,12 +2274,28 @@ systemColorWithName(NSString *name)
 //
 - (void) encodeWithCoder: (NSCoder*)aCoder
 {
-  [aCoder encodeObject: [self colorSpaceName]];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_cyan_component];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_magenta_component];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_yellow_component];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_black_component];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_alpha_component];
+  if ([aCoder allowsKeyedCoding])
+    {
+      NSString *str;
+
+      // FIXME: Missing handling of alpha value
+      [aCoder encodeInt: 5 forKey: @"NSColorSpace"];
+      str = [[NSString alloc] initWithFormat: @"%f %f %f %f", _cyan_component, 
+			      _magenta_component, _yellow_component, _black_component];
+      [aCoder encodeBytes: (const uint8_t*)[str cString] 
+	      length: [str cStringLength] 
+	      forKey: @"NSCYMK"];
+      RELEASE(str);
+    }
+  else 
+    {
+      [aCoder encodeObject: [self colorSpaceName]];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_cyan_component];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_magenta_component];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_yellow_component];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_black_component];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_alpha_component];
+    }
 }
 
 - (id) initWithCoder: (NSCoder*)aDecoder
@@ -2269,14 +2527,37 @@ systemColorWithName(NSString *name)
 //
 - (void) encodeWithCoder: (NSCoder*)aCoder
 {
-  [aCoder encodeObject: [self colorSpaceName]];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_red_component];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_green_component];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_blue_component];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_hue_component];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_saturation_component];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_brightness_component];
-  [aCoder encodeValueOfObjCType: @encode(float) at: &_alpha_component];
+  if ([aCoder allowsKeyedCoding])
+    {
+      NSString *str;
+
+      if ([[self colorSpaceName] isEqualToString: NSCalibratedRGBColorSpace])
+        {
+	  [aCoder encodeInt: 1 forKey: @"NSColorSpace"];
+	}
+      else
+        {
+	  [aCoder encodeInt: 2 forKey: @"NSColorSpace"];
+	}
+      // FIXME: Missing handling of alpha value
+      str = [[NSString alloc] initWithFormat: @"%f %f %f", _red_component, 
+			      _green_component, _blue_component];
+      [aCoder encodeBytes: (const uint8_t*)[str cString] 
+	      length: [str cStringLength] 
+	      forKey: @"NSRGB"];
+      RELEASE(str);
+    }
+  else 
+    {
+      [aCoder encodeObject: [self colorSpaceName]];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_red_component];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_green_component];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_blue_component];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_hue_component];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_saturation_component];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_brightness_component];
+      [aCoder encodeValueOfObjCType: @encode(float) at: &_alpha_component];
+    }
 }
 
 - (id) initWithCoder: (NSCoder*)aDecoder
@@ -2621,7 +2902,7 @@ systemColorWithName(NSString *name)
 
 - (void) set
 {
-  // FIXME: We need another PS command for this
+  [GSCurrentContext() GSSetPatterColor: _pattern];
 }
 
 //
@@ -2629,8 +2910,16 @@ systemColorWithName(NSString *name)
 //
 - (void) encodeWithCoder: (NSCoder*)aCoder
 {
-  [aCoder encodeObject: [self colorSpaceName]];
-  [aCoder encodeObject: _pattern];
+  if ([aCoder allowsKeyedCoding])
+    {
+      [aCoder encodeInt: 10 forKey: @"NSColorSpace"];
+      [aCoder encodeObject: _pattern forKey: @"NSImage"];
+    }
+  else 
+    {
+      [aCoder encodeObject: [self colorSpaceName]];
+      [aCoder encodeObject: _pattern];
+    }
 }
 
 - (id) initWithCoder: (NSCoder*)aDecoder
