@@ -22,7 +22,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
@@ -363,6 +363,8 @@ static int _gs_gui_color_picker_mode = NSRGBModeColorPanel;
 
 @end
 
+/**<p>TODO Description</p>
+ */
 @implementation NSColorPanel
 
 /*
@@ -378,6 +380,8 @@ static int _gs_gui_color_picker_mode = NSRGBModeColorPanel;
     }
 }
 
+/**<p>Creates ( if needed ) and returns the shared NSColorPanel.</p>
+ */
 + (NSColorPanel *)sharedColorPanel
 {
   if (_gs_gui_color_panel == nil)
@@ -395,6 +399,8 @@ static int _gs_gui_color_picker_mode = NSRGBModeColorPanel;
   return _gs_gui_color_panel;
 }
 
+/** <p>Returns whether the NSColorPanel has been already created.</p>
+ */
 + (BOOL) sharedColorPanelExists
 {
   return (_gs_gui_color_panel == nil) ? NO : YES;
@@ -405,25 +411,40 @@ static int _gs_gui_color_picker_mode = NSRGBModeColorPanel;
   _gs_gui_color_picker_mask = mask;
 }
 
+/**
+ */
 + (void) setPickerMode: (int)mode
 {
   _gs_gui_color_picker_mode = mode;
 }
 
+/**<p>Drags <var>aColor</var> frome <var>sourceView</var> at the location
+   give by the event <var>anEvent</var> ( [NSView-convertPoint:fromView:] ).
+   The type declare into the pasteboard is NSColorPboardType</p>
+   <p>See Also: [NSView-convertPoint:fromView:] 
+   [NSView-dragImage:at:offset:event:pasteboard:source:slideBack:</p>
+ */
 + (BOOL) dragColor: (NSColor *)aColor
 	 withEvent: (NSEvent *)anEvent
 	  fromView: (NSView *)sourceView
 {
   NSPasteboard	*pb = [NSPasteboard pasteboardWithName: NSDragPboard];
   NSImage	*image = [NSImage imageNamed: @"common_ColorSwatch"];
+  NSSize	size;
+  NSPoint	point;
 
   [pb declareTypes: [NSArray arrayWithObjects: NSColorPboardType, nil]
-             owner: aColor];
+      owner: aColor];
   [aColor writeToPasteboard: pb];
   [image setBackgroundColor: aColor];
 
+  size = [image size];
+  point = [sourceView convertPoint: [anEvent locationInWindow] fromView: nil];
+  point.x -= size.width/2;
+  point.y -= size.width/2;
+
   [sourceView dragImage: image
-                     at: [sourceView bounds].origin
+                     at: point
                  offset: NSMakeSize(0,0)
                   event: anEvent
              pasteboard: pb
@@ -471,16 +492,25 @@ static int _gs_gui_color_picker_mode = NSRGBModeColorPanel;
   [super dealloc];
 }
 
+/** <p>Returns the NSColorPanel's accessory view if it exists, 
+    nil otherwise.</p><p>See Also: -setAccessoryView:</p>    
+ */
 - (NSView *) accessoryView
 {
   return _accessoryView;
 }
 
+/** <p> Returns whether the NSColorPanel continuously sends its action message.
+    </p><p>See Also: -setContinuous:-setAction: -setTarget: </p>
+ */
 - (BOOL) isContinuous
 {
   return _isContinuous;
 }
 
+/** <p> Returns the current mode of the NSColorPanel.</p>
+    <p>See Also: -setMode:</p>
+ */
 - (int) mode
 {
   if (_currentPicker != nil)
@@ -489,6 +519,11 @@ static int _gs_gui_color_picker_mode = NSRGBModeColorPanel;
     return 0;
 }
 
+/**<p> Sets the accessoryView to a view. The old view ( if exists ) will be 
+    remove ( and release ). You need to retain it if you want to use
+    it later</p>
+    <p>See Also: -accessoryView</p>
+ */
 - (void) setAccessoryView: (NSView *)aView
 {
   if (_accessoryView == aView)
@@ -500,16 +535,27 @@ static int _gs_gui_color_picker_mode = NSRGBModeColorPanel;
   [_splitView addSubview: _accessoryView];
 }
 
+/**<p>Sets the NSColorPanl action method to <var>aSelector</var> The
+   action message is usally send in -setColor:, when the picker is updated,
+   when a new picker is show, when the alpha is changed or when one of the
+   color well at the bottom is selected.</p>
+ */
 - (void) setAction: (SEL)aSelector
 {
   _action = aSelector;
 }
 
+/** <p>Sets whether the NSColorPanel sends continuously action messages</p>
+    <p>See Also: -isContinuous</p>
+ */
 - (void) setContinuous: (BOOL)flag
 {
   _isContinuous = flag;
 }
 
+/** <p>Set the NSColorPanel mode to <var>mode</var>.</p>
+    <p>See Also: -mode</p>
+ */
 - (void) setMode: (int)mode
 {
   int i, count;
@@ -530,6 +576,9 @@ static int _gs_gui_color_picker_mode = NSRGBModeColorPanel;
     }
 }
 
+/** <p>Sets whether the NSColorPanel shows alpha values and the alpha
+    slider.</p><p>See Also: -showsAlpha</p>
+ */
 - (void) setShowsAlpha: (BOOL)flag
 {
   if (flag == _showsAlpha)
@@ -562,11 +611,16 @@ static int _gs_gui_color_picker_mode = NSRGBModeColorPanel;
   [_topView setNeedsDisplay: YES];
 }
 
+/** <p>Sets the target object to <var>anObject</var></p>
+ */
 - (void) setTarget: (id)anObject
 {
   _target = anObject;
 }
 
+/** <p>Returns whether the NSColorPanel shows alpha values and the alpha
+    slider</p><p>See Also: -setShowsAlpha:</p>
+ */
 - (BOOL) showsAlpha
 {
   return _showsAlpha;
@@ -587,9 +641,10 @@ static int _gs_gui_color_picker_mode = NSRGBModeColorPanel;
                             withObject: aColorList];
 }
 
-//
-// Setting Color
-//
+/** <p>Returns the alpha value of the NSColorPanel. Returns
+    1.0 if the NSColorPanel does not show alpha</p>
+    <p>See Also: -showsAlpha -setShowsAlpha:</p>    
+ */
 - (float) alpha
 {
   if ([self showsAlpha])
@@ -598,11 +653,19 @@ static int _gs_gui_color_picker_mode = NSRGBModeColorPanel;
     return 1.0;
 }
 
+/** <p>Returns the current NSColor displayed by the NSColorPanel.</p>
+    <p>See Also : -setColor:</p>
+ */
 - (NSColor *) color
 {
   return [_colorWell color];
 }
 
+/** <p>Sets the NSColor displayed to aColor. This method post a
+    NSColorPanelColorChangedNotification notification if needed.</p>
+    <p>See Also: -color [NSColorWell-setColor:]
+    </p>
+*/
 - (void) setColor: (NSColor *)aColor
 {
   [_colorWell setColor: aColor];
