@@ -24,7 +24,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
@@ -71,6 +71,11 @@ static NSString *GSColorWellDidBecomeExclusiveNotification =
   return _action;
 }
 
+/**<p>Activates the NSColorWell and displays the NSColorPanel with the current
+   NSColorWell's color. The NSColorWell can take color from the NSColorPanel.
+   If exclusive is YES other NSColorWells are desacivated
+   (through notifications).</p><p>See Also: -deactivate</p>
+ */
 - (void) activate: (BOOL)exclusive
 {
   NSNotificationCenter	*nc = [NSNotificationCenter defaultCenter];
@@ -100,11 +105,18 @@ static NSString *GSColorWellDidBecomeExclusiveNotification =
   [self setNeedsDisplay: YES];
 }
 
+/**<p> Returns the current NSColor of the NSColorWell.</p>
+   <p> See Also: -setColor:</p>
+ */
 - (NSColor *) color
 {
   return _the_color;
 }
 
+/** <p>Desactivates the NSColorWell and marks self for display.
+    It is usally call from an observer, when another NSColorWell is 
+    activate.</p><p>See Also: -activate:</p>
+ */
 - (void) deactivate
 {
   _is_active = NO;
@@ -208,6 +220,9 @@ static NSString *GSColorWellDidBecomeExclusiveNotification =
   [self drawWellInside: NSIntersectionRect(aRect, clipRect)];
 }
 
+/**<p>Draws the NSColorWell inside the rectangle <var>insideRect</var>.</p>
+   <p>See Also: [NSColor-drawSwatchInRect:]</p>
+ */
 - (void) drawWellInside: (NSRect)insideRect
 {
   if (NSIsEmptyRect(insideRect))
@@ -260,11 +275,18 @@ static NSString *GSColorWellDidBecomeExclusiveNotification =
   return self;
 }
 
+/** <p>Returns whether the NSColorWell is active. By default a NSColorWell
+    is not active.</p>
+    <p>See Also: -activate: -deactivate</p>
+ */
 - (BOOL) isActive
 {
   return _is_active;
 }
 
+/** <p>Returns whether the NSColorWell has border. By default a NSColorWell
+    has border.</p><p>See Also: -setBordered:</p>
+ */
 - (BOOL) isBordered
 {
   return _is_bordered;
@@ -281,7 +303,7 @@ static NSString *GSColorWellDidBecomeExclusiveNotification =
   // OPENSTEP 4.2 and OSX behavior indicates that the colorwell doesn't
   // work when the widget is marked as disabled.
   //
-  if([self isEnabled])
+  if ([self isEnabled])
     {
       NSPoint point = [self convertPoint: [theEvent locationInWindow]
                             fromView: nil];
@@ -322,12 +344,19 @@ static NSString *GSColorWellDidBecomeExclusiveNotification =
   _action = action;
 }
 
+/**<p>Sets whether the NSColorWell has border and marks self for display.
+   By default a NSColorWell has border.</p><p>See Also: -isBordered</p>
+ */
 - (void) setBordered: (BOOL)bordered
 {
   _is_bordered = bordered;
   [self setNeedsDisplay: YES];
 }
 
+/** <p>Sets the NSColorWell to color. Sets the NSColorPanel if active,
+    notify the target that the color changed and marks self for display.</p>
+    <p>See Also: -color</p>
+ */
 - (void) setColor: (NSColor *)color
 {
   ASSIGN(_the_color, color);
@@ -353,6 +382,9 @@ static NSString *GSColorWellDidBecomeExclusiveNotification =
   _target = target;
 }
 
+/** <p>Sets the NSColorWell's color to the sender color.</p>
+    <p>See Also: -setColor: </p>
+ */
 - (void) takeColorFrom: (id)sender
 {
   if ([sender respondsToSelector: @selector(color)])
