@@ -24,7 +24,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "config.h"
@@ -48,6 +48,9 @@ static Class usedCellClass;
 static Class cellClass;
 static Class actionCellClass;
 
+/**<p>TODO Description</p>
+ */
+
 @implementation NSControl
 
 /*
@@ -64,21 +67,24 @@ static Class actionCellClass;
     }
 }
 
-/*
- * Setting the Control's Cell
+/**<p> Returns the cell Class used by NSControl. Used by subclasses.</p>
+   <p>See Also: +setCellClass:</p>    
  */
 + (Class) cellClass
 {
   return usedCellClass;
 }
 
+/**<p> Sets the cell Class used by NSControl to <var>factoryId</var>.
+   Used by subclasses.</p> <p>See Also: +setCellClass:</p>    
+ */
 + (void) setCellClass: (Class)factoryId
 {
   usedCellClass = factoryId ? factoryId : cellClass;
 }
 
-/*
- * Instance methods
+/**<p>Initializes and returns a new NSControl into the rectangle 
+   frameRect and create a new associated NSCell</p><p>See Also: -setCell:</p> 
  */
 - (id) initWithFrame: (NSRect)frameRect
 {
@@ -98,14 +104,17 @@ static Class actionCellClass;
   [super dealloc];
 }
 
-/*
- * Setting the Control's Cell
+/** <p>Returns the NSControl's cell.</p><p>See Also: -setCell:</p> 
  */
 - (id) cell
 {
   return _cell;
 }
 
+/** <p>Sets the NSControl's cell to aCell, 
+    Raises an NSInvalidArgumentException exception if aCell is not nil and
+    if it is not a cell class.</p><p>See Also: -cell</p> 
+ */
 - (void) setCell: (NSCell *)aCell
 {
   if (aCell != nil && [aCell isKindOfClass: cellClass] == NO)
@@ -115,30 +124,37 @@ static Class actionCellClass;
   ASSIGN(_cell, aCell);
 }
 
-/*
- * Enabling and Disabling the Control
+/**<p>Returns whether the selected cell of the NSControl is enabled.</p>
+   <p>See Also: -setEnabled: [NSCell-isEnabled]</p>
  */
 - (BOOL) isEnabled
 {
   return [[self selectedCell] isEnabled];
 }
 
+/**<p>Sets whether the NSControl's selected cell is enabled.
+   If flag is NO, this method abort the editing. This method marks self for
+   display.</p><p>See Also: -isEnabled [NSCell-setEnabled:]</p>
+ */
 - (void) setEnabled: (BOOL)flag
 {
   [[self selectedCell] setEnabled: flag];
   if (!flag)
     [self abortEditing];
+
   [self setNeedsDisplay: YES];
 }
 
-/*
- * Identifying the Selected Cell
+/** <p>Returns the NSControl's selected cell.</p>
  */
 - (id) selectedCell
 {
   return _cell;
 }
 
+/** <p>Returns the tag of the NSControl's selected cell (if exists).
+    -1 otherwise.</p><p>See Also: [NSCell-tag]</p>
+ */
 - (int) selectedTag
 {
   NSCell *selected = [self selectedCell];
@@ -149,8 +165,9 @@ static Class actionCellClass;
     return [selected tag];
 }
 
-/*
- * Setting the Control's Value
+/** <p>Returns the value of the NSControl's selected cell as double.</p>
+    <p>See Also:  -setDoubleValue: [NSCell-doubleValue] -intValue -floatValue
+    -doubleValue -stringValue</p>
  */
 - (double) doubleValue
 {
@@ -158,16 +175,28 @@ static Class actionCellClass;
   return [[self selectedCell] doubleValue];
 }
 
+/** <p>Returns the value of the NSControl's selected cell as float.</p>
+    <p>See Also: -setFloatValue: [NSCell-floatValue] -intValue -stringValue
+    -doubleValue</p>
+ */
 - (float) floatValue
 {
   return [[self selectedCell] floatValue];
 }
 
+/** <p>Returns the value of the NSControl's selected cell as int.</p>
+    <p>See Also: -setIntValue: [NSCell-intValue] -floatValue -doubleValue
+    -stringValue</p>
+ */
 - (int) intValue
 {
   return [[self selectedCell] intValue];
 }
 
+/** <p>Returns the value of the NSControl's selected cell as NSString.</p>
+    <p>See Also: -setStringValue: [NSCell-stringValue] -intValue -floatValue
+    -doubleValue -stringValue</p>
+ */
 - (NSString *) stringValue
 {
   return [[self selectedCell] stringValue];
@@ -178,6 +207,11 @@ static Class actionCellClass;
   return [[self selectedCell] objectValue];
 }
 
+/** <p>Sets the value of the NSControl's selected cell to double.
+    If the selected cell is an action cell, it marks self for display.</p>
+    <p>See Also: -doubleValue [NSCell-setDoubleValue:] -setIntValue:
+    -setStringValue: -setFloatValue:</p>
+ */
 - (void) setDoubleValue: (double)aDouble
 {
   NSCell *selected = [self selectedCell];
@@ -193,6 +227,11 @@ static Class actionCellClass;
     }
 }
 
+/** <p>Sets the value of the NSControl's selected cell to float.
+    If the selected cell is an action cell, it marks self for display.</p>
+    <p>See Also: -floatValue [NSCell-setFloatValue:] -setIntValue: 
+    -setStringValue: -setDoubleValue:</p>
+ */
 - (void) setFloatValue: (float)aFloat
 {
   NSCell *selected = [self selectedCell];
@@ -208,6 +247,11 @@ static Class actionCellClass;
     }
 }
 
+/** <p>Sets the value of the NSControl's selected cell to int.
+    If the selected cell is an action cell, it marks self for display.</p>
+    <p>See Also: -intValue [NSCell-setIntValue:] -setDoubleValue: 
+    -setFloatValue: -setStringValue:</p>
+ */
 - (void) setIntValue: (int)anInt
 {
   NSCell *selected = [self selectedCell];
@@ -223,6 +267,11 @@ static Class actionCellClass;
     }
 }
 
+/** <p>Sets the value of the NSControl's selected cell to NSString.
+    If the selected cell is an action cell, it marks self for display.</p>
+    <p>See Also: -stringValue [NSCell-setStringValue:] -setIntValue:
+    -setFloatValue: -setDoubleValue:</p>
+ */
 - (void) setStringValue: (NSString *)aString
 {
   NSCell *selected = [self selectedCell];
@@ -253,26 +302,37 @@ static Class actionCellClass;
     }
 }
 
+/** <p>Marks self for display.</p>
+*/
 - (void) setNeedsDisplay
 {
   [super setNeedsDisplay: YES];
 }
 
-/*
- * Interacting with Other Controls
- */
+/**<p>Sets the NSControl's selected cell to the sender's double value.</p>
+   <p>See Also: [NSCell-takeDoubleValueFrom:] -takeFloatValueFrom: 
+   takeIntValueFrom: takeStringValueFrom:</p> 
+*/
 - (void) takeDoubleValueFrom: (id)sender
 {
   [[self selectedCell] takeDoubleValueFrom: sender];
   [self setNeedsDisplay: YES];
 }
 
+/**<p>Sets the NSControl's selected cell to the sender's float value.</p>
+   <p>See Also: [NSCell-takeDoubleValueFrom:] -takeDoubleValueFrom: 
+   -takeIntValueFrom: -takeStringValueFrom:</p> 
+*/
 - (void) takeFloatValueFrom: (id)sender
 {
   [[self selectedCell] takeFloatValueFrom: sender];
   [self setNeedsDisplay: YES];
 }
 
+/**<p>Sets the NSControl's selected cell to the sender's float int.</p>
+   <p>See Also: [NSCell-takeDoubleValueFrom:] -takeDoubleValueFrom: 
+   -takeFloatValueFrom: -takeStringValueFrom:</p> 
+*/
 - (void) takeIntValueFrom: (id)sender
 {
   [[self selectedCell] takeIntValueFrom: sender];
@@ -285,14 +345,20 @@ static Class actionCellClass;
   [self setNeedsDisplay: YES];
 }
 
+/**<p>Sets the NSControl's selected cell to the sender's float int.</p>
+   <p>See Also: [NSCell-takeDoubleValueFrom:] -takeDoubleValueFrom: 
+   -takeFloatValueFrom: -takeIntValueFrom:</p> 
+*/
 - (void) takeStringValueFrom: (id)sender
 {
   [[self selectedCell] takeStringValueFrom: sender];
   [self setNeedsDisplay: YES];
 }
 
-/*
- * Formatting Text
+/**<p>Returns the alignment of the text in the NSControl's cell.
+   Returns NSNaturalTextAlignment if the cell does not exists.
+   See <ref type="type" id="NSTextAlignment">NSTextAlignment</ref> for
+   more informations.</p><p>See Also: -setAlignment: [NSCell-alignment] </p>
  */
 - (NSTextAlignment) alignment
 {
@@ -302,6 +368,9 @@ static Class actionCellClass;
     return NSNaturalTextAlignment;
 }
 
+/**<p>Returns the font of the text in the NSControl's cell. Returns nil if
+   the cell does not exists.</p><p>See Also: -setFont: [NSCell-font]</p>
+ */
 - (NSFont *) font
 {
   if (_cell)
@@ -310,6 +379,12 @@ static Class actionCellClass;
     return nil;
 }
 
+/**<p>Sets the alignment of the text in the NSControl's cell to 
+   <var>mode</var>. This method abort the editing and  marks self for display 
+   if the cell is an NSActionCell. See <ref type="type" id="NSTextAlignment">
+   NSTextAlignment</ref> for more informations.</p>
+   <p>See Also: -alignment [NSCell-setAlignment:] -abortEditing</p>
+ */
 - (void) setAlignment: (NSTextAlignment)mode
 {
   if (_cell)
@@ -322,6 +397,10 @@ static Class actionCellClass;
     }
 }
 
+/**<p>Sets the font of the text in the NSControl's cell and the
+   editor object (if exists) to fontObject.</p>
+   <p>See Also: -font [NSCell-setFont:] -currentEditor</p>
+ */
 - (void) setFont: (NSFont *)fontObject
 {
   if (_cell)
@@ -361,56 +440,61 @@ static Class actionCellClass;
   return [_cell formatter];
 }
 
-/*
- * Managing the Field Editor
+/**<p>Sends an [NSCell-endEditing:] message to the current object used to
+   edit the NSControl. Returns NO if the the currentEditor does not exists, 
+   YES otherwise.</p>
  */
 - (BOOL) abortEditing
 {
-  NSText *t;
+  NSText *text;
 
-  t = [self currentEditor];
-  if (t == nil)
+  text = [self currentEditor];
+  if (text == nil)
     {
       return NO;
     }
 
-  [[self selectedCell] endEditing: t];
+  [[self selectedCell] endEditing: text];
   return YES;
 }
 
+/**<p>Returns the NSText object used when editing the NSControl.</p>
+ */
 - (NSText *) currentEditor
 {
   if (_cell != nil)
     {
-      NSText *t;
+      NSText *text;
 
-      t = [_window fieldEditor: NO forObject: self];
-      if (([t delegate] == self) && ([_window firstResponder] == t))
+      text = [_window fieldEditor: NO forObject: self];
+      if (([text delegate] == self) && ([_window firstResponder] == text))
         {
-	  return t;
+	  return text;
 	}
     }
 
   return nil;
 }
 
+/**
+ */
 - (void) validateEditing
 {
-  NSText *t;
+  NSText *text;
 
-  t = [self currentEditor];
-  if (t == nil)
+  text = [self currentEditor];
+  if (text == nil)
     {
       return;
     }
 
-  if ([t isRichText])
+  if ([text isRichText])
     {
       NSAttributedString *attr;
       NSTextStorage *storage;
       int len;
       
-      storage = [(NSTextView*)t textStorage];
+      storage = [(NSTextView*)text textStorage];
       len = [storage length];
       attr = [storage attributedSubstringFromRange: NSMakeRange(0, len)];
       [[self selectedCell] setAttributedStringValue: attr];
@@ -419,26 +503,28 @@ static Class actionCellClass;
     {
       NSString *string;
 
-      string = AUTORELEASE([[t string] copy]);
+      string = AUTORELEASE([[text string] copy]);
       [[self selectedCell] setStringValue: string];
     }
 }
 
-/*
- * Resizing the Control
+/**<p>Recalculates the internal size by sending [NSCell-calcDrawInfo:] 
+   to the cell.</p>
  */
 - (void) calcSize
 {
   [_cell calcDrawInfo: [self bounds]];
 }
 
+/**<p>Resizes the NSControl to fits the NSControl's cell size.</p> 
+  <p>See Also: [NSCell-cellSize]</p>
+ */
 - (void) sizeToFit
 {
   [self setFrameSize: [_cell cellSize]];
 }
 
-/*
- * Displaying the Control and Cell
+/** <p>Returns whether the NSControl's cell is opaque</p>
  */
 - (BOOL) isOpaque
 {
@@ -450,6 +536,9 @@ static Class actionCellClass;
   [self drawCell: _cell];
 }
 
+/**<p>Redraws a <var>aCell</var> if it is the NSControl's cell.</p>
+   <p>See Also: -setCell: [NSCell-drawWithFrame:inView:]</p>
+ */
 - (void) drawCell: (NSCell *)aCell
 {
   if (_cell == aCell)
@@ -458,6 +547,9 @@ static Class actionCellClass;
     }
 }
 
+/**<p>Redraws a <var>aCell</var>'s inside if it is the NSControl's cell.</p>
+   <p>See Also: -setCell: [NSCell-drawInteriorWithFrame:inView:]</p>
+ */
 - (void) drawCellInside: (NSCell *)aCell
 {
   if (_cell == aCell)
@@ -467,6 +559,9 @@ static Class actionCellClass;
     }
 }
 
+/** <p>Sets the aCell's state to NSOnState and marks self for display
+    if it is the NSControl's cell.</p>
+ */
 - (void) selectCell: (NSCell *)aCell
 {
   if (_cell == aCell)
@@ -476,29 +571,42 @@ static Class actionCellClass;
     }
 }
 
+/** <p>Marks self for display.</p>
+ */
 - (void) updateCell: (NSCell *)aCell
 {
   [self setNeedsDisplay: YES];
 }
 
+/** <p>Marks self for display.</p>
+ */
 - (void) updateCellInside: (NSCell *)aCell
 {
   [self setNeedsDisplay: YES];
 }
 
-/*
- * Target and Action
+/** <p>Returns the NSControl's cell action method.</p>
+    <p>See Also: -setAction: [NSCell-action] </p>
  */
 - (SEL) action
 {
   return [_cell action];
 }
 
+/** <p>Returns whether the NSControl's cell can continuously sends its action
+    message.</p><p>See Also: -setContinuous: [NSCell-isContinuous]</p>
+ */
 - (BOOL) isContinuous
 {
   return [_cell isContinuous];
 }
 
+/**<p>Asks the NSApplication to send an action <var>theAction</var> 
+   with <var>theTarget</var> as target to NSControl.
+   Returns NO if <var>theAction</var> is nil or if NSApplication can 
+   not send the action.</p>
+   <p>See Also: [NSApplication-sendAction:to:from:]</p>
+ */
 - (BOOL) sendAction: (SEL)theAction to: (id)theTarget
 {
   if (theAction)
@@ -512,21 +620,33 @@ static Class actionCellClass;
   return [_cell sendActionOn: mask];
 }
 
+/**<p>Sets the NSControl's cell action method.</p>
+   <p>See Also: -action [NSCell-setAction:]</p>
+*/
 - (void) setAction: (SEL)aSelector
 {
   [_cell setAction: aSelector];
 }
 
+/** <p>Sets whether the NSControl's cell can continuously sends its action 
+    message.</p><p>See Also: -isContinuous [NSCell-setContinuous:]</p>
+*/ 
 - (void) setContinuous: (BOOL)flag
 {
   [_cell setContinuous: flag];
 }
 
+/** <p>Sets the target object of the NSControl's cell to anObject.</p>
+    <p>See Also: -target [NSCell-setTarget:]</p>
+ */
 - (void) setTarget: (id)anObject
 {
   [_cell setTarget: anObject];
 }
 
+/**<p>Returns the target object of the NSControl's cell.</p>
+   <p>See Also: -setTarget: [NSCell-target]</p>
+ */
 - (id) target
 {
   return [_cell target];
@@ -562,14 +682,16 @@ static Class actionCellClass;
   return [selected attributedStringValue];
 }
 
-/*
- * Assigning a Tag
+/** Assigning a Tag
  */
 - (void) setTag: (int)anInt
 {
   _tag = anInt;
 }
 
+/**<p>Returns the NSControl tag</p>
+   <p>See Also: -setTag:</p>
+ */
 - (int) tag
 {
   return _tag;
@@ -604,8 +726,9 @@ static Class actionCellClass;
   return [[self selectedCell] acceptsFirstResponder];
 }
 
-/*
- * Tracking the Mouse
+/** <p>This method is invoked when the user click into the NSControl.</p>
+    
+ * 
  */
 - (void) mouseDown: (NSEvent *)theEvent
 {
@@ -687,16 +810,28 @@ static Class actionCellClass;
     [self sendAction: [self action] to: [self target]];
 }
 
+- (BOOL) shouldBeTreatedAsInkEvent: (NSEvent *)theEvent
+{
+  return NO;
+}
+
 - (void) resetCursorRects
 {
   [_cell resetCursorRect: _bounds inView: self];
 }
 
+/**<p>Returns wheter multiple clicks are ignored.</p>
+   <p>See Also: -setIgnoresMultiClick: -mouseDown:</p>
+ */
 - (BOOL) ignoresMultiClick
 {
   return _ignoresMultiClick;
 }
 
+
+/** <p>Sets wheter multiple clicks are ignored.</p>
+    <p>See Also: -ignoresMultiClick -mouseDown:</p>
+ */
 - (void) setIgnoresMultiClick: (BOOL)flag
 {
   _ignoresMultiClick = flag;
