@@ -22,7 +22,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
@@ -35,9 +35,6 @@
 #include "AppKit/NSSavePanel.h"
 #include "AppKit/NSSelection.h"
 
-// constants
-NSString *NSDataLinkFilenameExtension = @"dlink";
-
 @implementation NSDataLink
 
 //
@@ -60,7 +57,7 @@ NSString *NSDataLinkFilenameExtension = @"dlink";
 //
 - (id)initLinkedToFile:(NSString *)filename
 {
-  if((self = [self init]) != nil)
+  if ((self = [self init]) != nil)
     {
       NSData *data = [NSData dataWithBytes: [filename cString] length: [filename cStringLength]];
       NSSelection *selection = [NSSelection selectionWithDescriptionData: data];
@@ -73,7 +70,7 @@ NSString *NSDataLinkFilenameExtension = @"dlink";
 			managedBy:(NSDataLinkManager *)linkManager
 		  supportingTypes:(NSArray *)newTypes
 {
-  if((self = [self init]) != nil)
+  if ((self = [self init]) != nil)
     {
       ASSIGN(sourceSelection,selection);
       ASSIGN(sourceManager,linkManager);
@@ -133,7 +130,7 @@ NSString *NSDataLinkFilenameExtension = @"dlink";
 {
   NSString *path = filename;
 
-  if([[path pathExtension] isEqual: NSDataLinkFilenameExtension] == NO)
+  if ([[path pathExtension] isEqual: NSDataLinkFilenameExtension] == NO)
     {
       path = [filename stringByAppendingPathExtension: NSDataLinkFilenameExtension];
     }
@@ -228,12 +225,12 @@ NSString *NSDataLinkFilenameExtension = @"dlink";
   // circumstances a link cannot be broken, so this method 
   // always returns YES.
 
-  if([srcDelegate respondsToSelector: @selector(dataLinkManager:didBreakLink:)])
+  if ([srcDelegate respondsToSelector: @selector(dataLinkManager:didBreakLink:)])
     {
       [srcDelegate dataLinkManager: sourceManager didBreakLink: self];
     }
 
-  if([dstDelegate respondsToSelector: @selector(dataLinkManager:didBreakLink:)])
+  if ([dstDelegate respondsToSelector: @selector(dataLinkManager:didBreakLink:)])
     {
       [dstDelegate dataLinkManager: destinationManager didBreakLink: self];
     }
@@ -245,7 +242,7 @@ NSString *NSDataLinkFilenameExtension = @"dlink";
 {
   _flags.isDirty = YES;
 
-  if(updateMode != NSUpdateNever)
+  if (updateMode != NSUpdateNever)
     {
       [sourceManager noteDocumentEdited];
     }
@@ -307,7 +304,7 @@ NSString *NSDataLinkFilenameExtension = @"dlink";
 {
   int version = [aCoder versionForClassName: @"NSDataLink"];
 
-  if(version == 0)
+  if (version == 0)
     {
       BOOL flag = NO;
 
