@@ -22,15 +22,17 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
 #include <Foundation/NSDictionary.h>
 #include <Foundation/NSEnumerator.h>
 #include <Foundation/NSArray.h>
+#include <Foundation/NSArchiver.h>
 #include <AppKit/NSDataLinkManager.h>
 #include <AppKit/NSDataLink.h>
+#include <AppKit/NSPasteboard.h>
 
 @interface NSDataLink (Private)
 - (void) setLastUpdateTime: (NSDate *)date;
@@ -104,14 +106,14 @@
 {
   self = [super init];
 
-  if(self != nil)
+  if (self != nil)
     {
       ASSIGN(delegate,anObject);
       filename = nil;
-      delegateVerifiesLinks = NO;
-      interactsWithUser = NO;
-      isEdited = NO;
-      areLinkOutlinesVisible = NO;
+      _flags.delegateVerifiesLinks = NO;
+      _flags.interactsWithUser = NO;
+      _flags.isEdited = NO;
+      _flags.areLinkOutlinesVisible = NO;
     }
 
   return self;
@@ -122,14 +124,14 @@
 {
   self = [super init];
 
-  if(self != nil)
+  if (self != nil)
     {
       ASSIGN(delegate,anObject);
       ASSIGN(filename,path);
-      delegateVerifiesLinks = NO;
-      interactsWithUser = NO;
-      isEdited = NO;
-      areLinkOutlinesVisible = NO;
+      _flags.delegateVerifiesLinks = NO;
+      _flags.interactsWithUser = NO;
+      _flags.isEdited = NO;
+      _flags.areLinkOutlinesVisible = NO;
     }
 
   return self;
@@ -146,7 +148,7 @@
   [link setDestinationSelection: selection];
   [link setDestinationManager: self];
 
-  if([destinationLinks containsObject: link] == NO)
+  if ([destinationLinks containsObject: link] == NO)
     {
       [destinationLinks addObject: link];
       result = YES;
@@ -158,13 +160,26 @@
 - (BOOL)addLinkAsMarker:(NSDataLink *)link
 		     at:(NSSelection *)selection
 {
-  return NO;
+  // FIXME: Marker?
+  return [self addLink: link at: selection];
 }
 
 - (NSDataLink *)addLinkPreviouslyAt:(NSSelection *)oldSelection
 		     fromPasteboard:(NSPasteboard *)pasteboard
                                  at:(NSSelection *)selection
 {
+  NSData *data = [pasteboard dataForType: NSDataLinkPboardType];
+  NSArray *links = [NSUnarchiver unarchiveObjectWithData: data];
+  NSEnumerator *en = [links objectEnumerator];
+  NSDataLink *link = nil;
+
+  while ((link = [en nextObject]) != nil)
+    {
+	if ([link destinationSelection] == oldSelection)
+	{	    
+	}
+    }
+
   return nil;
 }
 
@@ -174,7 +189,7 @@
   NSEnumerator *en = [allLinks objectEnumerator];
   id obj = nil;
 
-  while((obj = [en nextObject]) != nil)
+  while ((obj = [en nextObject]) != nil)
     {
       [obj break];
     }
@@ -186,7 +201,7 @@
   NSEnumerator *en = [allLinks objectEnumerator];
   id obj = nil;
 
-  while((obj = [en nextObject]) != nil)
+  while ((obj = [en nextObject]) != nil)
     {
       [obj writeToPasteboard: pasteboard];
     }
@@ -197,26 +212,41 @@
 //
 - (void)noteDocumentClosed
 {
+    if ([delegate respondsToSelector: @selector(dataLinkManagerCloseDocument:)])
+    {
+	[delegate dataLinkManagerCloseDocument: self];
+    }
 }
 
 - (void)noteDocumentEdited
 {
+    if ([delegate respondsToSelector: @selector(dataLinkManagerDidEditLinks:)])
+    {
+	[delegate dataLinkManagerDidEditLinks: self];
+    }
 }
 
 - (void)noteDocumentReverted
 {
+    if ([delegate respondsToSelector: @selector(dataLinkManagerDidEditLinks:)])
+    {
+	[delegate dataLinkManagerDidEditLinks: self];
+    }
 }
 
 - (void)noteDocumentSaved
 {
+    // implemented by subclass
 }
 
 - (void)noteDocumentSavedAs:(NSString *)path
 {
+    // implemented by subclass
 }
 
 - (void)noteDocumentSavedTo:(NSString *)path
 {
+    // implemented by subclass
 }
 
 //
@@ -229,7 +259,7 @@
 
 - (BOOL)delegateVerifiesLinks
 {
-  return delegateVerifiesLinks;
+  return _flags.delegateVerifiesLinks;
 }
 
 - (NSString *)filename
@@ -239,22 +269,22 @@
 
 - (BOOL)interactsWithUser
 {
-  return interactsWithUser;
+  return _flags.interactsWithUser;
 }
 
 - (BOOL)isEdited
 {
-  return isEdited;
+  return _flags.isEdited;
 }
 
 - (void)setDelegateVerifiesLinks:(BOOL)flag
 {
-  delegateVerifiesLinks = flag;
+  _flags.delegateVerifiesLinks = flag;
 }
 
 - (void)setInteractsWithUser:(BOOL)flag
 {
-  interactsWithUser = flag;
+  _flags.interactsWithUser = flag;
 }
 
 //
@@ -262,7 +292,7 @@
 //
 - (BOOL)areLinkOutlinesVisible
 {
-  return areLinkOutlinesVisible;
+  return _flags.areLinkOutlinesVisible;
 }
 
 - (NSEnumerator *)destinationLinkEnumerator
@@ -275,9 +305,9 @@
   NSEnumerator *en = [self destinationLinkEnumerator];
   id obj = nil;
 
-  while((obj = [en nextObject]) != nil)
+  while ((obj = [en nextObject]) != nil)
     {
-      if([obj destinationSelection] == destSel)
+      if ([obj destinationSelection] == destSel)
 	{
 	  break;
 	}
@@ -288,7 +318,7 @@
 
 - (void)setLinkOutlinesVisible:(BOOL)flag
 {
-  areLinkOutlinesVisible = flag;
+  _flags.areLinkOutlinesVisible = flag;
 }
 
 - (NSEnumerator *)sourceLinkEnumerator
@@ -307,13 +337,13 @@
   [aCoder encodeValueOfObjCType: @encode(id)  at: &sourceLinks];
   [aCoder encodeValueOfObjCType: @encode(id)  at: &destinationLinks];
 
-  flag = areLinkOutlinesVisible;
+  flag = _flags.areLinkOutlinesVisible;
   [aCoder encodeValueOfObjCType: @encode(BOOL)  at: &flag];
-  flag = delegateVerifiesLinks;
+  flag = _flags.delegateVerifiesLinks;
   [aCoder encodeValueOfObjCType: @encode(BOOL)  at: &flag];
-  flag = interactsWithUser;
+  flag = _flags.interactsWithUser;
   [aCoder encodeValueOfObjCType: @encode(BOOL)  at: &flag];
-  flag = isEdited;
+  flag = _flags.isEdited;
   [aCoder encodeValueOfObjCType: @encode(BOOL)  at: &flag];
 }
 
@@ -321,7 +351,7 @@
 {
   int version = [aCoder versionForClassName: @"NSDataLinkManager"];
 
-  if(version == 0)
+  if (version == 0)
     {
       BOOL flag = NO;
       
@@ -330,13 +360,13 @@
       [aCoder decodeValueOfObjCType: @encode(id)  at: &destinationLinks];
       
       [aCoder decodeValueOfObjCType: @encode(BOOL)  at: &flag];
-      areLinkOutlinesVisible = flag;
+      _flags.areLinkOutlinesVisible = flag;
       [aCoder decodeValueOfObjCType: @encode(BOOL)  at: &flag];
-      delegateVerifiesLinks = flag;
+      _flags.delegateVerifiesLinks = flag;
       [aCoder decodeValueOfObjCType: @encode(BOOL)  at: &flag];
-      interactsWithUser = flag;
+      _flags.interactsWithUser = flag;
       [aCoder decodeValueOfObjCType: @encode(BOOL)  at: &flag];
-      isEdited = flag;
+      _flags.isEdited = flag;
     }
   else
     {
