@@ -24,7 +24,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <Foundation/NSData.h>
@@ -589,13 +589,13 @@
     }
   else if (sel_eq(action, @selector(undo:)))
     {
-      if(_undoManager == nil)
+      if (_undoManager == nil)
 	{
 	  result = NO;
 	}
       else
 	{
-	  if([_undoManager canUndo])
+	  if ([_undoManager canUndo])
 	    {
 	      [anItem setTitle: [_undoManager undoMenuItemTitle]];
 	      result = YES;
@@ -609,13 +609,13 @@
     }
   else if (sel_eq(action, @selector(redo:)))
     {
-      if(_undoManager == nil)
+      if (_undoManager == nil)
 	{
 	  result = NO;
 	}
       else
 	{
-	  if([_undoManager canRedo])
+	  if ([_undoManager canRedo])
 	    {
 	      [anItem setTitle: [_undoManager redoMenuItemTitle]];
 	      result = YES;
