@@ -24,7 +24,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
@@ -49,6 +49,8 @@ static NSColor	*shadowCol;
 }
 @end
 
+/** <p>TODO Description </p>
+ */
 @implementation NSFormCell
 + (void) initialize
 {
@@ -65,14 +67,20 @@ static NSColor	*shadowCol;
 }
 
 /* The title attributes are those inherited from the NSActionCell class. */
-- init
+- (id) init
 {
   return [self initTextCell: @"Field:"];
 }
 
-- initTextCell: (NSString *)aString
+/** <p>Initializes and returns new NSFormCell with aString as its title and
+    the text cell with an empty NSString.</p>
+    <p>See Also: [NSCell-initTextCell:]</p>
+ */
+- (id) initTextCell: (NSString *)aString
 {
-  self = [super initTextCell: @""];
+  if (! ( self = [super initTextCell: @""] ) )
+    return nil;
+  
   _cell.is_bezeled = YES;
   _cell.is_editable = YES;
   [self setAlignment: NSLeftTextAlignment];
@@ -80,6 +88,7 @@ static NSColor	*shadowCol;
   [_titleCell setAlignment: NSRightTextAlignment];
   _formcell_auto_title_width = YES;
   _displayedTitleWidth = -1;
+
   return self;
 }
 
@@ -89,6 +98,10 @@ static NSColor	*shadowCol;
   [super dealloc];
 }
 
+/** <p>Returns whether the NSFormCell is Opaque. Returns YES if 
+    the textCell and the title cell are both Opaque, NO otherwise</p>
+    <p>See Also: [NSCell-isOpaque]</p>
+ */
 - (BOOL)isOpaque
 {
   return [_titleCell isOpaque] && [super isOpaque];
@@ -108,9 +121,13 @@ static NSColor	*shadowCol;
     }
 }
 
+/** <p> Sets the NSFormCell title to aString. 
+    TODO => _formcell_auto_title_width / Update the control(s)</p>
+ */
 - (void)setTitle: (NSString*)aString
 {
   [_titleCell setStringValue: aString];
+  
   if (_formcell_auto_title_width)
     {
       // Invalidates title width 
@@ -136,11 +153,19 @@ static NSColor	*shadowCol;
     }
 }
 
+/** <p>Sets the text alignment of the NSFormCell's title to mode.
+     NSRightTextAlignment by default. See <ref type="type" 
+     id="NSTextAlignment">NSTextAlignment</ref> for more informations.
+     </p><p>See Also: -titleAlignment [NSCell-setAlignment:]</p>
+ */
 - (void)setTitleAlignment:(NSTextAlignment)mode
 {
   [_titleCell setAlignment: mode];
 }
 
+/** <p>Set the text font of the NSFormCell's title to fontObject.</p>
+    <p>See Also: -titleFont [NSCell-setFont:]</p>
+ */
 - (void)setTitleFont: (NSFont*)fontObject
 {
   [_titleCell setFont: fontObject];
@@ -155,6 +180,9 @@ static NSColor	*shadowCol;
     }
 }
 
+/**<p>Sets the width of the NSFormCell's title to width. All NSFormCell
+   of the NSForm are updated</p><p>See Also: -titleWidth</p>
+*/
 - (void)setTitleWidth: (float)width
 {
   if (width >= 0)
@@ -180,16 +208,26 @@ static NSColor	*shadowCol;
   return [_titleCell attributedStringValue];
 }
 
+/** <p>Returns the NSFormCell's title.</p>
+    <p>See Also: -setTitle: [NSCell-stringValue]</p>
+ */
 - (NSString*)title
 {
   return [_titleCell stringValue];
 }
 
+/** <p>Returns the text alignment of the NSFormCell's title. 
+    NSRightTextAlignment by default. See NSTextAlignment for more informations
+    </p><p>See Also: -setTitleAlignment:</p>
+ */
 - (NSTextAlignment)titleAlignment
 {
   return [_titleCell alignment];
 }
 
+/** <p>Returns the text font of the NSFormCell's title</p>
+    <p>See Also: -setTitleFont: [NSCell-font]</p>
+ */
 - (NSFont*)titleFont
 {
   return [_titleCell font];
