@@ -23,7 +23,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include <Foundation/NSNotification.h>
@@ -48,12 +48,12 @@
     RETAIN([NSDictionary dictionaryWithContentsOfFile: 
 			     [self pathForResource: @"Help" ofType: @"plist"]]);
 
-  if(contextHelp)
+  if (contextHelp)
     {
       helpFile = [contextHelp objectForKey: key];
     }
 
-  if(helpFile)
+  if (helpFile)
     {
       return [NSUnarchiver unarchiveObjectWithData:
 			     [helpFile objectForKey: @"NSHelpRTFContents"]];
@@ -83,7 +83,7 @@
 
   help = [info objectForKey: @"GSHelpContentsFile"];
 
-  if(!help)
+  if (!help)
     {
       help = [info objectForKey: @"NSExecutable"];
       // If there's no specification, we look for a file named "appname.rtf"
@@ -176,9 +176,9 @@ static BOOL _gnu_contextHelpActive = NO;
   // their context help is.
      
   id hc = NSMapGet(contextHelpTopics, object);
-  if(hc)
+  if (hc)
     {
-      if(![hc isKindOfClass: [NSAttributedString class]])
+      if (![hc isKindOfClass: [NSAttributedString class]])
 	{
 	  hc = [[NSBundle mainBundle] contextHelpForKey: hc];
 	  /* We store the retrieved value, or remove the key from
