@@ -20,7 +20,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
    */ 
 #include "config.h"
 #include <string.h>
@@ -192,6 +192,9 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
     }
 }
 
+/** <p>Returns the NSImage named aName. The search is done in the main bundle
+    first and then in the usual images directories</p>
+ */
 + (id) imageNamed: (NSString *)aName
 {
   NSString	*realName = [nsmapping objectForKey: aName];
@@ -310,7 +313,9 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   return [self initWithSize: NSMakeSize(0, 0)];
 }
 
-// Designated initializer for nearly everything.
+/** <p>Initialize and returns a new NSImage with <var>aSize</var> as specified
+    size.</p><p>See Also: -setSize: -size </p>
+ */
 - (id) initWithSize: (NSSize)aSize
 {
   [super init];
@@ -351,9 +356,15 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   return self;
 }
 
+
+/** <p>Initializes and returns a new NSImage from the file 
+    <var>fileName</var>. <var>fileName</var> should be an absolute path.</p>
+    <p>See Also: [NSImageRep+imageRepsWithContentsOfFile:]</p>
+ */
 - (id) initWithContentsOfFile: (NSString *)fileName
 {
-  self = [self init];
+  if ( ! ( self = [self init] ) )
+    return nil;
 
   _flags.dataRetained = YES;
   if (![self _loadFromFile: fileName])
@@ -365,9 +376,13 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   return self;
 }
 
+/**<p>Initializes and returns a new NSImage from the NSData data.</p>
+   <p>See Also: [NSImageRep+imageRepWithData:]</p>
+ */
 - (id) initWithData: (NSData *)data
 {
-  self = [self init];
+  if (! ( self = [self init] ) )
+    return nil;
 
   _flags.dataRetained = YES;
   if (![self _loadFromData: data])
@@ -425,10 +440,19 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   return self;
 }
 
+/** <p>Initializes and returns a new NSImage from the data in pasteboard.
+    the pasteboard types can be whose defined in  
+    [NSImageRep+imagePasteboardTypes] or NSFilenamesPboardType</p>
+    <p>See Also: [NSImageRep+imageRepsWithPasteboard:</p>
+ */
 - (id) initWithPasteboard: (NSPasteboard *)pasteboard
 {
-  NSArray *reps = [NSImageRep imageRepsWithPasteboard: pasteboard];
-  self = [self init];
+  NSArray *reps;
+
+  if ( ! ( self = [self init] ) )
+    return nil;
+  
+  reps = [NSImageRep imageRepsWithPasteboard: pasteboard];
 
   if (reps != nil)
     [self addRepresentations: reps]; 
@@ -524,6 +548,10 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   return _name;
 }
 
+/** <p>Sets the NSImage size to aSize. Changing the size recreate
+    the cache</p>
+    <p>See Also: -size -initWithSize:</p>
+ */
 - (void) setSize: (NSSize)aSize
 {
   // Optimized as this is called very often from NSImageCell
@@ -536,6 +564,10 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   [self recache];
 }
 
+/**<p> Returns NSImage size if the size have been set. Returns the
+   size of the best representation otherwise.</p>
+   <p>See Also: -setSize: -initWithSize:</p>
+ */
 - (NSSize) size
 {
   if (_size.width == 0) 
@@ -661,7 +693,7 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   unsigned i;
 
   i = [_reps count];
-  while(i--) 
+  while (i--) 
     {
       GSRepData	*repd;
 
@@ -683,6 +715,9 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   return _flags.scalable;
 }
 
+/**<p>Sets the color of the NSImage's background to <var>aColor</var></p>
+   <p>See Also: -backgroundColor</p>
+ */
 - (void) setBackgroundColor: (NSColor *)aColor
 {
   if (aColor == nil)
@@ -692,6 +727,9 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   ASSIGN(_color, aColor);
 }
 
+/**<p>Returns the color of the NSImage's background</p>
+   <p>See Also: -setBackgroundColor:</p>
+ */
 - (NSColor *) backgroundColor
 {
   return _color;
@@ -714,6 +752,12 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
 		 fromRect: (NSRect)aRect
 		operation: (NSCompositingOperation)op
 {
+#if 0
+  [self compositeToPoint: aPoint
+	fromRect: aRect
+	operation: op
+	fraction: 1.0];
+#else 
   NSImageRep *rep = nil;
 
   NS_DURING
@@ -762,6 +806,7 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
 	}
     }
   NS_ENDHANDLER
+#endif
 }
 
 - (void) compositeToPoint: (NSPoint)aPoint
@@ -777,11 +822,61 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
 }
 
 - (void) compositeToPoint: (NSPoint)aPoint
-		 fromRect: (NSRect)srcRect
+		 fromRect: (NSRect)aRect
 		operation: (NSCompositingOperation)op
 		 fraction: (float)delta
 {
-// FIXME We need another PS command for this
+  NSImageRep *rep = nil;
+
+  NS_DURING
+    { 
+      if ([GSCurrentContext() isDrawingToScreen] == YES)
+	  rep = [self _doImageCache];
+      if (rep
+	  &&_cacheMode != NSImageCacheNever 
+	  && [rep isKindOfClass: cachedClass])
+        {
+	  NSRect rect;
+
+	  rect = [(NSCachedImageRep *)rep rect];
+	  NSDebugLLog(@"NSImage", @"composite rect %@ in %@", 
+		      NSStringFromRect(rect), NSStringFromRect(aRect));
+	  // Move the drawing rectangle to the origin of the image rep
+	  // and intersect the two rects.
+	  aRect.origin.x += rect.origin.x;
+	  aRect.origin.y += rect.origin.y;
+	  rect = NSIntersectionRect(aRect, rect);
+
+	  [GSCurrentContext() GScomposite: [[(NSCachedImageRep *)rep window] gState]
+			   toPoint: aPoint
+			   fromRect: rect
+			   operation: op
+			   fraction: delta];
+	}
+      else	
+        {
+	  NSRect rect;
+          rep = [self bestRepresentationForDevice: nil];
+	  rect = NSMakeRect(aPoint.x, aPoint.y, _size.width, _size.height);
+	  [self drawRepresentation: rep inRect: rect];
+	}
+    }
+  NS_HANDLER
+    {
+      NSLog(@"NSImage: compositeToPoint:fromRect:operation:fraction: failed due to %@: %@", 
+	    [localException name], [localException reason]);
+      if ([_delegate respondsToSelector: @selector(imageDidNotDraw:inRect:)])
+        {
+	  NSImage *image = [_delegate imageDidNotDraw: self inRect: aRect];
+
+	  if (image != nil)
+	    [image compositeToPoint: aPoint
+		   fromRect: aRect 
+		   operation: op
+		   fraction: delta];
+	}
+    }
+  NS_ENDHANDLER
 }
 
 - (void) dissolveToPoint: (NSPoint)aPoint fraction: (float)aFloat
@@ -797,6 +892,12 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
 		fromRect: (NSRect)aRect 
 		fraction: (float)aFloat
 {
+#if 0
+  [self compositeToPoint: aPoint
+	fromRect: aRect
+	operation: NSCompositeSourceOver
+	fraction: aFloat];
+#else 
   NSImageRep *rep = nil;
 
   NS_DURING
@@ -845,6 +946,7 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
 	}
     }
   NS_ENDHANDLER
+#endif
 }
 
 - (BOOL) drawRepresentation: (NSImageRep *)imageRep inRect: (NSRect)aRect
@@ -1058,6 +1160,10 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   }
 }
 
+/** <p>Adds the NSImageRep imageRep to the NSImage's representations array.
+    </p><p>See Also: -addRepresentations: removeRepresentation:</p>
+ */
+
 - (void) addRepresentation: (NSImageRep *)imageRep
 {
   GSRepData	*repd;
@@ -1068,6 +1174,10 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
   RELEASE(repd);
 }
 
+/** <p>Adds the NSImageRep array imageRepArray to the NSImage's
+    representations array.</p>
+    <p>See Also: -addRepresentation: -removeRepresentation:</p>
+ */
 - (void) addRepresentations: (NSArray *)imageRepArray
 {
   unsigned	i, count;
@@ -1083,6 +1193,9 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
     }
 }
 
+/** <p>Remove the NSImageRep imageRep from the NSImage's representations 
+    array</p><p>See Also: -addRepresentations: -addRepresentation:</p>
+ */
 - (void) removeRepresentation: (NSImageRep *)imageRep
 {
   unsigned	i;
@@ -1103,11 +1216,17 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
     }
 }
 
+/** <p>Locks the focus on the best representation</p>
+    <p>See Also: -lockFocusOnRepresentation:</p>
+ */
 - (void) lockFocus
 {
   [self lockFocusOnRepresentation: nil];
 }
 
+/**<p>Locks the focus in the imageRep. if imageRep is nil this method
+   locks the focus on the best representation</p>
+ */
 - (void) lockFocusOnRepresentation: (NSImageRep *)imageRep
 {
   if (_cacheMode != NSImageCacheNever)
@@ -1299,10 +1418,8 @@ repd_for_rep(NSArray *_reps, NSImageRep *rep)
     {
       if ([GSCurrentContext() isDrawingToScreen] == YES)
         {
-          int screen = [[[GSCurrentServer() attributes] 
-			  objectForKey: GSScreenNumber] intValue];
-          deviceDescription = [[[NSScreen screens] objectAtIndex: screen] 
-				deviceDescription];
+	    // Take the device description from the current context.
+	    deviceDescription = [GSCurrentContext() attributes];
         }
       else if ([NSPrintOperation currentOperation])
         {
