@@ -22,7 +22,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "config.h"
@@ -67,7 +67,7 @@
 
 - (void)setObjectValue:(id)object
 {
-  if ([object isKindOfClass:[NSImage class]])
+    if ((object == nil) || ([object isKindOfClass:[NSImage class]]))
     {
       [self setImage: object];
     }
@@ -124,7 +124,7 @@
   NSDebugLLog(@"NSImageCell", @"NSImageCell -drawWithFrame");
 
   // do nothing if cell's frame rect is zero
-  if (NSIsEmptyRect(cellFrame) || ![controlView window])
+  if (NSIsEmptyRect(cellFrame))
     return;
   
   // draw the border if needed
@@ -215,7 +215,7 @@ scaleProportionally(NSSize imageSize, NSRect canvasRect)
 
   NSDebugLLog(@"NSImageCell", @"NSImageCell drawInteriorWithFrame called");
 
-  if (![controlView window] || !_cell_image)
+  if (!_cell_image)
     return;
 
   // leave room for the frame
@@ -314,6 +314,7 @@ scaleProportionally(NSSize imageSize, NSRect canvasRect)
   switch (_frameStyle)
     {
       case NSImageFrameNone:
+      default:
 	borderSize = NSZeroSize;
 	break;
       case NSImageFramePhoto:
@@ -344,18 +345,19 @@ scaleProportionally(NSSize imageSize, NSRect canvasRect)
   // Get border size
   switch (_frameStyle)
     {
-    case NSImageFrameNone:
-      borderSize = NSZeroSize;
-      break;
-    case NSImageFramePhoto:
-      // what does this one look like? TODO (in sync with the rest of the code)
-      borderSize = _sizeForBorderType (NSNoBorder);
-      break;
-    case NSImageFrameGrayBezel:
-    case NSImageFrameGroove:
-    case NSImageFrameButton:
-      borderSize = _sizeForBorderType (NSBezelBorder); 
-      break;
+      case NSImageFrameNone:
+      default:
+	borderSize = NSZeroSize;
+	break;
+      case NSImageFramePhoto:
+	// what does this one look like? TODO (in sync with the rest of the code)
+	borderSize = _sizeForBorderType (NSNoBorder);
+	break;
+      case NSImageFrameGrayBezel:
+      case NSImageFrameGroove:
+      case NSImageFrameButton:
+	borderSize = _sizeForBorderType (NSBezelBorder); 
+	break;
     }
 
   return NSInsetRect (theRect, borderSize.width, borderSize.height);
