@@ -20,7 +20,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
@@ -503,10 +503,6 @@ static NSImage	*arrowImage = nil;	/* Cache arrow image.	*/
   if (NSIsEmptyRect(cellFrame))
     return;
 
-  // Do nothing if the window is deferred
-  if ([[controlView window] gState] == 0)
-    return;
-
   // Draw the border if needed
   [self drawBorderAndBackgroundWithFrame: cellFrame inView: controlView];
 
