@@ -24,7 +24,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <Foundation/NSRunLoop.h>
@@ -91,8 +91,8 @@ _addLeftBorderOffsetToRect(NSRect aRect)
   return YES;
 }
 
-// We do not want to popup menus in this menu.
-- (id) menuForEvent: (NSEvent*) theEvent
+// We do not want to popup menus in this menu view.
+- (NSMenu *) menuForEvent: (NSEvent*) theEvent
 {
   NSDebugLLog (@"NSMenu", @"Query for menu in view");
   return nil;
