@@ -34,7 +34,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <Foundation/NSString.h>
@@ -238,8 +238,8 @@ static NSOpenPanel *_gs_gui_open_panel = nil;
     or NSCancelButton depending on which button the user pressed.
     </p>
     <p>
-    Use the -filename or -filenames method to retrieve the name of the
-    file the user selected.
+    Use the [NSSavePanel-filename] or -filenames method to retrieve
+    the name of the file the user selected.
     </p>
  */
 @implementation NSOpenPanel
@@ -255,10 +255,8 @@ static NSOpenPanel *_gs_gui_open_panel = nil;
   }
 }
 
-/*
- * Accessing the NSOpenPanel shared instance
- */
-/** Returns the shared NSOpenPanel instance */
+/**<p>Creates ( if needed ) and returns the shared NSOpenPanel instance.</p> 
+*/
 + (NSOpenPanel *) openPanel
 {
   if (!_gs_gui_open_panel)
@@ -290,47 +288,62 @@ static NSOpenPanel *_gs_gui_open_panel = nil;
 /*
  * Filtering Files
  */
-/** Allows the user to select multiple files if flag is YES. */
+/**<p> Allows the user to select multiple files if flag is YES.
+   The default behavior is not to allow multiple selections</p><p>See Also:
+   -allowsMultipleSelection [NSBrowser-setAllowsMultipleSelection:]</p>
+*/
 - (void) setAllowsMultipleSelection: (BOOL)flag
 {
   [_browser setAllowsMultipleSelection: flag];
 }
 
-/** Returns YES if the user is allowed to select multiple files. The
-    default behavior is not to allow mutiple selections. */
+/**<p>Returns YES if the user is allowed to select multiple files. The
+   default behavior is not to allow mutiple selections.</p><p>See Also:
+   -setAllowsMultipleSelection: [NSBrowser-allowsMultipleSelection]</p>
+*/
 - (BOOL) allowsMultipleSelection
 {
   return [_browser allowsMultipleSelection];
 }
 
-/** Allows the user to choose directories if flag is YES. */
+/**<p>Allows the user to choose directories if flag is YES. The default 
+   behavior is to allow choosing directories.</p>
+   <p>See Also: -canChooseDirectories [NSBrowser-setAllowsBranchSelection:]</p>
+*/
 - (void) setCanChooseDirectories: (BOOL)flag
 {
   _canChooseDirectories = flag;
   [_browser setAllowsBranchSelection: flag];
 }
 
-/** Returns YES if the user is allowed to choose directories  The
-    default behavior is to allow choosing directories. */
+/** <p>Returns YES if the user is allowed to choose directories  The
+    default behavior is to allow choosing directories.</p>
+    <p>See Also: -setCanChooseDirectories:</p>
+ */
 - (BOOL) canChooseDirectories
 {
   return _canChooseDirectories;
 }
 
-/** Allows the user to choose files if flag is YES */
+/** <p>Allows the user to choose files if flag is YES.The default behavior it
+    to allow choosing files. </p><p>See Also: -canChooseFiles</p>
+*/
 - (void) setCanChooseFiles: (BOOL)flag
 {
   _canChooseFiles = flag;
 }
 
-/** Returns YES if the user is allowed to choose files.  The
-    default behavior it to allow choosing files.  */
+/**<p>Returns YES if the user is allowed to choose files.  The
+    default behavior it to allow choosing files.</p>
+    <p>See Also: -setCanChooseFiles:</p>
+*/
 - (BOOL) canChooseFiles
 {
   return _canChooseFiles;
 }
 
-/** Returns the absolute path of the file selected by the user.  */
+/** <p>Returns the absolute path of the file selected by the user.</p>
+*/
 - (NSString*) filename
 {
   NSArray *ret;
@@ -343,9 +356,9 @@ static NSOpenPanel *_gs_gui_open_panel = nil;
     return nil;
 }
 
-/** Returns an array containing the absolute paths (as NSString
- objects) of the selected files and directories.  If multiple
- selections aren't allowed, the array contains a single name.
+/**<p>Returns an array containing the absolute paths (as NSString
+   objects) of the selected files and directories.  If multiple
+   selections aren't allowed, the array contains a single name.</p>
 */
 - (NSArray *) filenames
 {
@@ -408,8 +421,9 @@ static NSOpenPanel *_gs_gui_open_panel = nil;
 /*
  * Running the NSOpenPanel
  */
-/** Displays the open panel in a modal session, filtering for
-    files that have the specified types 
+/**<p>Displays the open panel in a modal session, filtering for
+   files that have the specified types </p>
+   <p>See Also: -runModalForDirectory:file:types:</p>
 */
 - (int) runModalForTypes: (NSArray *)fileTypes
 {
@@ -418,10 +432,11 @@ static NSOpenPanel *_gs_gui_open_panel = nil;
 			      types: fileTypes];
 }
 
-/** Displays the open panel in a modal session, with the directory
+/** <p>Displays the open panel in a modal session, with the directory
     path shown and file name (if any) selected. Files are filtered for the
     specified types. If the directory is nil, then the directory shown in 
-    the open panel is the last directory selected.
+    the open panel is the last directory selected.</p>
+    <p>See Also: -runModalForTypes:</p>
 */
 - (int) runModalForDirectory: (NSString *)path
 			file: (NSString *)name
