@@ -23,7 +23,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 
 <chapter>
@@ -1991,17 +1991,16 @@ static  NSMapTable              *mimeMap = NULL;
 	    }
 	  else
 	    {
-	      NSDistributedNotificationCenter *nc;
+	      NSNotificationCenter *nc;
 	      NSMutableArray *startIndicator;
 	      NSArray *args = nil;
 	      NSDate *timeoutDate;
 
-	      NSLog(@"\nI couldn't contact the pasteboard server for %@ -\n"
+	      NSDebugLLog(@"NSPasteboard",
+@"\nI couldn't contact the pasteboard server for %@ -\n"
 @"so I'm attempting to start one - which might take a few seconds.\n"
-@"Trying to launch gpbs from %@ or a machine/operating-system subdirectory.\n"
-@"It is recommended that you start the pasteboard server (gpbs) when\n"
-@"your windowing system is started up.\n", description,
-[cmd stringByDeletingLastPathComponent]);
+@"Trying to launch gpbs from %@ or a machine/operating-system subdirectory.\n",
+description, [cmd stringByDeletingLastPathComponent]);
 
 	      if ([host length] > 0)
 		{
