@@ -29,7 +29,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include <math.h>
@@ -879,7 +879,7 @@ scaleRect(NSRect rect, double scale)
     {
       viewPageRange = NSMakeRange(1, (info.xpages * info.ypages));
     }
-  [dict setObject: NSNUMBER(NSMaxRange(viewPageRange) )
+  [dict setObject: NSNUMBER(NSMaxRange(viewPageRange))
 	   forKey: @"NSPrintTotalPages"];
   if (allPages == YES)
     {
@@ -986,7 +986,7 @@ scaleRect(NSRect rect, double scale)
     } /* Print each page */
   
   /* Make sure we end the sheet */
-  if ( info.nup > 1 && (info.last - info.first) % info.nup != info.nup - 1 )
+  if (info.nup > 1 && (info.last - info.first) % info.nup != info.nup - 1)
     {
       [_view drawSheetBorderWithSize: info.paperBounds.size];
       [_view _endSheet];
@@ -1082,7 +1082,7 @@ scaleRect(NSRect rect, double scale)
   [self endPage];
 
   /* End a physical page */
-  if ( ((currentPage - info.first) % info.nup == info.nup-1) )
+  if (((currentPage - info.first) % info.nup == info.nup-1))
     {
       [self drawSheetBorderWithSize: info.paperBounds.size];
       [self _endSheet];
