@@ -25,7 +25,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
 
@@ -85,13 +85,14 @@ static NSPrintPanel *shared_instance;
 
   principalClass = [[GSPrinting printingBundle] principalClass];
 
-  if( principalClass == nil )
+  if (principalClass == nil)
     return nil;
 	
   return [[principalClass printPanelClass] allocWithZone: zone];
 }
 
-/** Creates and returns a shared instance of the NSPrintPanel panel.
+/** Creates ( if needed) and returns a shared instance of the
+    NSPrintPanel panel.
  */
 + (NSPrintPanel *)printPanel
 {
@@ -189,14 +190,16 @@ static NSPrintPanel *shared_instance;
 //
 // Customizing the Panel 
 //
-/** Set the accessory view for the print panel 
+/** <p>Sets the accessory view for the print panel to aView</p>
+    <p>See Also: -accessoryView</p>
  */
 - (void)setAccessoryView:(NSView *)aView
 {
   ASSIGN(_accessoryView, aView);
 }
 
-/** Returns the accessory view for the print panel 
+/** <p>Returns the accessory view for the print panel </p>
+    <p>See Also: -setAccessoryView:</p>
  */
 - (NSView *)accessoryView
 {
@@ -273,7 +276,7 @@ static NSPrintPanel *shared_instance;
     {
       _picked = NSPPPreviewButton;
     }
-  else if (tag ==NSFaxButton )
+  else if (tag ==NSFaxButton)
     {
       _picked = NSFaxButton;
       NSRunAlertPanel(@"Sorry", @"Faxing of print file not implemented", 
