@@ -22,7 +22,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
@@ -60,7 +60,7 @@
 /*
  * Managing the next responder
  */
-- (id) nextResponder
+- (NSResponder*) nextResponder
 {
   return _next_responder;
 }
@@ -180,7 +180,7 @@
 
 - (void) helpRequested: (NSEvent*)theEvent
 {
-  if(![[NSHelpManager sharedHelpManager]
+  if (![[NSHelpManager sharedHelpManager]
 	showContextHelpForObject: self
 	locationHint: [theEvent locationInWindow]])
     if (_next_responder)
@@ -338,19 +338,24 @@
  */
 - (void) encodeWithCoder: (NSCoder*)aCoder
 {
-  if([aCoder allowsKeyedCoding])
+  if ([aCoder allowsKeyedCoding])
     {
-      if(_interface_style != NSNoInterfaceStyle)
+      if (_interface_style != NSNoInterfaceStyle)
 	{
 	  [aCoder encodeInt: _interface_style
 		  forKey: @"NSInterfaceStyle"];
 	}
 
-      if([self menu] != nil)
+      if ([self menu] != nil)
 	{
 	  [aCoder encodeObject: [self menu]
 		  forKey: @"NSMenu"];	  
 	}
+      if ([self nextResponder] != nil)
+	{
+	  [aCoder encodeConditionalObject: [self nextResponder]
+		  forKey: @"NSNextResponder"];	  
+	}
     }
   else
     {
@@ -364,17 +369,22 @@
 {
   id obj = nil;
 
-  if([aDecoder allowsKeyedCoding])
+  if ([aDecoder allowsKeyedCoding])
     {
-      if([aDecoder containsValueForKey: @"NSInterfaceStyle"])
+      if ([aDecoder containsValueForKey: @"NSInterfaceStyle"])
 	{
 	  _interface_style = [aDecoder decodeIntForKey: @"NSInterfaceStyle"];
 	}
 
-      if([aDecoder containsValueForKey: @"NSMenu"])
+      if ([aDecoder containsValueForKey: @"NSMenu"])
 	{
 	  obj = [aDecoder decodeObjectForKey: @"NSMenu"];
 	}
+
+      if ([aDecoder containsValueForKey: @"NSNextResponder"])
+	{
+	  [self setNextResponder: [aDecoder decodeObjectForKey: @"NSNextResponder"]];
+	}
     }
   else
     {
@@ -416,4 +426,10 @@
 {
   return nil;
 }
+
+- (BOOL) shouldBeTreatedAsInkEvent: (NSEvent *)theEvent
+{
+  return NO;
+}
+
 @end
