@@ -25,7 +25,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
 */
 
 #include <Foundation/NSDebug.h>
@@ -144,6 +144,8 @@ static float scrollerWidth;
   _vPageScroll = 10;
   _borderType = NSNoBorder;
   _scrollsDynamically = YES;
+  // For compatibility the ruler should be present but not visible.
+  [self setHasHorizontalRuler: YES];
   [self tile];
 
   return self;
@@ -1031,26 +1033,40 @@ static float scrollerWidth;
   return _borderType;
 }
 
+/** <p>Returns whether the NSScrollView has a horizontal ruler</p>
+    <p>See Also: -setHasHorizontalRuler:</p>
+ */
 - (BOOL) hasHorizontalRuler
 {
   return _hasHorizRuler;
 }
 
+/** <p>Returns whether the NSScrollView has a horizontal scroller</p>
+    <p>See Also: -setHasHorizontalScroller:</p>
+ */
 - (BOOL) hasHorizontalScroller
 {
   return _hasHorizScroller;
 }
 
+/** <p>Returns whether the NSScrollView has a vertical ruler</p>
+    <p>See Also: -setHasVerticalRuler:</p>
+ */
 - (BOOL) hasVerticalRuler
 {
   return _hasVertRuler;
 }
 
+/** <p>Returns whether the NSScrollView has a vertical scroller</p>
+    <p>See Also: -setHasVerticalScroller:</p>
+ */
 - (BOOL) hasVerticalScroller
 {
   return _hasVertScroller;
 }
 
+/**<p>Returns the size of the NSScrollView's content view</p>
+ */
 - (NSSize) contentSize
 {
   return [_contentView bounds].size;
