@@ -28,7 +28,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <math.h>
@@ -103,7 +103,7 @@ static NSNotificationCenter *nc = nil;
   NSApplication	*app = [NSApplication sharedApplication];
   static NSRect	oldRect; //only one can be dragged at a time
   static BOOL	lit = NO;
-  NSPoint	p;
+  NSPoint	p, op;
   NSEvent	*e;
   NSRect	r, r1, bigRect, vis;
   id		v = nil, prev = nil;
@@ -296,6 +296,9 @@ static NSNotificationCenter *nc = nil;
     {
       constrainImp = (floatIMP)[_delegate methodForSelector: constrainSel];
     }
+    
+  // Save the old position
+  op = p;
 
   // user is moving the knob loop until left mouse up
   while ([e type] != NSLeftMouseUp)
@@ -511,7 +514,7 @@ static NSNotificationCenter *nc = nil;
 			  inMode: NSEventTrackingRunLoopMode
 			  dequeue: YES];
 	      }
-	    while(ee != nil);
+	    while (ee != nil);
 	  }
       }
       
@@ -526,6 +529,18 @@ static NSNotificationCenter *nc = nil;
 
   [self unlockFocus];
 
+  // Divider position hasn't changed don't try to resize subviews  
+  if (_isVertical == YES && p.x == op.x)
+    {
+      [self setNeedsDisplay: YES];
+      return;
+    }
+  else if (p.y == op.y)   
+    {
+      [self setNeedsDisplay: YES];
+      return;
+    }
+
   [nc postNotificationName: NSSplitViewWillResizeSubviewsNotification
 		    object: self];
 
@@ -868,7 +883,7 @@ static inline NSPoint centerSizeInRect(NSSize innerSize, NSRect outerRect)
 #define SET_DELEGATE_NOTIFICATION(notif_name) \
   if ([_delegate respondsToSelector: @selector(splitView##notif_name:)]) \
     [nc addObserver: _delegate \
-	   selector: @selector(splitView##notif_name: ) \
+	   selector: @selector(splitView##notif_name:) \
 	       name: NSSplitView##notif_name##Notification \
 	     object: self]
 
