@@ -20,7 +20,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "config.h"
@@ -172,10 +172,10 @@ id _nsstepperCellClass = nil;
   BOOL isDirectionUp;
   BOOL autorepeat = [_cell autorepeat];
 
-  if([_cell isEnabled] == NO)
+  if ([_cell isEnabled] == NO)
     return;
 
-  if([event type] != NSLeftMouseDown)
+  if ([event type] != NSLeftMouseDown)
     return;
 
   upRect = [_cell upButtonRectWithFrame: _bounds];
@@ -232,7 +232,7 @@ id _nsstepperCellClass = nil;
 		   untilDate: farAway
 		   inMode: NSEventTrackingRunLoopMode
 		   dequeue: YES];
-    while([event type] != NSLeftMouseUp)
+    while ([event type] != NSLeftMouseUp)
       {
 	if ([event type] == NSPeriodic)
 	  {
