@@ -22,7 +22,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "AppKit/NSColor.h"
@@ -318,7 +318,17 @@
 
 - (NSSize) minimumSize
 {
-  return NSZeroSize;
+  switch (_type)
+    {
+      case NSTopTabsBezelBorder:
+	return NSMakeSize(2, 19.5);
+      case NSNoTabsBezelBorder:
+	return NSMakeSize(2, 3);
+      case NSBottomTabsBezelBorder:
+	return NSMakeSize(2, 16);
+      default:
+	return NSZeroSize;
+    }
 }
 
 - (NSRect) contentRect
@@ -357,7 +367,7 @@
   NSGraphicsContext     *ctxt = GSCurrentContext();
   int			howMany = [_items count];
   int			i;
-  NSRect		previousRect;
+  NSRect		previousRect = NSMakeRect(0, 0, 0, 0);
   int			previousState = 0;
   NSRect		aRect = _bounds;
 
@@ -667,7 +677,7 @@
     {
       NSTabViewItem *anItem = [_items objectAtIndex: i];
 
-      if(NSPointInRect(point,[anItem _tabRect]))
+      if (NSPointInRect(point,[anItem _tabRect]))
 	return anItem;
     }
 
