@@ -20,7 +20,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "AppKit/NSTableHeaderCell.h"
@@ -59,7 +59,7 @@ static NSColor *clearCol = nil;
   NSRect interiorFrame = NSMakeRect (cellFrame.origin.x-1, cellFrame.origin.y-1, 
 				cellFrame.size.width+2, cellFrame.size.height+2);
 
-  if (NSIsEmptyRect (cellFrame) || ![controlView window])
+  if (NSIsEmptyRect (cellFrame))
     return;
 
   if (_cell.is_highlighted == YES)
