@@ -26,7 +26,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "config.h"
@@ -105,19 +105,27 @@ static Class textFieldCellClass;
   [super dealloc];
 }
 
-//
-// Setting User Access to Text
-//
+/** <p>Returns whether the NSTextField is editable. By default a NSTextField
+    is not editable.</p>
+    <p>See Also: -setEditable: [NSCell-isEditable]</p>
+*/
 - (BOOL) isEditable
 {
   return [_cell isEditable];
 }
 
+/** <p>Returns whether the NSTextField is selectable.</p>
+    <p>See Also: -setSelectable: [NSCell-isSelectable]</p>
+*/
 - (BOOL) isSelectable
 {
   return [_cell isSelectable];
 }
 
+/** <p>Sets whether the NSTextField's cell and the NSText object is editable.
+    By default a NSTextField is not editable.</p>
+    <p>See Also: -isEditable [NSCell-setEditable:] [NSText-setEditable:]</p>
+*/
 - (void) setEditable: (BOOL)flag
 {
   [_cell setEditable: flag];
@@ -125,6 +133,10 @@ static Class textFieldCellClass;
     [_text_object setEditable: flag];
 }
 
+/** <p>Sets whether the NSTextField's cell and the NSText object
+    is selectable.</p><p>See Also: -isSelectable 
+    [NSTextFieldCell-setSelectable:] [NSText-setSelectable:]</p>
+*/
 - (void) setSelectable: (BOOL)flag
 {
   [_cell setSelectable: flag];
@@ -132,9 +144,8 @@ static Class textFieldCellClass;
     [_text_object setSelectable: flag];
 }
 
-//
-// Editing Text
-//
+/**<p>Selects all the text of the NSTextField if it's selectable.</p>
+ */
 - (void) selectText: (id)sender
 {
   if ([self isSelectable] && (_super_view != nil))
@@ -143,18 +154,18 @@ static Class textFieldCellClass;
 	[_text_object selectAll: self];
       else
 	{
-	  NSText *t = [_window fieldEditor: YES  forObject: self];
+	  NSText *text = [_window fieldEditor: YES  forObject: self];
 	  int length;
 
-	  if ([t superview] != nil)
-	    if ([t resignFirstResponder] == NO)
+	  if ([text superview] != nil)
+	    if ([text resignFirstResponder] == NO)
 	      return;
 	  
 	  //  [NSCursor hide];
 	  /* [self stringValue] generates a call to validateEditing 
 	     so we need to call it before setting up the _text_object */
 	  length = [[self stringValue] length];
-	  _text_object = [_cell setUpFieldEditorAttributes: t];
+	  _text_object = [_cell setUpFieldEditorAttributes: text];
 	  [_cell selectWithFrame: _bounds
 		 inView: self
 		 editor: _text_object
@@ -165,32 +176,43 @@ static Class textFieldCellClass;
     }
 }
 
-//
-// Setting Tab Key Behavior
-//
+/**<p>Returns the object selected when the user presses the TAB key.</p>
+   <p>See Also: -setNextText: [NSView-nextKeyView]</p>
+ */
 - (id) nextText
 {
   return [self nextKeyView];
 }
 
+/**<p>Returns the object selected when the user presses the Shift-TAB key.</p>
+   <p>See Also: -setPreviousText: [NSView-previousKeyView]</p>
+ */
 - (id) previousText
 {
   return [self previousKeyView];
 }
 
+/**<p>Sets the object selected when the user presses the TAB key to
+   <var>anObject</var>.</p>
+   <p>See Also: -nextText [NSView-setNextKeyView:]</p>
+ */
 - (void) setNextText: (id)anObject
 {
   [self setNextKeyView: anObject];
 }
 
+/**<p>Sets the object selected when the user presses the shift-TAB key to
+   <var>anObject</var>.</p>
+   <p>See Also: -previousText [NSView-setPreviousKeyView:]</p>
+ */
 - (void) setPreviousText: (id)anObject
 {
   [self setPreviousKeyView: anObject];
 }
 
-//
-// Assigning a Delegate
-//
+/** <p>Sets the delegate to <var>anObject</var>.</p>
+    <p>See Also: -delegate</p>
+*/
 - (void) setDelegate: (id)anObject
 {
   if (_delegate)
@@ -208,59 +230,91 @@ static Class textFieldCellClass;
   SET_DELEGATE_NOTIFICATION(DidChange);
 }
 
+/** <p>Returns the delegate object.</p>
+    <p>See Also: -setDelegate:</p>
+*/
 - (id) delegate
 {
   return _delegate;
 }
 
-//
-// Modifying Graphic Attributes
-//
+/**<p>Sets the color used to draw the background to <var>aColor</var>.</p>
+   <p>See Also: -backgroundColor -setDrawsBackground: -drawsBackground
+   [NSTextFieldCell-setBackgroundColor:]</p>
+ */
 - (void) setBackgroundColor: (NSColor *)aColor
 {
   [_cell setBackgroundColor: aColor];
 }
 
+/** <p>Returns the color used to draw the background.</p>
+    <p>See Also: -setBackgroundColor: setDrawsBackground: -drawsBackground
+    [NSTextFieldCell-backgroundColor]</p>
+ */
 - (NSColor *) backgroundColor
 {
   return [_cell backgroundColor];
 }
 
+/** <p>Returns whether the NSTextField draws the background. By default NO.</p>
+    <p>See Also: -setDrawsBackground: [NSTextFieldCell-drawsBackground]</p>
+ */
 - (BOOL) drawsBackground
 {
   return [_cell drawsBackground];
 }
 
+/** <p>Returns whether the NSTextField's cell has bezeled border.</p>
+    <p>See Also: -setBezeled: [NSTextFieldCell-isBezeled]</p>
+ */
 - (BOOL) isBezeled
 {
   return [_cell isBezeled];
 }
 
+/** <p>Returns whether the NSTextField's cell has border.</p>
+    <p>See Also: -setBordered: [NSTextFieldCell-isBordered]</p>
+ */
 - (BOOL) isBordered
 {
   return [_cell isBordered];
 }
 
+/** <p>Sets whether the NSTextField's cell has bezeled border.</p>
+    <p>See Also: -isBezeled [NSTextFieldCell-setBezeled:]</p>
+ */
 - (void) setBezeled: (BOOL)flag
 {
   [_cell setBezeled: flag];
 }
 
+/** <p>Sets whether the NSTextField's cell has border.</p>
+    <p>See Also: -isBordered [NSTextFieldCell-setBordered:]</p>
+ */
 - (void) setBordered: (BOOL)flag
 {
   [_cell setBordered: flag];
 }
 
+/** <p>Sets whether the NSTextField draws the background. By default NO.</p>
+    <p>See Also: -drawsBackground [NSTextFieldCell-setDrawsBackground:]</p>
+ */
 - (void) setDrawsBackground: (BOOL)flag
 {
   [_cell setDrawsBackground: flag];
 }
 
+/** <p>Sets the  color with which the text will be draw to aColor.</p>
+    <p>See Also: -textColor [NSTextFieldCell-setTextColor:]</p>
+ */
 - (void) setTextColor: (NSColor *)aColor
 {
   [_cell setTextColor: aColor];
 }
 
+/** <p>Returns the colour used to draw the text.</p>
+    <p>See Also: -setTextColor: [NSTextFieldCell-textColor]</p>
+ */
 - (NSColor *) textColor
 {
   return [_cell textColor];
@@ -341,6 +395,11 @@ static Class textFieldCellClass;
   return [self isEditable];
 }
 
+/** <p>Returns whether the NSTextField accepts to be the first responder.
+    This method returns YES if the NSTextField is selectable and if
+    there is no NSText object</p><p>See Also: -becomeFirstResponder 
+    -isSelectable [NSView-acceptsFirstResponder]</p>
+ */
 - (BOOL) acceptsFirstResponder
 {
   // we do not accept first responder if there is already a 
@@ -414,7 +473,10 @@ static Class textFieldCellClass;
 	    }
 	  else
 	    {
-	      if ([_delegate control: self 
+	      SEL sel = @selector(control:didFailToFormatString:errorDescription:);
+
+	      if ([_delegate respondsToSelector: sel] && 
+		  [_delegate control: self 
 			     didFailToFormatString: string 
 			     errorDescription: error] == YES)
 		{
@@ -426,15 +488,20 @@ static Class textFieldCellClass;
     }
 }
 
+/**<p>Posts a NSControlTextDidBeginEditingNotification notification with object
+   self and a NSDictionary containing the NSFieldEditor for key
+   as user Info</p>
+*/
 - (void) textDidBeginEditing: (NSNotification *)aNotification
 {
-  NSDictionary *d;
+  NSDictionary *notifDict;
   
-  d = [NSDictionary dictionaryWithObject:[aNotification object] 
-		    forKey: @"NSFieldEditor"];
+  notifDict = [NSDictionary dictionaryWithObject:[aNotification object] 
+			    forKey: @"NSFieldEditor"];
+
   [nc postNotificationName: NSControlTextDidBeginEditingNotification
       object: self
-      userInfo: d];
+      userInfo: notifDict];
 }
 
 - (void) textDidChange: (NSNotification *)aNotification
@@ -468,9 +535,14 @@ static Class textFieldCellClass;
 
       if (wasAccepted == NO)
 	{
-	  [_delegate control:self 
-		     didFailToValidatePartialString: partialString 
-		     errorDescription: error];
+	  SEL sel = @selector(control:didFailToValidatePartialString:errorDescription:);
+	  
+	  if ([_delegate respondsToSelector: sel])
+	    {
+	      [_delegate control: self 
+			 didFailToValidatePartialString: partialString 
+			 errorDescription: error];
+	    }
 	}
 
       if (newString != nil)
@@ -589,6 +661,20 @@ static Class textFieldCellClass;
   return YES;
 }
 
+- (BOOL)textView: (NSTextView*)textView doCommandBySelector: (SEL)command
+{
+  if (_delegate && 
+      [_delegate respondsToSelector: @selector(control:textView:doCommandBySelector:)])
+    {
+      return [_delegate control: self 
+			textView: textView 
+			doCommandBySelector: command];
+    }
+
+   return NO;
+}
+
+
 //
 // Rich Text
 //
