@@ -42,7 +42,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
 */
 
 #include <Foundation/NSNotification.h>
@@ -174,7 +174,7 @@ send -shouldChangeTextInRange:replacementString: or -didChangeText.
     return;
 
   [_textStorage beginEditing];
-  for (i = r.location; i < NSMaxRange(r); )
+  for (i = r.location; i < NSMaxRange(r);)
     {
       current = [_textStorage attribute: name
 				atIndex: i
