@@ -25,7 +25,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include <Foundation/NSObject.h>
@@ -236,7 +236,8 @@ NSString *GSMovableToolbarItemPboardType = @"GSMovableToolbarItemPboardType";
   attrStr = [[NSAttributedString alloc] initWithString: label attributes: attr];
       
   textWidth = [attrStr size].width + 2 * InsetItemTextX;
-  if (layoutedWidth != -1 && textWidth > layoutedWidth) 
+  if ([[_toolbarItem toolbar] displayMode] != NSToolbarDisplayModeIconOnly 
+    && layoutedWidth != -1 && textWidth > layoutedWidth) 
      layoutedWidth = textWidth;
      
   // Adjust the layout in accordance with NSToolbarDisplayMode
@@ -252,7 +253,6 @@ NSString *GSMovableToolbarItemPboardType = @"GSMovableToolbarItemPboardType";
       case NSToolbarDisplayModeIconOnly:
         [self setImagePosition: NSImageOnly];
         layoutedHeight -= [attrStr size].height + InsetItemTextY;
-	layoutedWidth -= [attrStr size].height + InsetItemTextY;
 	break;
       case NSToolbarDisplayModeLabelOnly:
         [self setImagePosition: NSNoImage];
@@ -1019,7 +1019,7 @@ NSString *GSMovableToolbarItemPboardType = @"GSMovableToolbarItemPboardType";
       // GNUstep predefined toolbar items
        
       if ([itemIdentifier isEqualToString: @"NSToolbarSeparatorItemIdentifier"] 
-        && ![self isKindOfClass:[GSToolbarSeparatorItem class]] == NO)
+        && [self isKindOfClass:[GSToolbarSeparatorItem class]] == NO)
         {
           [self release];
           self = [[GSToolbarSeparatorItem alloc] 
@@ -1144,7 +1144,7 @@ NSString *GSMovableToolbarItemPboardType = @"GSMovableToolbarItemPboardType";
 
 - (BOOL) isEnabled
 {
-  if(_flags._isEnabled)
+  if (_flags._isEnabled)
     {
       return [(id)_backView isEnabled];
     }
@@ -1153,7 +1153,7 @@ NSString *GSMovableToolbarItemPboardType = @"GSMovableToolbarItemPboardType";
 
 - (NSImage *)image
 {
-  if(_flags._image)
+  if (_flags._image)
     {
       return _image;
     }
@@ -1203,7 +1203,7 @@ NSString *GSMovableToolbarItemPboardType = @"GSMovableToolbarItemPboardType";
 
 - (void) setAction: (SEL)action
 {
-  if(_flags._setAction)
+  if (_flags._setAction)
     {
       if ([_backView isKindOfClass: [GSToolbarButton class]])
         [(GSToolbarButton *)_backView setToolbarItemAction: action];
@@ -1221,13 +1221,13 @@ NSString *GSMovableToolbarItemPboardType = @"GSMovableToolbarItemPboardType";
 
 - (void) setEnabled: (BOOL)enabled
 {
-  if(_flags._setEnabled)
+  if (_flags._setEnabled)
     [(id)_backView setEnabled: enabled];
 }
 
 - (void) setImage: (NSImage *)image
 {
-  if(_flags._setImage)
+  if (_flags._setImage)
     {  
       ASSIGN(_image, image);  
       
@@ -1273,13 +1273,13 @@ NSString *GSMovableToolbarItemPboardType = @"GSMovableToolbarItemPboardType";
 
 - (void) setTag: (int)tag
 {
-  if(_flags._tag)
+  if (_flags._tag)
     _tag = tag;
 }
 
 - (void) setTarget: (id)target
 {
-   if(_flags._target)
+   if (_flags._target)
      {
        if ([_backView isKindOfClass: [NSButton class]])
          [(NSButton *)_backView setTarget: target];
@@ -1332,7 +1332,7 @@ NSString *GSMovableToolbarItemPboardType = @"GSMovableToolbarItemPboardType";
 
 - (int) tag
 {
-  if(_flags._tag)
+  if (_flags._tag)
     return _tag;
 
   return 0;
@@ -1463,7 +1463,7 @@ NSString *GSMovableToolbarItemPboardType = @"GSMovableToolbarItemPboardType";
 // NSValidatedUserInterfaceItem protocol
 - (SEL) action
 {
-  if(_flags._action)
+  if (_flags._action)
     {
       if ([_backView isKindOfClass: [GSToolbarButton class]])
         return [(GSToolbarButton *)_backView toolbarItemAction];
@@ -1473,7 +1473,7 @@ NSString *GSMovableToolbarItemPboardType = @"GSMovableToolbarItemPboardType";
 
 - (id) target
 {
-  if(_flags._target)
+  if (_flags._target)
     {
       if ([_backView isKindOfClass: [NSButton class]])
         return [(NSButton *)_backView target];
