@@ -26,10 +26,21 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */ 
 
 #include "config.h"
+
+#if	defined(HAVE_GETMNTENT) && defined (MNT_MEMB)
+#if	defined(HAVE_MNTENT_H)
+#include <mntent.h>
+#elif defined(HAVE_SYS_MNTENT_H)
+#include <sys/mntent.h>
+#else
+#undef	HAVE_GETMNTENT
+#endif
+#endif
+
 #include <Foundation/NSBundle.h>
 #include <Foundation/NSDictionary.h>
 #include <Foundation/NSHost.h>
@@ -72,6 +83,7 @@ static NSString	*GSWorkspaceNotification = @"GSWorkspaceNotification";
   NSDistributedNotificationCenter	*remote;
 }
 - (void) _handleRemoteNotification: (NSNotification*)aNotification;
+- (void) _postLocal: (NSString*)name userInfo: (NSDictionary*)info;
 @end
 
 @implementation	_GSWorkspaceCenter
@@ -170,9 +182,22 @@ static NSString	*GSWorkspaceNotification = @"GSWorkspaceNotification";
  */
 - (void) _handleRemoteNotification: (NSNotification*)aNotification
 {
-  [super postNotification: aNotification];
+  [self _postLocal: [aNotification name]
+	  userInfo: [aNotification userInfo]];
 }
 
+/*
+ * Method allowing a notification to be posted locally.
+ */
+- (void) _postLocal: (NSString*)name userInfo: (NSDictionary*)info
+{
+  NSNotification	*aNotification;
+
+  aNotification = [NSNotification notificationWithName: name
+						object: self
+					      userInfo: info];
+  [super postNotification: aNotification];
+}
 @end
 
 
@@ -280,13 +305,13 @@ static NSString	*GSWorkspaceNotification = @"GSWorkspaceNotification";
  *   NSTypes = (
  *     {
  *       NSIcon = "tiff.tiff";
- *       NSUnixExtensions = ( tiff, tif );
+ *       NSUnixExtensions = (tiff, tif);
  *     },
  *     {
  *       NSIcon = "xbm.tiff";
- *       NSUnixExtensions = ( xbm );
+ *       NSUnixExtensions = (xbm);
  *     }
- *   );
+ *);
  * }
  * </example>
  */
@@ -1128,9 +1153,10 @@ inFileViewerRootedAtPath: (NSString*)rootFullpath
 - (NSDictionary*) activeApplication
 {
   NSProcessInfo *processInfo = [NSProcessInfo processInfo];
+  NSString	*appName = [[GSServicesManager manager] port];
 
   return [NSDictionary dictionaryWithObjectsAndKeys:
-    [processInfo processName], @"NSApplicationName",
+    appName, @"NSApplicationName",
     [[NSBundle mainBundle] bundlePath], @"NSApplicationPath",
     [NSNumber numberWithInt: [processInfo processIdentifier]], 
 		   @"NSApplicationProcessIdentifier",
@@ -1215,25 +1241,29 @@ inFileViewerRootedAtPath: (NSString*)rootFullpath
 
 - (NSArray*) mountedRemovableMedia
 {
-  NSArray	*volumes = [self mountedLocalVolumePaths];
-  NSMutableArray *names = [NSMutableArray arrayWithCapacity: [volumes count]];
-  unsigned	i;
+  NSArray		*volumes;
+  NSMutableArray	*names;
+  unsigned		count;
+  unsigned		i;
 
-  for (i = 0; i < [volumes count]; i++)
+  volumes = [self mountedLocalVolumePaths];
+  count = [volumes count];
+  names = [NSMutableArray arrayWithCapacity: count];
+  for (i = 0; i < count; i++)
     {
-      BOOL removableFlag;
-      BOOL writableFlag;
-      BOOL unmountableFlag;
-      NSString *description;
-      NSString *fileSystemType;
-      NSString *name = [volumes objectAtIndex: i];
+      BOOL	removableFlag;
+      BOOL	writableFlag;
+      BOOL	unmountableFlag;
+      NSString	*description;
+      NSString	*fileSystemType;
+      NSString	*name = [volumes objectAtIndex: i];
 
       if ([self getFileSystemInfoForPath: name
-		isRemovable: &removableFlag
-		isWritable: &writableFlag
-		isUnmountable: &unmountableFlag
-		description: &description
-		type: &fileSystemType] && removableFlag)
+			     isRemovable: &removableFlag
+			      isWritable: &writableFlag
+			   isUnmountable: &unmountableFlag
+			     description: &description
+				    type: &fileSystemType] && removableFlag)
         {
 	  [names addObject: name];
 	}
@@ -1244,12 +1274,63 @@ inFileViewerRootedAtPath: (NSString*)rootFullpath
 
 - (NSArray*) mountedLocalVolumePaths
 {
+  NSMutableArray	*names;
+  NSFileManager		*mgr = [NSFileManager defaultManager];
+#ifdef	__MINGW__
+  unsigned		max = BUFSIZ;
+  unichar		buf[max];
+  unichar		*base = buf;
+  unichar		*ptr;
+  unichar		*end;
+  unsigned		len;
+
+  names = [NSMutableArray arrayWithCapacity: 8];
+  len = GetLogicalDriveStringsW(max-1, base);
+  while (len >= max)
+    {
+      base = NSZoneMalloc(NSDefaultMallocZone(), (len+1) * sizeof(unichar));
+      max = len;
+      len = GetLogicalDriveStringsW(max-1, base);
+    }
+  for (ptr = base; *ptr != 0; ptr = end + 1)
+    {
+      NSString	*path;
+
+      end = ptr;
+      while (*end != 0)
+	{
+	  end++;
+	}
+      len = (end - ptr);
+      path = [mgr stringWithFileSystemRepresentation: ptr length: len];
+      [names addObject: path];
+    }
+  if (base != buf)
+    {
+      NSZoneFree(NSDefaultMallocZone(), base);
+    }
+
+#elif	defined(HAVE_GETMNTENT) && defined (MNT_MEMB)
+  FILE		*fptr = fopen("/etc/mtab", "r");
+  struct mntent	*m;
+
+  names = [NSMutableArray arrayWithCapacity: 8];
+  while ((m = getmntent(fptr)) != 0)
+    {
+      NSString	*path;
+
+      path = [mgr stringWithFileSystemRepresentation: m->MNT_MEMB
+					      length: strlen(m->MNT_MEMB)];
+      [names addObject: path];
+    }
+#else
+
   // FIXME This is system specific
   NSString	*mtab = [NSString stringWithContentsOfFile: @"/etc/mtab"];
   NSArray	*mounts = [mtab componentsSeparatedByString: @"\n"];
-  NSMutableArray *names = [NSMutableArray arrayWithCapacity: [mounts count]];
   unsigned int	i;
 
+  names = [NSMutableArray arrayWithCapacity: [mounts count]];
   for (i = 0; i < [mounts count]; i++)
     {
       NSString  *mount = [mounts objectAtIndex: i];
@@ -1271,7 +1352,7 @@ inFileViewerRootedAtPath: (NSString*)rootFullpath
            }
         }
     }
-  
+#endif  
   return names;
 }
 
@@ -1314,12 +1395,25 @@ inFileViewerRootedAtPath: (NSString*)rootFullpath
 }
 
 /*
- * Requesting Additional Time before Power Off or Logout
+ * Requesting Additional Time before Power Off or Logout<br />
+ * Returns the amount of time actually granted (which may be less than
+ * requested).<br />
+ * Times are measured in milliseconds.
  */
 - (int) extendPowerOffBy: (int)requested
 {
-  // FIXME
-  return 0;
+  int	result = 0;
+  id	app = [self _workspaceApplication];
+
+  if (app != nil)
+    {
+      NS_DURING
+	result = [app extendPowerOffBy: requested];
+      NS_HANDLER
+	result = 0;
+      NS_ENDHANDLER
+    }
+  return result;
 }
 
 @end
