@@ -23,7 +23,7 @@
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
-   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "config.h"
@@ -145,7 +145,7 @@ NSString *NSControlTextDidChangeNotification =
 @"NSControlTextDidChangeNotification";
 
 // NSDataLink global strings
-NSString *NSDataLinkFileNameExtension = @"dlf";
+NSString *NSDataLinkFilenameExtension = @"dlf";
 
 // NSDrawer notifications
 NSString *NSDrawerDidCloseNotification =
